@@ -2,6 +2,7 @@
 /* Copyright (C) 2001-2002	Rodolphe Quiedeville	<rodolphe@quiedeville.org>
  * Copyright (C) 2004-2012	Laurent Destailleur		<eldy@users.sourceforge.net>
  * Copyright (C) 2005-2012	Regis Houssin			<regis.houssin@capnetworks.com>
+ * Copyright (C) 2016       Juanjo Menent		<jmenent@2byte.es>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -67,8 +68,8 @@ print '<br>';
 $phparray=phpinfo_array();
 foreach($phparray as $key => $value)
 {
-	//print load_fiche_titre($key);
-	print '<table class="noborder">';
+    print '<div class="div-table-responsive-no-min">';
+    print '<table class="noborder">';
 	print '<tr class="liste_titre">';
 	//print '<td width="220px">'.$langs->trans("Parameter").'</td>';
 	print '<td width="220px">'.$key.'</td>';
@@ -87,9 +88,9 @@ foreach($phparray as $key => $value)
 			$valtoshow=$keyvalue;
 			if ($keyparam == 'X-ChromePhp-Data') $valtoshow=dol_trunc($keyvalue,80);
 			print '<td colspan="2">';
-			if ($keyparam == 'Path') $valtoshow=join('; ',explode(';',trim($valtoshow)));
-			if ($keyparam == 'PATH') $valtoshow=join('; ',explode(';',trim($valtoshow)));
-			if ($keyparam == '_SERVER["PATH"]') $valtoshow=join('; ',explode(';',trim($valtoshow)));
+			if ($keyparam == 'Path') $valtoshow=implode('; ',explode(';',trim($valtoshow)));
+			if ($keyparam == 'PATH') $valtoshow=implode('; ',explode(';',trim($valtoshow)));
+			if ($keyparam == '_SERVER["PATH"]') $valtoshow=implode('; ',explode(';',trim($valtoshow)));
 			print $valtoshow;
 			print '</td>';
 			print '</tr>';
@@ -104,7 +105,7 @@ foreach($phparray as $key => $value)
 			{
 				print '<td>';
 				$valtoshow=$keyvalue2;
-				if ($keyparam == 'disable_functions') $valtoshow=join(', ',explode(',',trim($valtoshow)));
+				if ($keyparam == 'disable_functions') $valtoshow=implode(', ',explode(',',trim($valtoshow)));
 				//print $keyparam;
 				print $valtoshow;
 				$i++;
@@ -113,7 +114,9 @@ foreach($phparray as $key => $value)
 			print '</tr>';
 		}
 	}
-	print '</table><br>';
+	print '</table>';
+	print '</div>';
+	print '<br>';
 }
 
 
