@@ -32,12 +32,12 @@ $obj_facturation = unserialize($_SESSION['serObjFacturation']);
 unset ($_SESSION['serObjFacturation']);
 
 
-switch ( $_GET['action'] )
+switch (GETPOST('action','alpha'))
 {
 	default:
 		if ( $_POST['hdnSource'] != 'NULL' )
 		{
-			$sql = "SELECT p.rowid, p.ref, p.price, p.tva_tx, p.recuperableonly";
+			$sql = "SELECT p.rowid, p.ref, p.price, p.tva_tx, p.default_vat_code, p.recuperableonly";
 			if (! empty($conf->stock->enabled) && !empty($conf_fkentrepot)) $sql.= ", ps.reel";
 			$sql.= " FROM ".MAIN_DB_PREFIX."product as p";
 			if (! empty($conf->stock->enabled) && !empty($conf_fkentrepot)) $sql.= " LEFT JOIN ".MAIN_DB_PREFIX."product_stock as ps ON p.rowid = ps.fk_product AND ps.fk_entrepot = ".$conf_fkentrepot;
@@ -54,7 +54,6 @@ switch ( $_GET['action'] )
 			}
 
 			$result = $db->query($sql);
-
 			if ($result)
 			{
 				// ... et enregistrement dans l'objet
@@ -67,62 +66,90 @@ switch ( $_GET['action'] )
 						$ret[$key] = $value;
 					}
                     // Here $ret['tva_tx'] is vat rate of product but we want to not use the one into table but found by function
-                    
+
 					$productid = $ret['rowid'];
 					$product = new Product($db);
                     $product->fetch($productid);
+                    $prod = $product;
 
 					$thirdpartyid = $_SESSION['CASHDESK_ID_THIRDPARTY'];
                     $societe = new Societe($db);
 					$societe->fetch($thirdpartyid);
 
-					$tva_tx = get_default_tva($mysoc,$societe,$productid);
-					$tva_npr = get_default_npr($mysoc,$societe,$productid);
+					// Update if prices fields are defined
+					$tva_tx = get_default_tva($mysoc, $societe, $product->id);
+					$tva_npr = get_default_npr($mysoc, $societe, $product->id);
 					if (empty($tva_tx)) $tva_npr=0;
-					dol_syslog('tva_tx='.$tva_tx.'-tva_npr='.$tva_npr);
-					
+
+					$pu_ht = $prod->price;
+					$pu_ttc = $prod->price_ttc;
+					$price_min = $prod->price_min;
+					$price_base_type = $prod->price_base_type;
+
+					// multiprix
 					if (! empty($conf->global->PRODUIT_MULTIPRICES) && ! empty($societe->price_level))
 					{
-						if(isset($product->multiprices[$societe->price_level]))
-						{
-							$ret['price'] = $product->multiprices[$societe->price_level];
-							$ret['price_ttc'] = $product->multiprices_ttc[$societe->price_level];
-							// $product->multiprices_min[$societe->price_level];
-							// $product->multiprices_min_ttc[$societe->price_level];
-							// $product->multiprices_base_type[$societe->price_level];
-							if (! empty($conf->global->PRODUIT_MULTIPRICES_USE_VAT_PER_LEVEL))  // using this option is a bug. kept for backward compatibility
-							{
-							    if (isset($prod->multiprices_tva_tx[$societe->price_level])) $tva_tx=$prod->multiprices_tva_tx[$societe->price_level];
-							    if (isset($prod->multiprices_recuperableonly[$societe->price_level])) $tva_npr=$prod->multiprices_recuperableonly[$societe->price_level];
-							    if (empty($tva_tx)) $tva_npr=0;
-							}
-						}
+					    $pu_ht = $prod->multiprices[$societe->price_level];
+					    $pu_ttc = $prod->multiprices_ttc[$societe->price_level];
+					    $price_min = $prod->multiprices_min[$societe->price_level];
+					    $price_base_type = $prod->multiprices_base_type[$societe->price_level];
+					    if (! empty($conf->global->PRODUIT_MULTIPRICES_USE_VAT_PER_LEVEL))  // using this option is a bug. kept for backward compatibility
+					    {
+					        if (isset($prod->multiprices_tva_tx[$societe->price_level])) $tva_tx=$prod->multiprices_tva_tx[$societe->price_level];
+					        if (isset($prod->multiprices_recuperableonly[$societe->price_level])) $tva_npr=$prod->multiprices_recuperableonly[$societe->price_level];
+					    }
+					}
+					elseif (! empty($conf->global->PRODUIT_CUSTOMER_PRICES))
+					{
+					    require_once DOL_DOCUMENT_ROOT . '/product/class/productcustomerprice.class.php';
+
+					    $prodcustprice = new Productcustomerprice($db);
+
+					    $filter = array('t.fk_product' => $prod->id,'t.fk_soc' => $societe->id);
+
+					    $result = $prodcustprice->fetch_all('', '', 0, 0, $filter);
+					    if ($result >= 0)
+					    {
+					        if (count($prodcustprice->lines) > 0)
+					        {
+					            $pu_ht = price($prodcustprice->lines [0]->price);
+					            $pu_ttc = price($prodcustprice->lines [0]->price_ttc);
+					            $price_base_type = $prodcustprice->lines [0]->price_base_type;
+					            $tva_tx = $prodcustprice->lines [0]->tva_tx;
+					        }
+					    }
+					    else
+					    {
+					        setEventMessages($prodcustprice->error, $prodcustprice->errors, 'errors');
+					    }
+					}
+
+					$tmpvat = price2num(preg_replace('/\s*\(.*\)/', '', $tva_tx));
+					$tmpprodvat = price2num(preg_replace('/\s*\(.*\)/', '', $prod->tva_tx));
+
+					// if price ht is forced (ie: calculated by margin rate and cost price). TODO Why this ?
+					if (! empty($price_ht)) {
+					    $pu_ht = price2num($price_ht, 'MU');
+					    $pu_ttc = price2num($pu_ht * (1 + ($tmpvat / 100)), 'MU');
+					}
+					// On reevalue prix selon taux tva car taux tva transaction peut etre different
+					// de ceux du produit par defaut (par exemple si pays different entre vendeur et acheteur).
+					elseif ($tmpvat != $tmpprodvat) {
+					    if ($price_base_type != 'HT') {
+					        $pu_ht = price2num($pu_ttc / (1 + ($tmpvat / 100)), 'MU');
+					    } else {
+					        $pu_ttc = price2num($pu_ht * (1 + ($tmpvat / 100)), 'MU');
+					    }
 					}
 
-					$ret['tva_tx'] = $tva_tx;
-					$ret['tva_npr'] = $tva_npr;
-                    //var_dump('tva_tx='.$ret['tva_tx'].'-tva_npr='.$ret['tva_npr'].'-'.$conf->global->PRODUIT_MULTIPRICES_USE_VAT_PER_LEVEL);exit;
-                    
 					$obj_facturation->id($ret['rowid']);
 					$obj_facturation->ref($ret['ref']);
 					$obj_facturation->stock($ret['reel']);
 					$obj_facturation->prix($ret['price']);
-					
-					// Use $ret['tva_tx'] / ret['tva_npr'] to find vat id
-					$vatrowid = null;
-					$sqlfindvatid = 'SELECT rowid FROM '.MAIN_DB_PREFIX.'c_tva';
-					$sqlfindvatid.= ' WHERE taux = '.$ret['tva_tx'].' AND recuperableonly = '.(int) $ret['tva_npr'];
-					$sqlfindvatid.= ' AND fk_pays = '.$mysoc->country_id;
-					$resqlfindvatid=$db->query($sqlfindvatid);
-					if ($resqlfindvatid)
-					{
-					    $obj = $db->fetch_object($resqlfindvatid);
-					    if ($obj) $vatrowid = $obj->rowid;
-					}
-					else dol_print_error($db);
-					
-					dol_syslog("save vatrowid=".$vatrowid);
-					$obj_facturation->tva($vatrowid);     // Save vat it for next use
+
+
+					$vatrate = $tva_tx;
+					$obj_facturation->vatrate = $vatrate;       // Save vat rate (full text vat with code)
 
 					// Definition du filtre pour n'afficher que le produit concerne
 					if ( $_POST['hdnSource'] == 'LISTE' )
@@ -168,11 +195,11 @@ switch ( $_GET['action'] )
 		{
 		    dol_syslog("facturation_verif save vat ".$_POST['selTva']);
 			$obj_facturation->qte($_POST['txtQte']);
-			$obj_facturation->tva($_POST['selTva']);                 // Save VAT selected so we can use it for next product
+			$obj_facturation->tva($_POST['selTva']);     // id of vat. Saved so we can use it for next product
 			$obj_facturation->remisePercent($_POST['txtRemise']);
 			$obj_facturation->ajoutArticle();	// This add an entry into $_SESSION['poscart']
 			// We update prixTotalTtc
-			 
+
 		}
 
 		$redirection = DOL_URL_ROOT.'/cashdesk/affIndex.php?menutpl=facturation';
