@@ -22,9 +22,10 @@ $langs->load("bills");
 
 ?>
 
-<h3 class="titre1"><?php echo $langs->trans("SellFinished"); ?></h3><br>
+<div class="blocksellfinished">
 
 <div class="cadre_facturation">
+<h3 class="titre1"><?php echo $langs->trans("SellFinished"); ?></h3><br>
 
 <script type="text/javascript">
 
@@ -33,7 +34,7 @@ $langs->load("bills");
 		largeur = 600;
 		hauteur = 500;
 		opt = 'width='+largeur+', height='+hauteur+', left='+(screen.width - largeur)/2+', top='+(screen.height-hauteur)/2+'';
-		window.open('validation_ticket.php?facid=<?php echo $_GET['facid']; ?>', '<?php echo $langs->trans('PrintTicket') ?>', opt);
+		window.open('validation_ticket.php?facid=<?php echo GETPOST('facid','int'); ?>', '<?php echo $langs->trans('PrintTicket') ?>', opt);
 	}
 
 	popupTicket();
@@ -45,3 +46,6 @@ $langs->load("bills");
 <p><a class="lien1" href="#" onclick="Javascript: popupTicket(); return(false);"><?php echo $langs->trans("PrintTicket"); ?></a></p>
 
 </div>
+</div>
+<br>
+
