@@ -24,17 +24,20 @@
 require '../main.inc.php';
 require_once DOL_DOCUMENT_ROOT.'/cashdesk/include/environnement.php';
 require_once DOL_DOCUMENT_ROOT.'/cashdesk/class/Facturation.class.php';
+include_once(DOL_DOCUMENT_ROOT.'/core/class/hookmanager.class.php');
 
 $obj_facturation = unserialize($_SESSION['serObjFacturation']);
 unset($_SESSION['serObjFacturation']);
 
+$hookmanager->initHooks(array('cashdeskTplTicket'));
 
-require ('tpl/ticket.tpl.php');
+$parameters=array();
+$reshook=$hookmanager->executeHooks('doActions',$parameters,$obj_facturation);
+if (empty($reshook))
+{
+    require ('tpl/ticket.tpl.php');
+}
 
 
 $_SESSION['serObjFacturation'] = serialize($obj_facturation);
 
-?>
-
-
-
