@@ -36,8 +36,6 @@ $langs->load("categories");
 $langs->load("bills");
 
 
-$mesg = '';
-
 $id=GETPOST('id','int');
 $ref=GETPOST('ref');
 $type=GETPOST('type');
@@ -101,36 +99,42 @@ if ($object->id)
 	elseif ($type == Categorie::TYPE_MEMBER)    $title=$langs->trans("MembersCategoryShort");
 	elseif ($type == Categorie::TYPE_CONTACT)   $title=$langs->trans("ContactCategoriesShort");
 	elseif ($type == Categorie::TYPE_ACCOUNT)   $title=$langs->trans("AccountsCategoriesShort");
+	elseif ($type == Categorie::TYPE_PROJECT)   $title=$langs->trans("ProjectsCategoriesShort");
     else                                        $title=$langs->trans("Category");
 
 	$head = categories_prepare_head($object,$type);
-	dol_fiche_head($head, 'photos', $title, 0, 'category');
 
+
+	dol_fiche_head($head, 'photos', $title, 0, 'category');
+	
+	$linkback = '<a href="'.DOL_URL_ROOT.'/categories/index.php?leftmenu=cat&type='.$type.'">'.$langs->trans("BackToList").'</a>';
+	
+	$object->ref = $object->label;
+	$morehtmlref='<br><div class="refidno"><a href="'.DOL_URL_ROOT.'/categories/index.php?leftmenu=cat&type='.$type.'">'.$langs->trans("Root").'</a> >> ';
+	$ways = $object->print_all_ways(" &gt;&gt; ", '', 1);
+	foreach ($ways as $way)
+	{
+	    $morehtmlref.=$way."<br>\n";
+	}
+	$morehtmlref.='</div>';
+	
+	dol_banner_tab($object, 'ref', $linkback, ($user->societe_id?0:1), 'ref', 'ref', $morehtmlref, '', 0, '', '', 1);
+	
 	/*
 	 * Confirmation de la suppression de photo
 	*/
 	if ($action == 'delete')
 	{
-		print $form->formconfirm($_SERVER["PHP_SELF"].'?id='.$object->id.'&type='.$type.'&file='.$_GET["file"], $langs->trans('DeletePicture'), $langs->trans('ConfirmDeletePicture'), 'confirm_delete', '', 0, 1);
+	    print $form->formconfirm($_SERVER["PHP_SELF"].'?id='.$object->id.'&type='.$type.'&file='.$_GET["file"], $langs->trans('DeletePicture'), $langs->trans('ConfirmDeletePicture'), 'confirm_delete', '', 0, 1);
 	}
 
-	print($mesg);
-
+	print '<br>';
+	
+	print '<div class="underbanner clearboth"></div>';
 	print '<table class="border" width="100%">';
 
-	// Path of category
-	print '<tr><td class="titlefield notopnoleft">';
-	$ways = $object->print_all_ways(" &gt;&gt; ", '', 1);
-	print $langs->trans("Ref").'</td><td>';
-	print '<a href="'.DOL_URL_ROOT.'/categories/index.php?leftmenu=cat&type='.$type.'">'.$langs->trans("Root").'</a> >> ';
-	foreach ($ways as $way)
-	{
-		print $way."<br>\n";
-	}
-	print '</td></tr>';
-
 	// Description
-	print '<tr><td class="notopnoleft">';
+	print '<tr><td class="titlefield notopnoleft">';
 	print $langs->trans("Description").'</td><td>';
 	print dol_htmlentitiesbr($object->description);
 	print '</td></tr>';
@@ -140,10 +144,10 @@ if ($object->id)
 	print $langs->trans("Color").'</td><td>';
 	print $formother->showColor($object->color);
 	print '</td></tr>';
-	
+
 	print "</table>\n";
 
-	print "</div>\n";
+	print dol_fiche_end();
 
 
 
