@@ -1,9 +1,12 @@
 <?php
 /* Copyright (C) 2001-2006 Rodolphe Quiedeville <rodolphe@quiedeville.org>
  * Copyright (C) 2003      Xavier DUTOIT        <doli@sydesy.com>
- * Copyright (C) 2004-2011 Laurent Destailleur  <eldy@users.sourceforge.net>
+ * Copyright (C) 2004-2015 Laurent Destailleur  <eldy@users.sourceforge.net>
  * Copyright (C) 2004      Christophe Combelles <ccomb@free.fr>
  * Copyright (C) 2005-2012 Regis Houssin        <regis.houssin@capnetworks.com>
+ * Copyright (C) 2015-2016 Alexandre Spangaro	<aspangaro@zendsi.com>
+ * Copyright (C) 2015      Jean-François Ferry	<jfefe@aternatik.fr>
+ * Copyright (C) 2016      Marcos García        <marcosgdf@gmail.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -21,7 +24,7 @@
 
 /**
  *	\file       htdocs/compta/bank/ligne.php
- *	\ingroup    compta
+ *	\ingroup    bank
  *	\brief      Page to edit a bank transaction record
  */
 
@@ -33,6 +36,9 @@ $langs->load("categories");
 $langs->load("compta");
 $langs->load("bills");
 if (! empty($conf->adherent->enabled)) $langs->load("members");
+if (! empty($conf->don->enabled)) $langs->load("donations");
+if (! empty($conf->loan->enabled)) $langs->load("loan");
+if (! empty($conf->salaries->enabled)) $langs->load("salaries");
 
 
 $id = (GETPOST('id','int') ? GETPOST('id','int') : GETPOST('account','int'));
@@ -77,13 +83,13 @@ if ($action == 'confirm_delete_categ' && $confirm == "yes" && $user->rights->ban
 
 if ($user->rights->banque->modifier && $action == 'class')
 {
-    $sql = "DELETE FROM ".MAIN_DB_PREFIX."bank_class WHERE lineid = ".$rowid." AND fk_categ = ".$_POST["cat1"];
+    $sql = "DELETE FROM ".MAIN_DB_PREFIX."bank_class WHERE lineid = ".$rowid." AND fk_categ = ".GETPOST('cat1', 'int');
     if (! $db->query($sql))
     {
         dol_print_error($db);
     }
 
-    $sql = "INSERT INTO ".MAIN_DB_PREFIX."bank_class (lineid, fk_categ) VALUES (".$rowid.", ".$_POST["cat1"].")";
+    $sql = "INSERT INTO ".MAIN_DB_PREFIX."bank_class (lineid, fk_categ) VALUES (".$rowid.", ".GETPOST('cat1', 'int').")";
     if (! $db->query($sql))
     {
         dol_print_error($db);
@@ -97,9 +103,9 @@ if ($user->rights->banque->modifier && $action == "update")
 	$ac = new Account($db);
 	$ac->fetch($id);
 
-	if ($ac->courant == 2 && $_POST['value'] != 'LIQ')
+	if ($ac->courant == Account::TYPE_CASH && $_POST['value'] != 'LIQ')
 	{
-		$mesg = '<div class="error">'.$langs->trans("ErrorCashAccountAcceptsOnlyCashMoney").'</div>';
+		setEventMessages($langs->trans("ErrorCashAccountAcceptsOnlyCashMoney"), null, 'errors');
 		$error++;
 	}
 
@@ -141,7 +147,7 @@ if ($user->rights->banque->modifier && $action == "update")
 		$result = $db->query($sql);
 		if ($result)
 		{
-			$mesg=$langs->trans("RecordSaved");
+			setEventMessages($langs->trans("RecordSaved"), null, 'mesgs');
 			$db->commit();
 		}
 		else
@@ -161,7 +167,7 @@ if ($user->rights->banque->consolidate && ($action == 'num_releve' || $action ==
     // Check parameters
     if ($rappro && empty($num_rel))
     {
-        $mesg=$langs->trans("ErrorFieldRequired",$langs->transnoentitiesnoconv("AccountStatement"));
+	    setEventMessages($langs->trans("ErrorFieldRequired", $langs->transnoentitiesnoconv("AccountStatement")), null, 'errors');
         $error++;
     }
 
@@ -175,11 +181,11 @@ if ($user->rights->banque->consolidate && ($action == 'num_releve' || $action ==
         else $sql.=", rappro = ".$rappro;
         $sql.= " WHERE rowid = ".$rowid;
 
-        dol_syslog("ligne.php sql=".$sql, LOG_DEBUG);
+        dol_syslog("ligne.php", LOG_DEBUG);
         $result = $db->query($sql);
         if ($result)
         {
-            $mesg=$langs->trans("RecordSaved");
+	        setEventMessages($langs->trans("RecordSaved"), null, 'mesgs');
             $db->commit();
         }
         else
@@ -200,24 +206,13 @@ $form = new Form($db);
 
 llxHeader();
 
-// On initialise la liste des categories
-$sql = "SELECT rowid, label";
-$sql.= " FROM ".MAIN_DB_PREFIX."bank_categ";
-$sql.= " ORDER BY label";
-$result = $db->query($sql);
-if ($result)
-{
-    $var=True;
-    $num = $db->num_rows($result);
-    $i = 0;
-    $options = "<option value=\"0\" selected=\"true\">&nbsp;</option>";
-    while ($i < $num)
-    {
-        $obj = $db->fetch_object($result);
-        $options .= "<option value=\"$obj->rowid\">$obj->label</option>\n";
-        $i++;
-    }
-    $db->free($result);
+// Load bank groups
+require_once DOL_DOCUMENT_ROOT.'/compta/bank/class/bankcateg.class.php';
+$bankcateg = new BankCateg($db);
+$options = array();
+
+foreach ($bankcateg->fetchAll() as $bankcategory) {
+    $options[$bankcategory->id] = $bankcategory->label;
 }
 
 $var=false;
@@ -235,8 +230,6 @@ $tabs = array(
 
 dol_fiche_head($tabs, 0, $langs->trans('LineRecord'), 0, 'account');
 
-dol_htmloutput_mesg($mesg);
-
 $sql = "SELECT b.rowid,b.dateo as do,b.datev as dv, b.amount, b.label, b.rappro,";
 $sql.= " b.num_releve, b.fk_user_author, b.num_chq, b.fk_type, b.fk_account, b.fk_bordereau as receiptid,";
 $sql.= " b.emetteur,b.banque";
@@ -267,7 +260,7 @@ if ($result)
         if ($action == 'delete_categ')
         {
             print $form->formconfirm($_SERVER['PHP_SELF']."?rowid=".$rowid."&cat1=".GETPOST("fk_categ")."&orig_account=".$orig_account, $langs->trans("RemoveFromRubrique"), $langs->trans("RemoveFromRubriqueConfirm"), "confirm_delete_categ", '', 'yes', 1);
-            
+
         }
 
         print '<form name="update" method="POST" action="'.$_SERVER['PHP_SELF'].'?rowid='.$rowid.'">';
@@ -278,11 +271,11 @@ if ($result)
 
         print '<table class="border" width="100%">';
 
-        $linkback = '<a href="'.DOL_URL_ROOT.'/compta/bank/search.php">'.$langs->trans("BackToList").'</a>';
+        $linkback = '<a href="'.DOL_URL_ROOT.'/compta/bank/bankentries.php">'.$langs->trans("BackToList").'</a>';
 
         // Ref
-        print '<tr><td width="20%">'.$langs->trans("Ref")."</td>";
-        print '<td colspan="4">';
+        print '<tr><td class="titlefield">'.$langs->trans("Ref")."</td>";
+        print '<td>';
         print $form->showrefnav($bankline, 'rowid', $linkback, 1, 'rowid', 'rowid');
         print '</td>';
         print '</tr>';
@@ -292,7 +285,7 @@ if ($result)
 
         // Bank account
         print "<tr><td>".$langs->trans("Account")."</td>";
-        print '<td colspan="4">';
+        print '<td>';
         print $acct->getNomUrl(1,'transactions');
         print '</td>';
         print '</tr>';
@@ -301,51 +294,74 @@ if ($result)
         if (count($links))
         {
             print "<tr><td>".$langs->trans("Links")."</td>";
-            print '<td colspan="4">';
+            print '<td>';
             foreach($links as $key=>$val)
             {
                 if ($key) print '<br>';
                 if ($links[$key]['type']=='payment') {
-                    print '<a href="'.DOL_URL_ROOT.'/compta/paiement/fiche.php?id='.$links[$key]['url_id'].'">';
+                    print '<a href="'.DOL_URL_ROOT.'/compta/paiement/card.php?id='.$links[$key]['url_id'].'">';
                     print img_object($langs->trans('ShowPayment'),'payment').' ';
                     print $langs->trans("Payment");
                     print '</a>';
                 }
                 else if ($links[$key]['type']=='payment_supplier') {
-                    print '<a href="'.DOL_URL_ROOT.'/fourn/paiement/fiche.php?id='.$links[$key]['url_id'].'">';
+                    print '<a href="'.DOL_URL_ROOT.'/fourn/paiement/card.php?id='.$links[$key]['url_id'].'">';
                     print img_object($langs->trans('ShowPayment'),'payment').' ';
                     print $langs->trans("Payment");
                     print '</a>';
                 }
                 else if ($links[$key]['type']=='company') {
-                    print '<a href="'.DOL_URL_ROOT.'/societe/soc.php?socid='.$links[$key]['url_id'].'">';
-                    print img_object($langs->trans('ShowCompany'),'company').' ';
-                    print $links[$key]['label'];
-                    print '</a>';
+                    $societe=new Societe($db);
+                    $societe->fetch($links[$key]['url_id']);
+                    print $societe->getNomUrl(1);
                 }
                 else if ($links[$key]['type']=='sc') {
-                    print '<a href="'.DOL_URL_ROOT.'/compta/sociales/charges.php?id='.$links[$key]['url_id'].'">';
+                    print '<a href="'.DOL_URL_ROOT.'/compta/sociales/card.php?id='.$links[$key]['url_id'].'">';
                     print img_object($langs->trans('ShowSocialContribution'),'bill').' ';
                     print $langs->trans("SocialContribution").($links[$key]['label']?' - '.$links[$key]['label']:'');
                     print '</a>';
                 }
                 else if ($links[$key]['type']=='payment_sc') {
-                    print '<a href="'.DOL_URL_ROOT.'/compta/payment_sc/fiche.php?id='.$links[$key]['url_id'].'">';
+                    print '<a href="'.DOL_URL_ROOT.'/compta/payment_sc/card.php?id='.$links[$key]['url_id'].'">';
                     print img_object($langs->trans('ShowPayment'),'payment').' ';
                     print $langs->trans("SocialContributionPayment");
                     print '</a>';
                 }
                 else if ($links[$key]['type']=='payment_vat') {
-                    print '<a href="'.DOL_URL_ROOT.'/compta/tva/fiche.php?id='.$links[$key]['url_id'].'">';
+                    print '<a href="'.DOL_URL_ROOT.'/compta/tva/card.php?id='.$links[$key]['url_id'].'">';
                     print img_object($langs->trans('ShowVAT'),'payment').' ';
                     print $langs->trans("VATPayment");
                     print '</a>';
                 }
+                else if ($links[$key]['type']=='payment_salary') {
+                    print '<a href="'.DOL_URL_ROOT.'/compta/salaries/card.php?id='.$links[$key]['url_id'].'">';
+                    print img_object($langs->trans('ShowPaymentSalary'),'payment').' ';
+                    print $langs->trans("SalaryPayment");
+                    print '</a>';
+                }
+                else if ($links[$key]['type']=='payment_loan') {
+                    print '<a href="'.DOL_URL_ROOT.'/loan/payment/card.php?id='.$links[$key]['url_id'].'">';
+                    print img_object($langs->trans('ShowLoanPayment'),'payment').' ';
+                    print $langs->trans("PaymentLoan");
+                    print '</a>';
+                }
+                else if ($links[$key]['type']=='loan') {
+                    print '<a href="'.DOL_URL_ROOT.'/loan/card.php?id='.$links[$key]['url_id'].'">';
+                    print img_object($langs->trans('ShowLoan'),'bill').' ';
+                    print $langs->trans("Loan");
+                    print '</a>';
+                }
                 else if ($links[$key]['type']=='member') {
-                    print '<a href="'.DOL_URL_ROOT.'/adherents/fiche.php?rowid='.$links[$key]['url_id'].'">';
+                    print '<a href="'.DOL_URL_ROOT.'/adherents/card.php?rowid='.$links[$key]['url_id'].'">';
                     print img_object($langs->trans('ShowMember'),'user').' ';
                     print $links[$key]['label'];
                     print '</a>';
+                }
+				else if ($links[$key]['type']=='payment_donation') {
+                    print '<a href="'.DOL_URL_ROOT.'/don/payment/card.php?id='.$links[$key]['url_id'].'">';
+                    print img_object($langs->trans('ShowDonation'),'payment').' ';
+                    print $langs->trans("DonationPayment");
+                    print '</a>';
                 }
                 else if ($links[$key]['type']=='banktransfert') {
                     print '<a href="'.DOL_URL_ROOT.'/compta/bank/ligne.php?rowid='.$links[$key]['url_id'].'">';
@@ -353,6 +369,12 @@ if ($result)
                     print $langs->trans("TransactionOnTheOtherAccount");
                     print '</a>';
                 }
+                else if ($links[$key]['type']=='user') {
+                    print '<a href="'.DOL_URL_ROOT.'/user/card.php?id='.$links[$key]['url_id'].'">';
+                    print img_object($langs->trans('ShowUser'),'user').' ';
+                    print $langs->trans("User");
+                    print '</a>';
+                }
                 else {
                     print '<a href="'.$links[$key]['url'].$links[$key]['url_id'].'">';
                     print img_object('','generic').' ';
@@ -363,8 +385,6 @@ if ($result)
             print '</td></tr>';
         }
 
-        $rowspan=0;
-
         //$user->rights->banque->modifier=false;
         //$user->rights->banque->consolidate=true;
 
@@ -373,8 +393,8 @@ if ($result)
         print "</td>";
         if ($user->rights->banque->modifier || $user->rights->banque->consolidate)
         {
-            print '<td colspan="3">';
-            print $form->select_types_paiements($objp->fk_type,"value",'',2);
+            print '<td>';
+            $form->select_types_paiements($objp->fk_type,"value",'',2);
             print '<input type="text" class="flat" name="num_chq" value="'.(empty($objp->num_chq) ? '' : $objp->num_chq).'">';
             if ($objp->receiptid)
             {
@@ -385,13 +405,10 @@ if ($result)
 
             }
             print '</td>';
-            $rowspan=7;
-            print '<td align="center" rowspan="'.$rowspan.'" width="20%"><input type="submit" class="button" value="'.$langs->trans("Update").'">';
-            print '</td>';
         }
         else
         {
-            print '<td colspan="4">'.$objp->fk_type.' '.$objp->num_chq.'</td>';
+            print '<td>'.$objp->fk_type.' '.$objp->num_chq.'</td>';
         }
         print "</tr>";
 
@@ -399,13 +416,13 @@ if ($result)
         print "<tr><td>".$langs->trans("Bank")."</td>";
         if ($user->rights->banque->modifier || $user->rights->banque->consolidate)
         {
-            print '<td colspan="3">';
+            print '<td>';
             print '<input type="text" class="flat" size="40" name="banque" value="'.(empty($objp->banque) ? '' : $objp->banque).'">';
             print '</td>';
         }
         else
         {
-            print '<td colspan="'.($rowspan?'3':'4').'">'.$objp->banque.'</td>';
+            print '<td>'.$objp->banque.'</td>';
         }
         print "</tr>";
 
@@ -413,13 +430,13 @@ if ($result)
         print "<tr><td>".$langs->trans("CheckTransmitter")."</td>";
         if ($user->rights->banque->modifier || $user->rights->banque->consolidate)
         {
-            print '<td colspan="3">';
+            print '<td>';
             print '<input type="text" class="flat" size="40" name="emetteur" value="'.(empty($objp->emetteur) ? '' : stripslashes($objp->emetteur)).'">';
             print '</td>';
         }
         else
         {
-            print '<td colspan="'.($rowspan?'3':'4').'">'.$objp->emetteur.'</td>';
+            print '<td>'.$objp->emetteur.'</td>';
         }
         print "</tr>";
 
@@ -427,13 +444,13 @@ if ($result)
         print '<tr><td>'.$langs->trans("DateOperation").'</td>';
         if ($user->rights->banque->modifier || $user->rights->banque->consolidate)
         {
-            print '<td colspan="3">';
+            print '<td>';
             print $form->select_date($db->jdate($objp->do),'dateo','','','','update',1,0,1,$objp->rappro);
             print '</td>';
         }
         else
         {
-            print '<td colspan="'.($rowspan?'3':'4').'">';
+            print '<td>';
             print dol_print_date($db->jdate($objp->do),"day");
             print '</td>';
         }
@@ -443,7 +460,7 @@ if ($result)
         print "<tr><td>".$langs->trans("DateValue")."</td>";
         if ($user->rights->banque->modifier || $user->rights->banque->consolidate)
         {
-            print '<td colspan="3">';
+            print '<td>';
             print $form->select_date($db->jdate($objp->dv),'datev','','','','update',1,0,1,$objp->rappro);
             if (! $objp->rappro)
             {
@@ -457,7 +474,7 @@ if ($result)
         }
         else
         {
-            print '<td colspan="'.($rowspan?'3':'4').'">';
+            print '<td>';
             print dol_print_date($db->jdate($objp->dv),"day");
             print '</td>';
         }
@@ -467,8 +484,8 @@ if ($result)
         print "<tr><td>".$langs->trans("Label")."</td>";
         if ($user->rights->banque->modifier || $user->rights->banque->consolidate)
         {
-            print '<td colspan="3">';
-            print '<input name="label" class="flat" '.($objp->rappro?' disabled="disabled"':'').' value="';
+            print '<td>';
+            print '<input name="label" class="flat" '.($objp->rappro?' disabled':'').' value="';
             if (preg_match('/^\((.*)\)$/i',$objp->label,$reg))
             {
                 // Label generique car entre parentheses. On l'affiche en le traduisant
@@ -483,7 +500,7 @@ if ($result)
         }
         else
         {
-            print '<td colspan="'.($rowspan?'3':'4').'">';
+            print '<td>';
             if (preg_match('/^\((.*)\)$/i',$objp->label,$reg))
             {
                 // Label generique car entre parentheses. On l'affiche en le traduisant
@@ -501,26 +518,29 @@ if ($result)
         print "<tr><td>".$langs->trans("Amount")."</td>";
         if ($user->rights->banque->modifier)
         {
-            print '<td colspan="3">';
-            print '<input name="amount" class="flat" size="10" '.($objp->rappro?' disabled="disabled"':'').' value="'.price($objp->amount).'"> '.$langs->trans("Currency".$conf->currency);
+            print '<td>';
+            print '<input name="amount" class="flat" size="10" '.($objp->rappro?' disabled':'').' value="'.price($objp->amount).'"> '.$langs->trans("Currency".$acct->currency_code);
             print '</td>';
         }
         else
         {
-            print '<td colspan="'.($rowspan?'3':'4').'">';
+            print '<td>';
             print price($objp->amount);
             print '</td>';
         }
         print "</tr>";
 
         print "</table>";
+
+        print '<br><div class="center"><input type="submit" class="button" value="'.$langs->trans("Update").'"></div>';
+
         print "</form>";
 
         // Releve rappro
         if ($acct->canBeConciliated() > 0)  // Si compte rapprochable
         {
             print '<br>'."\n";
-            print_fiche_titre($langs->trans("Reconciliation"),'','');
+            print load_fiche_titre($langs->trans("Reconciliation"), '', 'title_bank.png');
             print '<form method="POST" action="'.$_SERVER['PHP_SELF'].'?rowid='.$objp->rowid.'">';
             print '<input type="hidden" name="token" value="'.$_SESSION['newtoken'].'">';
             print '<input type="hidden" name="action" value="setreconcile">';
@@ -528,43 +548,45 @@ if ($result)
 
             print '<table class="border" width="100%">';
 
-            print '<tr><td width="20%">'.$langs->trans("Conciliation")."</td>";
+            print '<tr><td class="titlefield">'.$langs->trans("Conciliation")."</td>";
             if ($user->rights->banque->consolidate)
             {
-                print '<td colspan="3">';
+                print '<td>';
                 if ($objp->rappro)
                 {
-                    print $langs->trans("AccountStatement").' <input name="num_rel_bis" class="flat" value="'.$objp->num_releve.'"'.($objp->rappro?' disabled="disabled"':'').'>';
+                    print $langs->trans("AccountStatement").' <input name="num_rel_bis" class="flat" value="'.$objp->num_releve.'"'.($objp->rappro?' disabled':'').'>';
                     print '<input name="num_rel" type="hidden" value="'.$objp->num_releve.'">';
                 }
                 else
                 {
-                    print $langs->trans("AccountStatement").' <input name="num_rel" class="flat" value="'.$objp->num_releve.'"'.($objp->rappro?' disabled="disabled"':'').'>';
+                    print $langs->trans("AccountStatement").' <input name="num_rel" class="flat" value="'.$objp->num_releve.'"'.($objp->rappro?' disabled':'').'>';
                 }
                 if ($objp->num_releve) print ' &nbsp; (<a href="'.DOL_URL_ROOT.'/compta/bank/releve.php?num='.$objp->num_releve.'&account='.$acct->id.'">'.$langs->trans("AccountStatement").' '.$objp->num_releve.')</a>';
-                print '</td><td align="center" rowspan="2" width="20%"><input type="submit" class="button" value="'.$langs->trans("Update").'"></td>';
+                print '</td>';
             }
             else
             {
-                print '<td colspan="4">'.$objp->num_releve.'&nbsp;</td>';
+                print '<td>'.$objp->num_releve.'&nbsp;</td>';
             }
             print '</tr>';
 
             print "<tr><td>".$langs->trans("BankLineConciliated")."</td>";
             if ($user->rights->banque->consolidate)
             {
-                print '<td colspan="3">';
+                print '<td>';
                 print '<input type="checkbox" name="reconciled" class="flat" '.(isset($_POST["reconciled"])?($_POST["reconciled"]?' checked="checked"':''):($objp->rappro?' checked="checked"':'')).'">';
                 print '</td>';
             }
             else
             {
-                print '<td colspan="4">'.yn($objp->rappro).'</td>';
+                print '<td>'.yn($objp->rappro).'</td>';
             }
             print '</tr>';
+            print '</table>';
 
-            print "</table>";
-            print '</form>';
+			print '<br><div class="center"><input type="submit" class="button" value="'.$langs->trans("Update").'"></div>';
+
+			print '</form>';
         }
 
     }
@@ -577,22 +599,21 @@ print '</div>';
 
 
 // List of bank categories
-
 print '<br>';
-print '<table class="noborder" width="100%">';
 
 print '<form method="POST" action="'.$_SERVER['PHP_SELF'].'?rowid='.$rowid.'&amp;id='.$id.'">';
 print '<input type="hidden" name="token" value="'.$_SESSION['newtoken'].'">';
 print '<input type="hidden" name="action" value="class">';
 print '<input type="hidden" name="orig_account" value="'.$orig_account.'">';
+
+print '<table class="noborder" width="100%">';
 print '<tr class="liste_titre"><td>'.$langs->trans("Rubriques").'</td><td colspan="2">';
 if ($user->rights->banque->modifier)
 {
-    print '<select class="flat" name="cat1">'.$options.'</select>&nbsp;';
+    print Form::selectarray('cat1', $options, '', 1).' ';
     print '<input type="submit" class="button" value="'.$langs->trans("Add").'"></td>';
 }
-print "</tr>";
-print "</form>";
+print '</tr>';
 
 $sql = "SELECT c.label, c.rowid";
 $sql.= " FROM ".MAIN_DB_PREFIX."bank_class as a, ".MAIN_DB_PREFIX."bank_categ as c";
@@ -617,15 +638,14 @@ if ($result)
         {
             print '<td align="right"><a href="'.$_SERVER['PHP_SELF'].'?action=delete_categ&amp;rowid='.$rowid.'&amp;fk_categ='.$objp->rowid.'">'.img_delete($langs->trans("Remove")).'</a></td>';
         }
-        print "</tr>";
+        print '</tr>';
 
         $i++;
     }
     $db->free($result);
 }
-print "</table>";
+print '</table></form>';
 
 llxFooter();
 
 $db->close();
-?>
