@@ -29,11 +29,7 @@ if (!$user->admin && $user->societe_id > 0)
 
 llxHeader();
 
-print_fiche_titre("Payments");
-
-
-
-$db->close();
+print load_fiche_titre("Payments");
 
 llxFooter();
-?>
+$db->close();
