@@ -2,6 +2,11 @@
 /* Copyright (C) 2002-2006 Rodolphe Quiedeville <rodolphe@quiedeville.org>
  * Copyright (C) 2004-2011 Laurent Destailleur  <eldy@users.sourceforge.net>
  * Copyright (C) 2005-2012 Regis Houssin        <regis.houssin@capnetworks.com>
+ * Copyright (C) 2012      Cédric Salvador      <csalvador@gpcsolutions.fr>
+ * Copyright (C) 2012-2014 Raphaël Dourseanud   <rdoursenaud@gpcsolutions.fr>
+ * Copyright (C) 2014-2106 Ferran Marcet        <fmarcet@2byte.es>
+ * Copyright (C) 2014	   Juanjo Menent        <jmenent@2byte.es>
+ * Copyright (C) 2014	   Florian Henry        <florian.henry@open-concept.pro>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -31,6 +36,8 @@ require_once DOL_DOCUMENT_ROOT.'/core/lib/date.lib.php';
 
 
 $langs->load("bills");
+$langs->load("donation");
+$langs->load("salaries");
 
 $date_startmonth=GETPOST('date_startmonth');
 $date_startday=GETPOST('date_startday');
@@ -45,6 +52,17 @@ if ($user->societe_id > 0) $socid = $user->societe_id;
 if (! empty($conf->comptabilite->enabled)) $result=restrictedArea($user,'compta','','','resultat');
 if (! empty($conf->accounting->enabled)) $result=restrictedArea($user,'accounting','','','comptarapport');
 
+$limit = GETPOST("limit")?GETPOST("limit","int"):$conf->liste_limit;
+$sortfield = GETPOST("sortfield",'alpha');
+$sortorder = GETPOST("sortorder",'alpha');
+$page = GETPOST("page",'int');
+if ($page == -1) { $page = 0; }
+$offset = $limit * $page;
+$pageprev = $page - 1;
+$pagenext = $page + 1;
+if (! $sortfield) $sortfield='s.nom, s.rowid';
+if (! $sortorder) $sortorder='ASC';
+
 // Date range
 $year=GETPOST("year");
 if (empty($year))
@@ -94,7 +112,7 @@ else
 }
 
 // Define modecompta ('CREANCES-DETTES' or 'RECETTES-DEPENSES')
-$modecompta=(GETPOST("modecompta")?GETPOST("modecompta"):$conf->global->COMPTA_MODE);
+$modecompta=(GETPOST("modecompta")?GETPOST("modecompta"):$conf->global->ACCOUNTING_MODE);
 
 
 /*
@@ -115,7 +133,7 @@ $total_ttc=0;
 // Affiche en-tete de rapport
 if ($modecompta=="CREANCES-DETTES")
 {
-    $nom=$langs->trans("AnnualByCompaniesDueDebtMode");
+    $name=$langs->trans("AnnualByCompaniesDueDebtMode");
 	$calcmode=$langs->trans("CalcModeDebt");
     $calcmode.='<br>('.$langs->trans("SeeReportInInputOutputMode",'<a href="'.$_SERVER["PHP_SELF"].'?year='.$year.(GETPOST("month")>0?'&month='.GETPOST("month"):'').'&modecompta=RECETTES-DEPENSES">','</a>').')';
     $period=$form->select_date($date_start,'date_start',0,0,0,'',1,0,1).' - '.$form->select_date($date_end,'date_end',0,0,0,'',1,0,1);
@@ -127,7 +145,7 @@ if ($modecompta=="CREANCES-DETTES")
     //$exportlink=$langs->trans("NotYetAvailable");
 }
 else {
-    $nom=$langs->trans("AnnualByCompaniesInputOutputMode");
+    $name=$langs->trans("AnnualByCompaniesInputOutputMode");
 	$calcmode=$langs->trans("CalcModeEngagement");
     $calcmode.='<br>('.$langs->trans("SeeReportInDueDebtMode",'<a href="'.$_SERVER["PHP_SELF"].'?year='.$year.(GETPOST("month")>0?'&month='.GETPOST("month"):'').'&modecompta=CREANCES-DETTES">','</a>').')';
     //$period=$form->select_date($date_start,'date_start',0,0,0,'',1,0,1).' - '.$form->select_date($date_end,'date_end',1,1,0,'',1,0,1);
@@ -137,15 +155,34 @@ else {
     $builddate=time();
     //$exportlink=$langs->trans("NotYetAvailable");
 }
-report_header($nom,$nomlink,$period,$periodlink,$description,$builddate,$exportlink,array('modecompta'=>$modecompta),$calcmode);
+
+$hselected = 'report';
+
+report_header($name,$nomlink,$period,$periodlink,$description,$builddate,$exportlink,array('modecompta'=>$modecompta),$calcmode);
+
+if (! empty($conf->accounting->enabled))
+{
+    print info_admin($langs->trans("WarningReportNotReliable"), 0, 0, 1);
+}
 
 // Show report array
+$param='&modecompta='.$modecompta;
+if ($date_startday) $param.='&date_startday='.$date_startday;
+if ($date_startmonth) $param.='&date_startmonth='.$date_startmonth;
+if ($date_startyear) $param.='&date_startyear='.$date_startyear;
+if ($date_endday) $param.='&date_endday='.$date_endday;
+if ($date_endmonth) $param.='&date_endmonth='.$date_endmonth;
+if ($date_endyear) $param.='&date_endyear='.$date_startyear;
+
 print '<table class="noborder" width="100%">';
 print '<tr class="liste_titre">';
-print '<td width="10%">&nbsp;</td><td>&nbsp;</td>';
+print_liste_field_titre('');
+print_liste_field_titre($langs->trans("Name"), $_SERVER["PHP_SELF"],'s.nom, s.rowid','',$param,'',$sortfield,$sortorder);
 if ($modecompta == 'CREANCES-DETTES')
-	print "<td align=\"right\">".$langs->trans("AmountHT")."</td>";
-print "<td align=\"right\">".$langs->trans("AmountTTC")."</td>";
+{
+	print_liste_field_titre($langs->trans("AmountHT"), $_SERVER["PHP_SELF"],'amount_ht','',$param,'align="right"',$sortfield,$sortorder);
+}
+print_liste_field_titre($langs->trans("AmountTTC"), $_SERVER["PHP_SELF"],'amount_ttc','',$param,'align="right"',$sortfield,$sortorder);
 print "</tr>\n";
 
 /*
@@ -155,15 +192,15 @@ print '<tr><td colspan="4">'.$langs->trans("CustomersInvoices").'</td></tr>';
 
 if ($modecompta == 'CREANCES-DETTES')
 {
-    $sql = "SELECT s.nom, s.rowid as socid, sum(f.total) as amount_ht, sum(f.total_ttc) as amount_ttc";
+    $sql = "SELECT s.nom as name, s.rowid as socid, sum(f.total) as amount_ht, sum(f.total_ttc) as amount_ttc";
     $sql.= " FROM ".MAIN_DB_PREFIX."societe as s";
     $sql.= ", ".MAIN_DB_PREFIX."facture as f";
     $sql.= " WHERE f.fk_soc = s.rowid";
     $sql.= " AND f.fk_statut IN (1,2)";
     if (! empty($conf->global->FACTURE_DEPOSITS_ARE_JUST_PAYMENTS))
-    	$sql.= " AND f.type IN (0,1,2)";
+    	$sql.= " AND f.type IN (0,1,2,5)";
 	else
-		$sql.= " AND f.type IN (0,1,2,3)";
+		$sql.= " AND f.type IN (0,1,2,3,5)";
     if (! empty($date_start) && ! empty($date_end))
     	$sql.= " AND f.datef >= '".$db->idate($date_start)."' AND f.datef <= '".$db->idate($date_end)."'";
 }
@@ -173,7 +210,7 @@ else
      * Liste des paiements (les anciens paiements ne sont pas vus par cette requete car, sur les
      * vieilles versions, ils n'etaient pas lies via paiement_facture. On les ajoute plus loin)
      */
-    $sql = "SELECT s.nom as nom, s.rowid as socid, sum(pf.amount) as amount_ttc";
+    $sql = "SELECT s.nom as name, s.rowid as socid, sum(pf.amount) as amount_ttc";
     $sql.= " FROM ".MAIN_DB_PREFIX."societe as s";
     $sql.= ", ".MAIN_DB_PREFIX."facture as f";
     $sql.= ", ".MAIN_DB_PREFIX."paiement_facture as pf";
@@ -187,9 +224,9 @@ else
 $sql.= " AND f.entity = ".$conf->entity;
 if ($socid) $sql.= " AND f.fk_soc = ".$socid;
 $sql.= " GROUP BY s.nom, s.rowid";
-$sql.= " ORDER BY s.nom, s.rowid";
+$sql.= $db->order($sortfield, $sortorder);
 
-dol_syslog("get customer invoices sql=".$sql);
+dol_syslog("get customer invoices", LOG_DEBUG);
 $result = $db->query($sql);
 if ($result) {
     $num = $db->num_rows($result);
@@ -201,7 +238,7 @@ if ($result) {
         $var=!$var;
 
         print "<tr ".$bc[$var]."><td>&nbsp;</td>";
-        print "<td>".$langs->trans("Bills").' <a href="'.DOL_URL_ROOT.'/compta/facture/list.php?socid='.$objp->socid.'">'.$objp->nom."</td>\n";
+        print "<td>".$langs->trans("Bills").' <a href="'.DOL_URL_ROOT.'/compta/facture/list.php?socid='.$objp->socid.'">'.$objp->name."</td>\n";
 
         if ($modecompta == 'CREANCES-DETTES')
         	print "<td align=\"right\">".price($objp->amount_ht)."</td>\n";
@@ -220,7 +257,7 @@ if ($result) {
 // On ajoute les paiements clients anciennes version, non lie par paiement_facture
 if ($modecompta != 'CREANCES-DETTES')
 {
-    $sql = "SELECT 'Autres' as nom, '0' as idp, sum(p.amount) as amount_ttc";
+    $sql = "SELECT 'Autres' as name, '0' as idp, sum(p.amount) as amount_ttc";
     $sql.= " FROM ".MAIN_DB_PREFIX."bank as b";
     $sql.= ", ".MAIN_DB_PREFIX."bank_account as ba";
     $sql.= ", ".MAIN_DB_PREFIX."paiement as p";
@@ -228,13 +265,13 @@ if ($modecompta != 'CREANCES-DETTES')
     $sql.= " WHERE pf.rowid IS NULL";
     $sql.= " AND p.fk_bank = b.rowid";
     $sql.= " AND b.fk_account = ba.rowid";
-    $sql.= " AND ba.entity = ".$conf->entity;
+    $sql.= " AND ba.entity IN (".getEntity('bank_account', 1).")";
     if (! empty($date_start) && ! empty($date_end))
     	$sql.= " AND p.datep >= '".$db->idate($date_start)."' AND p.datep <= '".$db->idate($date_end)."'";
-    $sql.= " GROUP BY nom, idp";
-    $sql.= " ORDER BY nom";
+    $sql.= " GROUP BY name, idp";
+    $sql.= " ORDER BY name";
 
-    dol_syslog("get old customer payments not linked to invoices sql=".$sql);
+    dol_syslog("get old customer payments not linked to invoices", LOG_DEBUG);
     $result = $db->query($sql);
     if ($result) {
         $num = $db->num_rows($result);
@@ -269,7 +306,7 @@ if ($total_ttc == 0)
 {
     $var=!$var;
     print "<tr ".$bc[$var]."><td>&nbsp;</td>";
-    print '<td colspan="3">'.$langs->trans("None").'</td>';
+    print '<td colspan="3" class="opacitymedium">'.$langs->trans("None").'</td>';
     print '</tr>';
 }
 
@@ -285,7 +322,7 @@ print '</tr>';
  */
 if ($modecompta == 'CREANCES-DETTES')
 {
-    $sql = "SELECT s.nom, s.rowid as socid, sum(f.total_ht) as amount_ht, sum(f.total_ttc) as amount_ttc";
+    $sql = "SELECT s.nom as name, s.rowid as socid, sum(f.total_ht) as amount_ht, sum(f.total_ttc) as amount_ttc";
     $sql.= " FROM ".MAIN_DB_PREFIX."societe as s";
     $sql.= ", ".MAIN_DB_PREFIX."facture_fourn as f";
     $sql.= " WHERE f.fk_soc = s.rowid";
@@ -299,7 +336,7 @@ if ($modecompta == 'CREANCES-DETTES')
 }
 else
 {
-    $sql = "SELECT s.nom, s.rowid as socid, sum(pf.amount) as amount_ttc";
+    $sql = "SELECT s.nom as name, s.rowid as socid, sum(pf.amount) as amount_ttc";
     $sql.= " FROM ".MAIN_DB_PREFIX."paiementfourn as p";
     $sql.= ", ".MAIN_DB_PREFIX."paiementfourn_facturefourn as pf";
     $sql.= " LEFT JOIN ".MAIN_DB_PREFIX."facture_fourn as f";
@@ -313,13 +350,13 @@ else
 $sql.= " AND f.entity = ".$conf->entity;
 if ($socid) $sql.= " AND f.fk_soc = ".$socid;
 $sql .= " GROUP BY s.nom, s.rowid";
-$sql .= " ORDER BY s.nom, s.rowid";
+$sql.= $db->order($sortfield, $sortorder);
 
 print '<tr><td colspan="4">'.$langs->trans("SuppliersInvoices").'</td></tr>';
 
 $subtotal_ht = 0;
 $subtotal_ttc = 0;
-dol_syslog("get suppliers invoices sql=".$sql);
+dol_syslog("get suppliers invoices", LOG_DEBUG);
 $result = $db->query($sql);
 if ($result) {
     $num = $db->num_rows($result);
@@ -333,7 +370,7 @@ if ($result) {
             $var=!$var;
 
             print "<tr ".$bc[$var]."><td>&nbsp;</td>";
-            print "<td>".$langs->trans("Bills")." <a href=\"".DOL_URL_ROOT."/fourn/facture/list.php?socid=".$objp->socid."\">".$objp->nom."</a></td>\n";
+            print "<td>".$langs->trans("Bills")." <a href=\"".DOL_URL_ROOT."/fourn/facture/list.php?socid=".$objp->socid."\">".$objp->name."</a></td>\n";
 
             if ($modecompta == 'CREANCES-DETTES')
             	print "<td align=\"right\">".price(-$objp->amount_ht)."</td>\n";
@@ -352,7 +389,7 @@ if ($result) {
     {
         $var=!$var;
         print "<tr ".$bc[$var]."><td>&nbsp;</td>";
-        print '<td colspan="3">'.$langs->trans("None").'</td>';
+        print '<td colspan="3" class="opacitymedium">'.$langs->trans("None").'</td>';
         print '</tr>';
     }
 
@@ -372,11 +409,11 @@ print '</tr>';
  * Charges sociales non deductibles
  */
 
-print '<tr><td colspan="4">'.$langs->trans("SocialContributions").' ('.$langs->trans("Type").' 0)</td></tr>';
+print '<tr><td colspan="4">'.$langs->trans("SocialContributionsNondeductibles").'</td></tr>';
 
 if ($modecompta == 'CREANCES-DETTES')
 {
-    $sql = "SELECT c.id, c.libelle as nom, sum(cs.amount) as amount";
+    $sql = "SELECT c.id, c.libelle as label, sum(cs.amount) as amount";
     $sql.= " FROM ".MAIN_DB_PREFIX."c_chargesociales as c";
     $sql.= ", ".MAIN_DB_PREFIX."chargesociales as cs";
     $sql.= " WHERE cs.fk_type = c.id";
@@ -386,7 +423,7 @@ if ($modecompta == 'CREANCES-DETTES')
 }
 else
 {
-    $sql = "SELECT c.id, c.libelle as nom, sum(p.amount) as amount";
+    $sql = "SELECT c.id, c.libelle as label, sum(p.amount) as amount";
     $sql.= " FROM ".MAIN_DB_PREFIX."c_chargesociales as c";
     $sql.= ", ".MAIN_DB_PREFIX."chargesociales as cs";
     $sql.= ", ".MAIN_DB_PREFIX."paiementcharge as p";
@@ -398,9 +435,13 @@ else
 }
 $sql.= " AND cs.entity = ".$conf->entity;
 $sql.= " GROUP BY c.libelle, c.id";
-$sql.= " ORDER BY c.libelle, c.id";
+$newsortfield = $sortfield;
+if ($newsortfield == 's.nom, s.rowid') $newsortfield = 'c.libelle, c.id';
+if ($newsortfield == 'amount_ht') $newsortfield = 'amount';
+if ($newsortfield == 'amount_ttc') $newsortfield = 'amount';
+$sql.= $db->order($newsortfield, $sortorder);
 
-dol_syslog("get social contributions deductible=0 sql=".$sql);
+dol_syslog("get social contributions deductible=0", LOG_DEBUG);
 $result=$db->query($sql);
 $subtotal_ht = 0;
 $subtotal_ttc = 0;
@@ -419,7 +460,7 @@ if ($result) {
 
             $var = !$var;
             print "<tr ".$bc[$var]."><td>&nbsp;</td>";
-            print '<td>'.$obj->nom.'</td>';
+            print '<td>'.$obj->label.'</td>';
             if ($modecompta == 'CREANCES-DETTES') print '<td align="right">'.price(-$obj->amount).'</td>';
             print '<td align="right">'.price(-$obj->amount).'</td>';
             print '</tr>';
@@ -429,7 +470,7 @@ if ($result) {
     else {
         $var = !$var;
         print "<tr ".$bc[$var]."><td>&nbsp;</td>";
-        print '<td colspan="3">'.$langs->trans("None").'</td>';
+        print '<td colspan="3" class="opacitymedium">'.$langs->trans("None").'</td>';
         print '</tr>';
     }
 } else {
@@ -446,11 +487,11 @@ print '</tr>';
  * Charges sociales deductibles
  */
 
-print '<tr><td colspan="4">'.$langs->trans("SocialContributions").' ('.$langs->trans("Type").' 1)</td></tr>';
+print '<tr><td colspan="4">'.$langs->trans("SocialContributionsDeductibles").'</td></tr>';
 
 if ($modecompta == 'CREANCES-DETTES')
 {
-    $sql = "SELECT c.id, c.libelle as nom, sum(cs.amount) as amount";
+    $sql = "SELECT c.id, c.libelle as label, sum(cs.amount) as amount";
     $sql.= " FROM ".MAIN_DB_PREFIX."c_chargesociales as c";
     $sql.= ", ".MAIN_DB_PREFIX."chargesociales as cs";
     $sql.= " WHERE cs.fk_type = c.id";
@@ -458,12 +499,10 @@ if ($modecompta == 'CREANCES-DETTES')
     if (! empty($date_start) && ! empty($date_end))
     	$sql.= " AND cs.date_ech >= '".$db->idate($date_start)."' AND cs.date_ech <= '".$db->idate($date_end)."'";
     $sql.= " AND cs.entity = ".$conf->entity;
-    $sql.= " GROUP BY c.libelle, c.id";
-    $sql.= " ORDER BY c.libelle, c.id";
 }
 else
 {
-    $sql = "SELECT c.id, c.libelle as nom, sum(p.amount) as amount";
+    $sql = "SELECT c.id, c.libelle as label, sum(p.amount) as amount";
     $sql.= " FROM ".MAIN_DB_PREFIX."c_chargesociales as c";
     $sql.= ", ".MAIN_DB_PREFIX."chargesociales as cs";
     $sql.= ", ".MAIN_DB_PREFIX."paiementcharge as p";
@@ -473,11 +512,15 @@ else
     if (! empty($date_start) && ! empty($date_end))
     	$sql.= " AND p.datep >= '".$db->idate($date_start)."' AND p.datep <= '".$db->idate($date_end)."'";
     $sql.= " AND cs.entity = ".$conf->entity;
-    $sql.= " GROUP BY c.libelle, c.id";
-    $sql.= " ORDER BY c.libelle, c.id";
 }
+$sql.= " GROUP BY c.libelle, c.id";
+$newsortfield = $sortfield;
+if ($newsortfield == 's.nom, s.rowid') $newsortfield = 'c.libelle, c.id';
+if ($newsortfield == 'amount_ht') $newsortfield = 'amount';
+if ($newsortfield == 'amount_ttc') $newsortfield = 'amount';
+$sql.= $db->order($newsortfield, $sortorder);
 
-dol_syslog("get social contributions deductible=1 sql=".$sql);
+dol_syslog("get social contributions deductible=1", LOG_DEBUG);
 $result=$db->query($sql);
 $subtotal_ht = 0;
 $subtotal_ttc = 0;
@@ -496,7 +539,7 @@ if ($result) {
 
             $var = !$var;
             print "<tr ".$bc[$var]."><td>&nbsp;</td>";
-            print '<td>'.$obj->nom.'</td>';
+            print '<td>'.$obj->label.'</td>';
             if ($modecompta == 'CREANCES-DETTES')
             	print '<td align="right">'.price(-$obj->amount).'</td>';
             print '<td align="right">'.price(-$obj->amount).'</td>';
@@ -507,7 +550,7 @@ if ($result) {
     else {
         $var = !$var;
         print "<tr ".$bc[$var]."><td>&nbsp;</td>";
-        print '<td colspan="3">'.$langs->trans("None").'</td>';
+        print '<td colspan="3" class="opacitymedium">'.$langs->trans("None").'</td>';
         print '</tr>';
     }
 } else {
@@ -519,7 +562,7 @@ if ($modecompta == 'CREANCES-DETTES')
 print '<td colspan="3" align="right">'.price(-$subtotal_ttc).'</td>';
 print '</tr>';
 
-if ($mysoc->tva_assuj == 'franchise')	// Non assujeti
+if ($mysoc->tva_assuj == 'franchise')	// Non assujetti
 {
     // Total
     print '<tr>';
@@ -538,6 +581,250 @@ if ($mysoc->tva_assuj == 'franchise')	// Non assujeti
 }
 
 
+/*
+ * Salaries
+ */
+
+if (! empty($conf->salaries->enabled))
+{
+	if ($modecompta == 'CREANCES-DETTES') {
+	    $column = 'p.datev';
+	} else {
+	    $column = 'p.datep';
+	}
+
+	print '<tr><td colspan="4">'.$langs->trans("Salaries").'</td></tr>';    
+	$sql = "SELECT u.rowid, u.firstname, u.lastname, p.fk_user, p.label as label, date_format($column,'%Y-%m') as dm, sum(p.amount) as amount";
+	$sql.= " FROM ".MAIN_DB_PREFIX."payment_salary as p";
+	$sql.= " INNER JOIN ".MAIN_DB_PREFIX."user as u ON u.rowid=p.fk_user";
+	$sql.= " WHERE p.entity = ".$conf->entity;
+	if (! empty($date_start) && ! empty($date_end))
+		$sql.= " AND $column >= '".$db->idate($date_start)."' AND $column <= '".$db->idate($date_end)."'";
+
+	$sql.= " GROUP BY u.rowid, u.firstname, u.lastname, p.fk_user, p.label, dm";
+	$newsortfield = $sortfield;
+    if ($newsortfield == 's.nom, s.rowid') $newsortfield = 'u.firstname, u.lastname';
+    if ($newsortfield == 'amount_ht') $newsortfield = 'amount';
+    if ($newsortfield == 'amount_ttc') $newsortfield = 'amount';
+	$sql.= $db->order($newsortfield, $sortorder);
+	
+	dol_syslog("get payment salaries");
+	$result=$db->query($sql);
+	$subtotal_ht = 0;
+	$subtotal_ttc = 0;
+	if ($result)
+	{
+	    $num = $db->num_rows($result);
+	    $var=true;
+	    $i = 0;
+	    if ($num)
+	    {
+	        while ($i < $num)
+	        {
+	            $obj = $db->fetch_object($result);
+
+	            $total_ht -= $obj->amount;
+	            $total_ttc -= $obj->amount;
+	            $subtotal_ht += $obj->amount;
+	            $subtotal_ttc += $obj->amount;
+
+	            $var = !$var;
+	            print "<tr ".$bc[$var]."><td>&nbsp;</td>";
+
+	            print "<td>".$langs->trans("Salary")." <a href=\"".DOL_URL_ROOT."/compta/salaries/index.php?filtre=s.fk_user=".$obj->fk_user."\">".$obj->firstname." ".$obj->lastname."</a></td>\n";
+
+	            if ($modecompta == 'CREANCES-DETTES') print '<td align="right">'.price(-$obj->amount).'</td>';
+	            print '<td align="right">'.price(-$obj->amount).'</td>';
+	            print '</tr>';
+	            $i++;
+	        }
+	    }
+	    else
+	    {
+	        $var = !$var;
+	        print "<tr ".$bc[$var]."><td>&nbsp;</td>";
+	        print '<td colspan="3" class="opacitymedium">'.$langs->trans("None").'</td>';
+	        print '</tr>';
+	    }
+	}
+	else
+	{
+	    dol_print_error($db);
+	}
+	print '<tr class="liste_total">';
+	if ($modecompta == 'CREANCES-DETTES')
+		print '<td colspan="3" align="right">'.price(-$subtotal_ht).'</td>';
+	print '<td colspan="3" align="right">'.price(-$subtotal_ttc).'</td>';
+	print '</tr>';
+}
+
+/*
+ * Expense
+ */
+
+if (! empty($conf->expensereport->enabled))
+{
+	$langs->load('trips');
+	if ($modecompta == 'CREANCES-DETTES') {
+		$sql = "SELECT p.rowid, p.ref, u.rowid as userid, u.firstname, u.lastname, date_format(date_valid,'%Y-%m') as dm, sum(p.total_ht) as amount_ht,sum(p.total_ttc) as amount_ttc";
+		$sql.= " FROM ".MAIN_DB_PREFIX."expensereport as p";
+		$sql.= " INNER JOIN ".MAIN_DB_PREFIX."user as u ON u.rowid=p.fk_user_author";
+		$sql.= " WHERE p.entity = ".getEntity('expensereport',1);
+		$sql.= " AND p.fk_statut>=5";
+
+		$column='p.date_valid';
+	} else {
+		$sql = "SELECT p.rowid, p.ref, u.rowid as userid, u.firstname, u.lastname, date_format(pe.datep,'%Y-%m') as dm, sum(p.total_ht) as amount_ht, sum(p.total_ttc) as amount_ttc";
+		$sql.= " FROM ".MAIN_DB_PREFIX."expensereport as p";
+		$sql.= " INNER JOIN ".MAIN_DB_PREFIX."user as u ON u.rowid=p.fk_user_author";
+		$sql.= " INNER JOIN ".MAIN_DB_PREFIX."payment_expensereport as pe ON pe.fk_expensereport = p.rowid";
+		$sql.= " INNER JOIN ".MAIN_DB_PREFIX."c_paiement as c ON pe.fk_typepayment = c.id";
+		$sql.= " WHERE p.entity = ".getEntity('expensereport',1);
+		$sql.= " AND p.fk_statut>=5";
+
+		$column='pe.datep';
+	}
+
+	print '<tr><td colspan="4">'.$langs->trans("ExpenseReport").'</td></tr>';
+
+	if (! empty($date_start) && ! empty($date_end))
+	{
+		$sql.= " AND $column >= '".$db->idate($date_start)."' AND $column <= '".$db->idate($date_end)."'";
+	}
+	
+	$sql.= " GROUP BY u.rowid, p.rowid, p.ref, u.firstname, u.lastname, dm";
+    $newsortfield = $sortfield;
+    if ($newsortfield == 's.nom, s.rowid') $newsortfield = 'p.ref';
+    $sql.= $db->order($newsortfield, $sortorder);
+
+	dol_syslog("get expense report outcome");
+	$result=$db->query($sql);
+	$subtotal_ht = 0;
+	$subtotal_ttc = 0;
+	if ($result)
+	{
+		$num = $db->num_rows($result);
+		$var=true;
+		if ($num)
+		{
+			while ($obj = $db->fetch_object($result))
+			{
+				$total_ht -= $obj->amount_ht;
+				$total_ttc -= $obj->amount_ttc;
+				$subtotal_ht += $obj->amount_ht;
+				$subtotal_ttc += $obj->amount_ttc;
+
+				$var = !$var;
+				print "<tr ".$bc[$var]."><td>&nbsp;</td>";
+
+				print "<td>".$langs->trans("ExpenseReport")." <a href=\"".DOL_URL_ROOT."/expensereport/list.php?search_user=".$obj->userid."\">".$obj->firstname." ".$obj->lastname."</a></td>\n";
+
+				if ($modecompta == 'CREANCES-DETTES') print '<td align="right">'.price(-$obj->amount_ht).'</td>';
+				print '<td align="right">'.price(-$obj->amount_ttc).'</td>';
+				print '</tr>';
+			}
+		}
+		else
+		{
+			$var = !$var;
+			print "<tr ".$bc[$var]."><td>&nbsp;</td>";
+			print '<td colspan="3" class="opacitymedium">'.$langs->trans("None").'</td>';
+			print '</tr>';
+		}
+	}
+	else
+	{
+		dol_print_error($db);
+	}
+	print '<tr class="liste_total">';
+	if ($modecompta == 'CREANCES-DETTES')
+		print '<td colspan="3" align="right">'.price(-$subtotal_ht).'</td>';
+		print '<td colspan="3" align="right">'.price(-$subtotal_ttc).'</td>';
+		print '</tr>';
+}
+
+/*
+ * Donations
+ */
+
+if (! empty($conf->don->enabled))
+{
+	print '<tr><td colspan="4">'.$langs->trans("Donations").'</td></tr>';
+	if ($modecompta == 'CREANCES-DETTES')
+	{
+    	$sql = "SELECT p.societe as name, p.firstname, p.lastname, date_format(p.datedon,'%Y-%m') as dm, sum(p.amount) as amount";
+    	$sql.= " FROM ".MAIN_DB_PREFIX."don as p";
+    	$sql.= " WHERE p.entity = ".$conf->entity;
+    	$sql.= " AND fk_statut in (1,2)";
+	}
+	else
+	{
+	    $sql = "SELECT p.societe as nom, p.firstname, p.lastname, date_format(p.datedon,'%Y-%m') as dm, sum(p.amount) as amount";
+	    $sql.= " FROM ".MAIN_DB_PREFIX."don as p";
+	    $sql.= " INNER JOIN ".MAIN_DB_PREFIX."payment_donation as pe ON pe.fk_donation = p.rowid";
+	    $sql.= " INNER JOIN ".MAIN_DB_PREFIX."c_paiement as c ON pe.fk_typepayment = c.id";
+	    $sql.= " WHERE p.entity = ".getEntity('donation',1);
+	    $sql.= " AND fk_statut >= 2";	 
+	}
+	if (! empty($date_start) && ! empty($date_end))
+		$sql.= " AND p.datedon >= '".$db->idate($date_start)."' AND p.datedon <= '".$db->idate($date_end)."'";
+	$sql.= " GROUP BY p.societe, p.firstname, p.lastname, dm";
+    $newsortfield = $sortfield;
+    if ($newsortfield == 's.nom, s.rowid') $newsortfield = 'p.societe, p.firstname, p.lastname, dm';
+    if ($newsortfield == 'amount_ht') $newsortfield = 'amount';
+    if ($newsortfield == 'amount_ttc') $newsortfield = 'amount';
+    $sql.= $db->order($newsortfield, $sortorder);
+
+	dol_syslog("get dunning");
+	$result=$db->query($sql);
+	$subtotal_ht = 0;
+	$subtotal_ttc = 0;
+	if ($result)
+	{
+		$num = $db->num_rows($result);
+		$var=true;
+		$i = 0;
+		if ($num)
+		{
+			while ($i < $num)
+			{
+				$obj = $db->fetch_object($result);
+
+				$total_ht += $obj->amount;
+				$total_ttc += $obj->amount;
+				$subtotal_ht += $obj->amount;
+				$subtotal_ttc += $obj->amount;
+
+				$var = !$var;
+				print "<tr ".$bc[$var]."><td>&nbsp;</td>";
+
+				print "<td>".$langs->trans("Donation")." <a href=\"".DOL_URL_ROOT."/don/list.php?search_company=".$obj->name."&search_name=".$obj->firstname." ".$obj->lastname."\">".$obj->name. " ".$obj->firstname." ".$obj->lastname."</a></td>\n";
+
+				if ($modecompta == 'CREANCES-DETTES') print '<td align="right">'.price($obj->amount).'</td>';
+				print '<td align="right">'.price($obj->amount).'</td>';
+				print '</tr>';
+				$i++;
+			}
+		}
+		else
+		{
+			$var = !$var;
+			print "<tr ".$bc[$var]."><td>&nbsp;</td>";
+			print '<td colspan="3" class="opacitymedium">'.$langs->trans("None").'</td>';
+			print '</tr>';
+		}
+	}
+	else
+	{
+		dol_print_error($db);
+	}
+	print '<tr class="liste_total">';
+	if ($modecompta == 'CREANCES-DETTES')
+		print '<td colspan="3" align="right">'.price($subtotal_ht).'</td>';
+	print '<td colspan="3" align="right">'.price($subtotal_ttc).'</td>';
+	print '</tr>';
+}
+
 /*
  * VAT
  */
@@ -554,16 +841,20 @@ if ($modecompta == 'CREANCES-DETTES')
     $sql.= " FROM ".MAIN_DB_PREFIX."facture as f";
     $sql.= " WHERE f.fk_statut IN (1,2)";
     if (! empty($conf->global->FACTURE_DEPOSITS_ARE_JUST_PAYMENTS))
-    	$sql.= " AND f.type IN (0,1,2)";
+    	$sql.= " AND f.type IN (0,1,2,5)";
 	else
-		$sql.= " AND f.type IN (0,1,2,3)";
+		$sql.= " AND f.type IN (0,1,2,3,5)";
     if (! empty($date_start) && ! empty($date_end))
     	$sql.= " AND f.datef >= '".$db->idate($date_start)."' AND f.datef <= '".$db->idate($date_end)."'";
     $sql.= " AND f.entity = ".$conf->entity;
     $sql.= " GROUP BY dm";
-    $sql.= " ORDER BY dm";
+    $newsortfield = $sortfield;
+    if ($newsortfield == 's.nom, s.rowid') $newsortfield = 'dm';
+    if ($newsortfield == 'amount_ht') $newsortfield = 'amount';
+    if ($newsortfield == 'amount_ttc') $newsortfield = 'amount';
+    $sql.= $db->order($newsortfield, $sortorder);
 
-    dol_syslog("get vat to pay sql=".$sql);
+    dol_syslog("get vat to pay", LOG_DEBUG);
     $result=$db->query($sql);
     if ($result)
     {
@@ -606,9 +897,13 @@ if ($modecompta == 'CREANCES-DETTES')
     	$sql.= " AND f.datef >= '".$db->idate($date_start)."' AND f.datef <= '".$db->idate($date_end)."'";
     $sql.= " AND f.entity = ".$conf->entity;
     $sql.= " GROUP BY dm";
-    $sql.= " ORDER BY dm";
+    $newsortfield = $sortfield;
+    if ($newsortfield == 's.nom, s.rowid') $newsortfield = 'dm';
+    if ($newsortfield == 'amount_ht') $newsortfield = 'amount';
+    if ($newsortfield == 'amount_ttc') $newsortfield = 'amount';
+    $sql.= $db->order($newsortfield, $sortorder);
 
-    dol_syslog("get vat received back sql=".$sql);
+    dol_syslog("get vat received back", LOG_DEBUG);
     $result=$db->query($sql);
     if ($result)
     {
@@ -650,9 +945,13 @@ else
     	$sql.= " AND t.datev >= '".$db->idate($date_start)."' AND t.datev <= '".$db->idate($date_end)."'";
     $sql.= " AND t.entity = ".$conf->entity;
     $sql.= " GROUP BY dm";
-    $sql.= " ORDER BY dm";
+    $newsortfield = $sortfield;
+    if ($newsortfield == 's.nom, s.rowid') $newsortfield = 'dm';
+    if ($newsortfield == 'amount_ht') $newsortfield = 'amount';
+    if ($newsortfield == 'amount_ttc') $newsortfield = 'amount';
+    $sql.= $db->order($newsortfield, $sortorder);
 
-    dol_syslog("get vat really paid sql=".$sql);
+    dol_syslog("get vat really paid", LOG_DEBUG);
     $result=$db->query($sql);
     if ($result) {
         $num = $db->num_rows($result);
@@ -691,9 +990,13 @@ else
     	$sql.= " AND t.datev >= '".$db->idate($date_start)."' AND t.datev <= '".$db->idate($date_end)."'";
     $sql.= " AND t.entity = ".$conf->entity;
     $sql.= " GROUP BY dm";
-    $sql.= " ORDER BY dm";
+    $newsortfield = $sortfield;
+    if ($newsortfield == 's.nom, s.rowid') $newsortfield = 'dm';
+    if ($newsortfield == 'amount_ht') $newsortfield = 'amount';
+    if ($newsortfield == 'amount_ttc') $newsortfield = 'amount';
+    $sql.= $db->order($newsortfield, $sortorder);
 
-    dol_syslog("get vat really received back sql=".$sql);
+    dol_syslog("get vat really received back", LOG_DEBUG);
     $result=$db->query($sql);
     if ($result) {
         $num = $db->num_rows($result);
@@ -727,7 +1030,7 @@ else
 }
 
 
-if ($mysoc->tva_assuj != 'franchise')	// Assujeti
+if ($mysoc->tva_assuj != 'franchise')	// Assujetti
 {
     print '<tr class="liste_total">';
     if ($modecompta == 'CREANCES-DETTES')
@@ -736,8 +1039,18 @@ if ($mysoc->tva_assuj != 'franchise')	// Assujeti
     print '</tr>';
 }
 
+$action = "balanceclient";
+$object = array(&$total_ht, &$total_ttc);
+$parameters["mode"] = $modecompta;
+$parameters["date_start"] = $date_start;
+$parameters["date_end"] = $date_end;
+$parameters["bc"] = $bc;
+// Initialize technical object to manage hooks of expenses. Note that conf->hooks_modules contains array array
+$hookmanager->initHooks(array('externalbalance'));
+$reshook=$hookmanager->executeHooks('addBalanceLine',$parameters,$object,$action);    // Note that $action and $object may have been modified by some hooks
+print $hookmanager->resPrint;
 
-if ($mysoc->tva_assuj != 'franchise')	// Assujeti
+if ($mysoc->tva_assuj != 'franchise')	// Assujetti
 {
     // Total
     print '<tr>';
@@ -757,4 +1070,3 @@ print '<br>';
 llxFooter();
 
 $db->close();
-?>
