@@ -74,21 +74,31 @@ if ($id > 0)
     $head = contact_prepare_head($object);
 
     dol_fiche_head($head, 'note', $title,0,'contact');
-
-
-    print '<form method="POST" action="'.$_SERVER['PHP_SELF'].'">';
-    print '<input type="hidden" name="token" value="'.$_SESSION['newtoken'].'">';
-
     
     $linkback = '<a href="'.DOL_URL_ROOT.'/contact/list.php">'.$langs->trans("BackToList").'</a>';
-    dol_banner_tab($object, 'id', $linkback, 1, 'rowid', 'ref', '');
+
+    $morehtmlref='<div class="refidno">';
+    if (empty($conf->global->SOCIETE_DISABLE_CONTACTS))
+    {
+        $objsoc=new Societe($db);
+        $objsoc->fetch($object->socid);
+        // Thirdparty
+        $morehtmlref.=$langs->trans('ThirdParty') . ' : ';
+        if ($objsoc->id > 0) $morehtmlref.=$objsoc->getNomUrl(1);
+        else $morehtmlref.=$langs->trans("ContactNotLinkedToCompany");
+    }
+    $morehtmlref.='</div>';
+    
+    dol_banner_tab($object, 'id', $linkback, 1, 'rowid', 'ref', $morehtmlref);
+    
+    $cssclass='titlefield';
+    //if ($action == 'editnote_public') $cssclass='titlefieldcreate';
+    //if ($action == 'editnote_private') $cssclass='titlefieldcreate';
     
     print '<div class="fichecenter">';
-    
     print '<div class="underbanner clearboth"></div>';
-    print '<table class="border centpercent">';
 
-    $linkback = '<a href="'.DOL_URL_ROOT.'/contact/list.php">'.$langs->trans("BackToList").'</a>';
+	print '<table class="border centpercent">';
 
     // Company
     if (empty($conf->global->SOCIETE_DISABLE_CONTACTS))
@@ -98,19 +108,19 @@ if ($id > 0)
     		$objsoc = new Societe($db);
     		$objsoc->fetch($object->socid);
 
-    		print '<tr><td>'.$langs->trans("ThirdParty").'</td><td colspan="3">'.$objsoc->getNomUrl(1).'</td></tr>';
+    		print '<tr><td class="'.$cssclass.'">'.$langs->trans("ThirdParty").'</td><td>'.$objsoc->getNomUrl(1).'</td></tr>';
     	}
 
     	else
     	{
-    		print '<tr><td>'.$langs->trans("ThirdParty").'</td><td colspan="3">';
+    		print '<tr><td class="'.$cssclass.'">'.$langs->trans("ThirdParty").'</td><td>';
     		print $langs->trans("ContactNotLinkedToCompany");
     		print '</td></tr>';
     	}
     }
 
     // Civility
-    print '<tr><td class="titlefield">'.$langs->trans("UserTitle").'</td><td colspan="3">';
+    print '<tr><td class="'.$cssclass.'">'.$langs->trans("UserTitle").'</td><td>';
     print $object->getCivilityLabel();
     print '</td></tr>';
 
@@ -120,7 +130,7 @@ if ($id > 0)
     {
     	include_once DOL_DOCUMENT_ROOT.'/core/lib/date.lib.php';
 
-    	print '<td class="titlefield">'.$langs->trans("DateToBirth").'</td><td colspan="3">'.dol_print_date($object->birthday,"day");
+    	print '<td>'.$langs->trans("DateToBirth").'</td><td>'.dol_print_date($object->birthday,"day");
 
     	print ' &nbsp; ';
     	//var_dump($birthdatearray);
@@ -138,20 +148,19 @@ if ($id > 0)
     }
     else
     {
-    	print '<td>'.$langs->trans("DateToBirth").'</td><td colspan="3">'.$langs->trans("Unknown")."</td>";
+    	print '<td>'.$langs->trans("DateToBirth").'</td><td>'.$langs->trans("Unknown")."</td>";
     }
     print "</tr>";
 
     print "</table>";
 
-    print '<div>';
-    
     print '<br>';
+    
+	$cssclass="titlefield";
+	include DOL_DOCUMENT_ROOT.'/core/tpl/notes.tpl.php';
 
-    $cssclass='titlefield';
-    include DOL_DOCUMENT_ROOT.'/core/tpl/notes.tpl.php';
-
-
+	print '</div>';
+	
     dol_fiche_end();
 }
 
