@@ -1,5 +1,5 @@
 <?php
-/* Copyright (C) 2015 Laurent Destailleur  <eldy@users.sourceforge.net>
+/* Copyright (C) 2015-2016 Laurent Destailleur  <eldy@users.sourceforge.net>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -18,22 +18,29 @@
 
 /**
  *	\file			htdocs/core/actions_dellink.inc.php
- *  \brief			Code for actions on deleting link between elements
+ *  \brief			Code for actions on linking and deleting link between elements
  */
 
 
 // $action must be defined
 // $object must be defined
 // $permissiondellink must be defined
-// $uploaddir (example $conf->projet->dir_output . "/";)
 
 $dellinkid = GETPOST('dellinkid','int');
+$addlinkid = GETPOST('idtolinkto','int');
 
-// Set public note
+// Link invoice to order
+if ($action == 'addlink' && ! empty($permissiondellink) && ! GETPOST('cancel') && $id > 0 && $addlinkid > 0)
+{
+    $object->fetch($id);
+    $object->fetch_thirdparty();
+    $result = $object->add_object_linked(GETPOST('addlink'), $addlinkid);
+}
+
+// Delete link
 if ($action == 'dellink' && ! empty($permissiondellink) && ! GETPOST('cancel') && $dellinkid > 0)
 {
 	$result=$object->deleteObjectLinked(0, '', 0, '', $dellinkid);
 	if ($result < 0) setEventMessages($object->error,$object->errors,'errors');
 }
 
-
