@@ -44,6 +44,21 @@ class box_actions extends ModeleBoxes
 	var $info_box_contents = array();
 
 
+	/**
+	 *  Constructor
+	 *
+	 *  @param  DoliDB	$db      	Database handler
+	 *  @param	string	$param		More parameters
+	 */
+	function __construct($db,$param='')
+	{
+	    global $user;
+
+	    $this->db = $db;
+
+	    $this->hidden = ! ($user->rights->agenda->myactions->read);
+	}
+
 	/**
      *  Load data for box to show them later
      *
@@ -173,8 +188,8 @@ class box_actions extends ModeleBoxes
     function showBox($head = null, $contents = null, $nooutput=0)
     {
 		global $langs, $conf;
-		parent::showBox($this->info_box_head, $this->info_box_contents);
-		$out='';
+		$out = parent::showBox($this->info_box_head, $this->info_box_contents);
+
         if (! empty($conf->global->SHOW_DIALOG_HOMEPAGE))
         {
 			$actioncejour=false;
