@@ -42,6 +42,21 @@ class box_factures extends ModeleBoxes
 	var $info_box_contents = array();
 
 
+	/**
+	 *  Constructor
+	 *
+	 *  @param  DoliDB  $db         Database handler
+	 *  @param  string  $param      More parameters
+	 */
+	function __construct($db,$param)
+	{
+	    global $user;
+
+	    $this->db=$db;
+
+	    $this->hidden=! ($user->rights->facture->lire);
+	}
+
 	/**
 	 *  Load data into info_box_contents array to show array later.
 	 *
@@ -181,11 +196,11 @@ class box_factures extends ModeleBoxes
 	 *  @param  array   $head       Array with properties of box title
 	 *  @param  array   $contents   Array with properties of box lines
 	 *  @param	int		$nooutput	No print, only return string
-	 *	@return	void
+	 *	@return	string
 	 */
     function showBox($head = null, $contents = null, $nooutput=0)
     {
-		parent::showBox($this->info_box_head, $this->info_box_contents, $nooutput);
+		return parent::showBox($this->info_box_head, $this->info_box_contents, $nooutput);
 	}
 
 }
