@@ -51,14 +51,14 @@ class FormAdmin
 	 *    	@param      string		$htmlname       Name of HTML select
 	 *    	@param      int			$showauto       Show 'auto' choice
 	 * 		@param		array		$filter			Array of keys to exclude in list
-	 * 		@param		int			$showempty		Add empty value
+	 * 		@param		string		$showempty		1=Add empty value or string to show
 	 *      @param      int			$showwarning    Show a warning if language is not complete
 	 *      @param		int			$disabled		Disable edit of select
 	 *      @param		string		$morecss		Add more css styles
 	 *      @param      int         $showcode       Add language code into label
 	 *      @return		string						Return HTML select string with list of languages
 	 */
-	function select_language($selected='',$htmlname='lang_id',$showauto=0,$filter=null,$showempty=0,$showwarning=0,$disabled=0,$morecss='',$showcode=0)
+	function select_language($selected='', $htmlname='lang_id', $showauto=0, $filter=null, $showempty='', $showwarning=0, $disabled=0, $morecss='', $showcode=0)
 	{
 		global $langs;
 
@@ -71,7 +71,10 @@ class FormAdmin
 		{
 			$out.= '<option value=""';
 			if ($selected == '') $out.= ' selected';
-			$out.= '>&nbsp;</option>';
+			$out.= '>';
+			if ($showempty != '1') $out.=$showempty;
+			else $out.='&nbsp;';
+			$out.='</option>';
 		}
 		if ($showauto)
 		{
