@@ -28,30 +28,30 @@
  */
 class Menubase
 {
-    var $db;							// To store db handler
-    var $error;							// To return error code (or message)
-    var $errors=array();				// To return several error codes (or messages)
+    public $db;							// To store db handler
+    public $error;							// To return error code (or message)
+    public $errors=array();				// To return several error codes (or messages)
 
-    var $id;
+    public $id;
 
-    var $menu_handler;
-    var $module;
-    var $type;
-    var $mainmenu;
-    var $fk_menu;
-    var $fk_mainmenu;
-    var $fk_leftmenu;
-    var $position;
-    var $url;
-    var $target;
-    var $titre;
-    var $langs;
-    var $level;
-    var $leftmenu;		//<! Not used
-    var $perms;
-    var $enabled;
-    var $user;
-    var $tms;
+    public $menu_handler;
+    public $module;
+    public $type;
+    public $mainmenu;
+    public $fk_menu;
+    public $fk_mainmenu;
+    public $fk_leftmenu;
+    public $position;
+    public $url;
+    public $target;
+    public $titre;
+    public $langs;
+    public $level;
+    public $leftmenu;		//<! Not used
+    public $perms;
+    public $enabled;
+    public $user;
+    public $tms;
 
 
     /**
