@@ -4,6 +4,7 @@
  * Copyright (C) 2004-2011	Laurent Destailleur		<eldy@users.sourceforge.net>
  * Copyright (C) 2006		Andre Cianfarani		<acianfa@free.fr>
  * Copyright (C) 2005-2012	Regis Houssin			<regis.houssin@capnetworks.com>
+ * Copyright (C) 2015       Raphaël Doursenaud      <rdoursenaud@gpcsolutions.fr>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -21,52 +22,26 @@
 
 /**
  *	\file       htdocs/core/db/mysqli.class.php
- *	\brief      Class file to manage Dolibarr database access for a Mysql database
+ *	\brief      Class file to manage Dolibarr database access for a MySQL database
  */
 
 require_once DOL_DOCUMENT_ROOT .'/core/db/DoliDB.class.php';
 
 /**
- *	Class to manage Dolibarr database access for a Mysql database
+ *	Class to manage Dolibarr database access for a MySQL database using the MySQLi extension
  */
 class DoliDBMysqli extends DoliDB
 {
-    //! Database handler
-    var $db;
+	/** @var mysqli Database object */
+	public $db;
     //! Database type
     public $type='mysqli';
     //! Database label
-    static $label='MySQL';
-    //! Charset used to force charset when creating database
-    var $forcecharset='utf8';	// latin1, utf8. Can't be static as it may be forced with a dynamic value
-    //! Collate used to force collate when creating database
-    var $forcecollate='utf8_general_ci';	// latin1_swedish_ci, utf8_general_ci. Can't be static as it may be forced with a dynamic value
+    const LABEL='MySQL or MariaDB';
     //! Version min database
-    static $versionmin=array(4,1,0);
-	//! Resultset of last request
+    const VERSIONMIN='5.0.3';
+	/** @var mysqli_result Resultset of last query */
 	private $_results;
-    //! 1 if connected, 0 else
-    var $connected;
-    //! 1 if database selected, 0 else
-    var $database_selected;
-    //! Database name selected
-    var $database_name;
-    //! Nom user base
-    var $database_user;
-	//! >=1 if a transaction is opened, 0 otherwise
-    var $transaction_opened;
-    //! Last executed request
-    var $lastquery;
-    //! Last failed executed request
-    var $lastqueryerror;
-    //! Message erreur mysql
-    var $lasterror;
-    //! Message erreur mysql
-    var $lasterrno;
-
-    var $ok;
-    var $error;
-
 
     /**
 	 *	Constructor.
@@ -78,90 +53,83 @@ class DoliDBMysqli extends DoliDB
 	 *	@param	    string	$pass		Mot de passe
 	 *	@param	    string	$name		Nom de la database
 	 *	@param	    int		$port		Port of database server
-	 *	@return	    int					1 if OK, 0 if not
      */
     function __construct($type, $host, $user, $pass, $name='', $port=0)
     {
         global $conf,$langs;
 
-        // TODO error in strict mode (static property for "$forcecharset" and "$forcecollate")
-        //if (! empty($conf->db->character_set)) $this->forcecharset=$conf->db->character_set;
-        //if (! empty($conf->db->dolibarr_main_db_collation)) $this->forcecollate=$conf->db->dolibarr_main_db_collation;
+        // Note that having "static" property for "$forcecharset" and "$forcecollate" will make error here in strict mode, so they are not static
+        if (! empty($conf->db->character_set)) $this->forcecharset=$conf->db->character_set;
+        if (! empty($conf->db->dolibarr_main_db_collation)) $this->forcecollate=$conf->db->dolibarr_main_db_collation;
 
         $this->database_user=$user;
+        $this->database_host=$host;
+        $this->database_port=$port;
 
         $this->transaction_opened=0;
 
         //print "Name DB: $host,$user,$pass,$name<br>";
 
-        if (! function_exists("mysqli_connect"))
+        if (! class_exists('mysqli'))
         {
-            $this->connected = 0;
-            $this->ok = 0;
+            $this->connected = false;
+            $this->ok = false;
             $this->error="Mysqli PHP functions for using Mysqli driver are not available in this version of PHP. Try to use another driver.";
             dol_syslog(get_class($this)."::DoliDBMysqli : Mysqli PHP functions for using Mysqli driver are not available in this version of PHP. Try to use another driver.",LOG_ERR);
-            return $this->ok;
         }
 
         if (! $host)
         {
-            $this->connected = 0;
-            $this->ok = 0;
+            $this->connected = false;
+            $this->ok = false;
             $this->error=$langs->trans("ErrorWrongHostParameter");
-            dol_syslog(get_class($this)."::DoliDBMysqli : Erreur Connect, wrong host parameters",LOG_ERR);
-            return $this->ok;
+            dol_syslog(get_class($this)."::DoliDBMysqli : Connect error, wrong host parameters",LOG_ERR);
         }
 
-        // Essai connexion serveur
-        // We do not try to connect to database, only to server. Connect to database is done later in constrcutor
-        $this->db = $this->connect($host, $user, $pass, '', $port);
+		// Try server connection
+		// We do not try to connect to database, only to server. Connect to database is done later in constrcutor
+		$this->db = $this->connect($host, $user, $pass, '', $port);
 
-        if ($this->db)
-        {
-            $this->connected = 1;
-            $this->ok = 1;
-        }
-        else
-        {
-            // host, login ou password incorrect
-            $this->connected = 0;
-            $this->ok = 0;
-            $this->error=mysqli_connect_error();
-            dol_syslog(get_class($this)."::DoliDBMysqli : Erreur Connect mysqli_connect_error=".$this->error,LOG_ERR);
-        }
+		if ($this->db->connect_errno) {
+			$this->connected = false;
+			$this->ok = false;
+			$this->error = $this->db->connect_error;
+			dol_syslog(get_class($this) . "::DoliDBMysqli Connect error: " . $this->error, LOG_ERR);
+		} else {
+			$this->connected = true;
+			$this->ok = true;
+		}
 
-        // Si connexion serveur ok et si connexion base demandee, on essaie connexion base
+		// If server connection is ok, we try to connect to the database
         if ($this->connected && $name)
         {
             if ($this->select_db($name))
             {
-                $this->database_selected = 1;
+                $this->database_selected = true;
                 $this->database_name = $name;
-                $this->ok = 1;
+                $this->ok = true;
 
                 // If client connected with different charset than Dolibarr HTML output
                 $clientmustbe='';
                 if (preg_match('/UTF-8/i',$conf->file->character_set_client))      $clientmustbe='utf8';
                 if (preg_match('/ISO-8859-1/i',$conf->file->character_set_client)) $clientmustbe='latin1';
-                if (mysqli_character_set_name($this->db) != $clientmustbe)
-                {
-                    $this->query("SET NAMES '".$clientmustbe."'", $this->db);
-                    //$this->query("SET CHARACTER SET ". $this->forcecharset);
-                }
+				if ($this->db->character_set_name() != $clientmustbe) {
+					$this->db->set_charset($clientmustbe);
+				}
             }
             else
             {
-                $this->database_selected = 0;
+                $this->database_selected = false;
                 $this->database_name = '';
-                $this->ok = 0;
+                $this->ok = false;
                 $this->error=$this->error();
-                dol_syslog(get_class($this)."::DoliDBMysqli : Erreur Select_db ".$this->error,LOG_ERR);
+                dol_syslog(get_class($this)."::DoliDBMysqli : Select_db error ".$this->error,LOG_ERR);
             }
         }
         else
         {
             // Pas de selection de base demandee, ok ou ko
-            $this->database_selected = 0;
+            $this->database_selected = false;
 
             if ($this->connected)
             {
@@ -169,15 +137,11 @@ class DoliDBMysqli extends DoliDB
                 $clientmustbe='';
                 if (preg_match('/UTF-8/i',$conf->file->character_set_client))      $clientmustbe='utf8';
                 if (preg_match('/ISO-8859-1/i',$conf->file->character_set_client)) $clientmustbe='latin1';
-                if (mysqli_character_set_name($this->db) != $clientmustbe)
-                {
-                    $this->query("SET NAMES '".$clientmustbe."'", $this->db);
-                    //$this->query("SET CHARACTER SET ". $this->forcecharset);
-                }
+				if ($this->db->character_set_name() != $clientmustbe) {
+					$this->db->set_charset($clientmustbe);
+				}
             }
         }
-
-        return $this->ok;
     }
 
 
@@ -202,36 +166,27 @@ class DoliDBMysqli extends DoliDB
     function select_db($database)
     {
         dol_syslog(get_class($this)."::select_db database=".$database, LOG_DEBUG);
-        return mysqli_select_db($this->db,$database);
+	    return $this->db->select_db($database);
     }
 
 
-    /**
-	 *	Connexion to server
+	/**
+	 * Connect to server
 	 *
-	 *	@param	    string	$host		database server host
-	 *	@param	    string	$login		login
-	 *	@param	    string	$passwd		password
-	 *	@param		string	$name		name of database (not used for mysql, used for pgsql)
-	 *	@param		string	$port		Port of database server
-	 *	@return		resource			Database access handler
-	 *	@see		close
-     */
-    function connect($host, $login, $passwd, $name, $port=0)
-    {
-        dol_syslog(get_class($this)."::connect host=$host, port=$port, login=$login, passwd=--hidden--, name=$name",LOG_DEBUG);
+	 * @param   string $host database server host
+	 * @param   string $login login
+	 * @param   string $passwd password
+	 * @param   string $name name of database (not used for mysql, used for pgsql)
+	 * @param   integer $port Port of database server
+	 * @return  mysqli  Database access object
+	 * @see close
+	 */
+	function connect($host, $login, $passwd, $name, $port = 0)
+	{
+		dol_syslog(get_class($this) . "::connect host=$host, port=$port, login=$login, passwd=--hidden--, name=$name", LOG_DEBUG);
 
-        $newhost=$host;
-        $newport=$port;
-
-        // With mysqli, port must be in connect parameters
-        if (! $newport) $newport=3306;
-
-        $this->db  = @mysqli_connect($newhost, $login, $passwd, $name, $newport);
-
-        //print "Resultat fonction connect: ".$this->db;
-        return $this->db;
-    }
+		return new mysqli($host, $login, $passwd, $name, $port);
+	}
 
     /**
 	 *	Return version of database server
@@ -240,17 +195,7 @@ class DoliDBMysqli extends DoliDB
      */
     function getVersion()
     {
-        return mysqli_get_server_info($this->db);
-    }
-
-	/**
-	 *	Return version of database server into an array
-	 *
-	 *	@return	        array  		Version array
-	 */
-    function getVersionArray()
-    {
-        return explode('.',$this->getVersion());
+        return $this->db->server_info;
     }
 
     /**
@@ -258,16 +203,16 @@ class DoliDBMysqli extends DoliDB
      *
      *	@return	        string      Version string
      */
-    function getDriverInfo()
-    {
-    	return mysqli_get_client_info($this->db);
-    }
+	function getDriverInfo()
+	{
+		return $this->db->client_info;
+	}
 
 
     /**
      *  Close database connexion
      *
-     *  @return     boolean     True if disconnect successfull, false otherwise
+     *  @return     bool     True if disconnect successfull, false otherwise
      *  @see        connect
      */
     function close()
@@ -275,88 +220,12 @@ class DoliDBMysqli extends DoliDB
         if ($this->db)
         {
 	        if ($this->transaction_opened > 0) dol_syslog(get_class($this)."::close Closing a connection with an opened transaction depth=".$this->transaction_opened,LOG_ERR);
-            $this->connected=0;
-            return mysqli_close($this->db);
+            $this->connected=false;
+            return $this->db->close();
         }
         return false;
     }
 
-
-    /**
-	 * Start transaction
-	 *
-	 * @return	    int         1 if transaction successfuly opened or already opened, 0 if error
-     */
-    function begin()
-    {
-        if (! $this->transaction_opened)
-        {
-            $ret=$this->query("BEGIN");
-            if ($ret)
-            {
-                $this->transaction_opened++;
-                dol_syslog("BEGIN Transaction",LOG_DEBUG);
-				dol_syslog('',0,1);
-            }
-            return $ret;
-        }
-        else
-        {
-            $this->transaction_opened++;
-			dol_syslog('',0,1);
-            return 1;
-        }
-    }
-
-    /**
-     * Validate a database transaction
-     *
-     * @param	string	$log		Add more log to default log line
-     * @return	int         		1 if validation is OK or transaction level no started, 0 if ERROR
-     */
-    function commit($log='')
-    {
-		dol_syslog('',0,-1);
-    	if ($this->transaction_opened<=1)
-        {
-            $ret=$this->query("COMMIT");
-            if ($ret)
-            {
-                $this->transaction_opened=0;
-                dol_syslog("COMMIT Transaction".($log?' '.$log:''),LOG_DEBUG);
-            }
-            return $ret;
-        }
-        else
-        {
-            $this->transaction_opened--;
-            return 1;
-        }
-    }
-
-    /**
-     *	Annulation d'une transaction et retour aux anciennes valeurs
-     *
-     * 	@param	string	$log		Add more log to default log line
-     * 	@return	int         		1 si annulation ok ou transaction non ouverte, 0 en cas d'erreur
-     */
-    function rollback($log='')
-    {
-		dol_syslog('',0,-1);
-    	if ($this->transaction_opened<=1)
-        {
-            $ret=$this->query("ROLLBACK");
-            $this->transaction_opened=0;
-            dol_syslog("ROLLBACK Transaction".($log?' '.$log:''),LOG_DEBUG);
-            return $ret;
-        }
-        else
-        {
-            $this->transaction_opened--;
-            return 1;
-        }
-    }
-
     /**
      * 	Execute a SQL request and return the resultset
      *
@@ -364,19 +233,24 @@ class DoliDBMysqli extends DoliDB
      * 	@param	int		$usesavepoint	0=Default mode, 1=Run a savepoint before and a rollbock to savepoint if error (this allow to have some request with errors inside global transactions).
      * 									Note that with Mysql, this parameter is not used as Myssql can already commit a transaction even if one request is in error, without using savepoints.
      *  @param  string	$type           Type of SQL order ('ddl' for insert, update, select, delete or 'dml' for create, alter...)
-     *	@return	resource    			Resultset of answer
+     *	@return	bool|mysqli_result		Resultset of answer
      */
     function query($query,$usesavepoint=0,$type='auto')
     {
+    	global $conf;
+
         $query = trim($query);
+
+	    if (! in_array($query,array('BEGIN','COMMIT','ROLLBACK'))) dol_syslog('sql='.$query, LOG_DEBUG);
+
         if (! $this->database_name)
         {
             // Ordre SQL ne necessitant pas de connexion a une base (exemple: CREATE DATABASE)
-            $ret = mysqli_query($this->db,$query);
+            $ret = $this->db->query($query);
         }
         else
         {
-            $ret = mysqli_query($this->db,$query);
+            $ret = $this->db->query($query);
         }
 
         if (! preg_match("/^COMMIT/i",$query) && ! preg_match("/^ROLLBACK/i",$query))
@@ -387,7 +261,9 @@ class DoliDBMysqli extends DoliDB
                 $this->lastqueryerror = $query;
                 $this->lasterror = $this->error();
                 $this->lasterrno = $this->errno();
-                dol_syslog(get_class($this)."::query SQL error: ".$query." ".$this->lasterrno, LOG_WARNING);
+
+				if ($conf->global->SYSLOG_LEVEL < LOG_DEBUG) dol_syslog(get_class($this)."::query SQL Error query: ".$query, LOG_ERR);	// Log of request was not yet done previously
+                dol_syslog(get_class($this)."::query SQL Error message: ".$this->lasterrno." ".$this->lasterror, LOG_ERR);
             }
             $this->lastquery=$query;
             $this->_results = $ret;
@@ -399,35 +275,35 @@ class DoliDBMysqli extends DoliDB
     /**
      *	Renvoie la ligne courante (comme un objet) pour le curseur resultset
      *
-     *	@param	Resultset	$resultset  Curseur de la requete voulue
-     *	@return	Object					Object result line or false if KO or end of cursor
+     *	@param	mysqli_result	$resultset	Curseur de la requete voulue
+     *	@return	object|null					Object result line or null if KO or end of cursor
      */
     function fetch_object($resultset)
     {
         // Si le resultset n'est pas fourni, on prend le dernier utilise sur cette connexion
         if (! is_object($resultset)) { $resultset=$this->_results; }
-        return mysqli_fetch_object($resultset);
+		return $resultset->fetch_object();
     }
 
 
     /**
      *	Return datas as an array
      *
-     *	@param	Resultset	$resultset  Resultset of request
-     *	@return	array					Array
+     *	@param	mysqli_result	$resultset	Resultset of request
+     *	@return	array|null					Array or null if KO or end of cursor
      */
     function fetch_array($resultset)
     {
         // If resultset not provided, we take the last used by connexion
         if (! is_object($resultset)) { $resultset=$this->_results; }
-        return mysqli_fetch_array($resultset);
+        return $resultset->fetch_array();
     }
 
     /**
      *	Return datas as an array
      *
-     *	@param	Resultset	$resultset  Resultset of request
-     *	@return	array					Array
+     *	@param	mysqli_result	$resultset	Resultset of request
+     *	@return	array|null|0				Array or null if KO or end of cursor or 0 if resultset is bool
      */
     function fetch_row($resultset)
     {
@@ -435,7 +311,7 @@ class DoliDBMysqli extends DoliDB
         if (! is_bool($resultset))
         {
             if (! is_object($resultset)) { $resultset=$this->_results; }
-            return mysqli_fetch_row($resultset);
+            return $resultset->fetch_row();
         }
         else
         {
@@ -447,98 +323,48 @@ class DoliDBMysqli extends DoliDB
     /**
      *	Return number of lines for result of a SELECT
      *
-     *	@param	Resultset	$resultset  Resulset of requests
-     *	@return int		    			Nb of lines
+     *	@param	mysqli_result	$resultset  Resulset of requests
+     *	@return	int				Nb of lines
      *	@see    affected_rows
      */
     function num_rows($resultset)
     {
         // If resultset not provided, we take the last used by connexion
         if (! is_object($resultset)) { $resultset=$this->_results; }
-        return mysqli_num_rows($resultset);
+        return $resultset->num_rows;
     }
 
     /**
      *	Renvoie le nombre de lignes dans le resultat d'une requete INSERT, DELETE ou UPDATE
      *
-     *	@param	resultset	$resultset   Curseur de la requete voulue
-     *	@return int		    Nombre de lignes
+     *	@param	mysqli_result	$resultset	Curseur de la requete voulue
+     *	@return int							Nombre de lignes
      *	@see    num_rows
      */
-
     function affected_rows($resultset)
     {
         // If resultset not provided, we take the last used by connexion
         if (! is_object($resultset)) { $resultset=$this->_results; }
         // mysql necessite un link de base pour cette fonction contrairement
         // a pqsql qui prend un resultset
-        return mysqli_affected_rows($this->db);
+        return $this->db->affected_rows;
     }
 
 
     /**
      *	Libere le dernier resultset utilise sur cette connexion
      *
-     *	@param  resultset	$resultset   Curseur de la requete voulue
+     *	@param  mysqli_result	$resultset	Curseur de la requete voulue
      *	@return	void
      */
-    function free($resultset=0)
+    function free($resultset=null)
     {
         // If resultset not provided, we take the last used by connexion
         if (! is_object($resultset)) { $resultset=$this->_results; }
         // Si resultset en est un, on libere la memoire
-        if (is_object($resultset)) mysqli_free_result($resultset);
+        if (is_object($resultset)) $resultset->free_result();
     }
 
-
-    /**
-     *	Define limits and offset of request
-     *
-     *	@param	int		$limit      Maximum number of lines returned (-1=conf->liste_limit, 0=no limit)
-     *	@param	int		$offset     Numero of line from where starting fetch
-     *	@return	string      		String with SQL syntax to add a limit and offset
-     */
-    function plimit($limit=0,$offset=0)
-    {
-        global $conf;
-        if (empty($limit)) return "";
-        if ($limit < 0) $limit=$conf->liste_limit;
-        if ($offset > 0) return " LIMIT $offset,$limit ";
-        else return " LIMIT $limit ";
-    }
-
-
-    /**
-     * Define sort criteria of request
-     *
-     * @param	string	$sortfield  List of sort fields
-     * @param	string	$sortorder  Sort order
-     * @return	string      		String to provide syntax of a sort sql string
-     * TODO	Mutualized this into a mother class
-     */
-    function order($sortfield=0,$sortorder=0)
-    {
-        if ($sortfield)
-        {
-            $return='';
-            $fields=explode(',',$sortfield);
-            foreach($fields as $val)
-            {
-                if (! $return) $return.=' ORDER BY ';
-                else $return.=',';
-
-				$return.=preg_replace('/[^0-9a-z_\.]/i','',$val);
-                if ($sortorder) $return.=' '.preg_replace('/[^0-9a-z]/i','',$sortorder);
-            }
-            return $return;
-        }
-        else
-        {
-            return '';
-        }
-    }
-
-
     /**
      *	Escape a string to insert data
      *
@@ -547,88 +373,7 @@ class DoliDBMysqli extends DoliDB
      */
     function escape($stringtoencode)
     {
-        return addslashes($stringtoencode);
-    }
-
-    /**
-	 *   Convert (by PHP) a GM Timestamp date into a string date with PHP server TZ to insert into a date field.
-     *   Function to use to build INSERT, UPDATE or WHERE predica
-     *
-     *   @param	    string	$param      Date TMS to convert
-     *   @return	string      		Date in a string YYYYMMDDHHMMSS
-     */
-    function idate($param)
-    {
-        return dol_print_date($param,"%Y%m%d%H%M%S");
-    }
-
-    /**
-     *	Convert (by PHP) a PHP server TZ string date into a GM Timestamps date
-     * 	19700101020000 -> 3600 with TZ+1
-     *
-     * 	@param		string	$string		Date in a string (YYYYMMDDHHMMSS, YYYYMMDD, YYYY-MM-DD HH:MM:SS)
-     *	@return		date				Date TMS
-     */
-    function jdate($string)
-    {
-        $string=preg_replace('/([^0-9])/i','',$string);
-        $tmp=$string.'000000';
-        $date=dol_mktime(substr($tmp,8,2),substr($tmp,10,2),substr($tmp,12,2),substr($tmp,4,2),substr($tmp,6,2),substr($tmp,0,4));
-        return $date;
-    }
-
-    /**
-     *  Format a SQL IF
-     *
-	 *	@param	string	$test           Test string (example: 'cd.statut=0', 'field IS NULL')
-	 *	@param	string	$resok          resultat si test egal
-	 *	@param	string	$resko          resultat si test non egal
-     *	@return	string          		SQL string
-     */
-    function ifsql($test,$resok,$resko)
-    {
-        return 'IF('.$test.','.$resok.','.$resko.')';
-    }
-
-
-    /**
-	 *	Return last request executed with query()
-	 *
-	 *	@return	string					Last query
-     */
-    function lastquery()
-    {
-        return $this->lastquery;
-    }
-
-    /**
-     *	Renvoie la derniere requete en erreur
-     *
-     *	@return	    string	lastqueryerror
-     */
-    function lastqueryerror()
-    {
-        return $this->lastqueryerror;
-    }
-
-    /**
-     *	Renvoie le libelle derniere erreur
-     *
-     *	@return	    string	lasterror
-     */
-    function lasterror()
-    {
-        return $this->lasterror;
-    }
-
-    /**
-     *	Renvoie le code derniere erreur
-     *
-     *	@return	    string	lasterrno
-     */
-    function lasterrno()
-    {
-        return $this->lasterrno;
+        return $this->db->real_escape_string($stringtoencode);
     }
 
     /**
@@ -641,8 +386,7 @@ class DoliDBMysqli extends DoliDB
         if (! $this->connected) {
             // Si il y a eu echec de connexion, $this->db n'est pas valide.
             return 'DB_ERROR_FAILED_TO_CONNECT';
-        }
-        else {
+        } else {
             // Constants to convert a MySql error code to a generic Dolibarr error code
             $errorcode_map = array(
             1004 => 'DB_ERROR_CANNOT_CREATE',
@@ -668,17 +412,17 @@ class DoliDBMysqli extends DoliDB
             1100 => 'DB_ERROR_NOT_LOCKED',
             1136 => 'DB_ERROR_VALUE_COUNT_ON_ROW',
             1146 => 'DB_ERROR_NOSUCHTABLE',
+            1215 => 'DB_ERROR_CANNOT_ADD_FOREIGN_KEY_CONSTRAINT',
             1216 => 'DB_ERROR_NO_PARENT',
             1217 => 'DB_ERROR_CHILD_EXISTS',
             1396 => 'DB_ERROR_USER_ALREADY_EXISTS',    // When creating user already existing
             1451 => 'DB_ERROR_CHILD_EXISTS'
             );
 
-            if (isset($errorcode_map[mysqli_errno($this->db)]))
-            {
-                return $errorcode_map[mysqli_errno($this->db)];
+            if (isset($errorcode_map[$this->db->errno])) {
+                return $errorcode_map[$this->db->errno];
             }
-            $errno=mysqli_errno($this->db);
+            $errno=$this->db->errno;
             return ($errno?'DB_ERROR_'.$errno:'0');
         }
     }
@@ -695,7 +439,7 @@ class DoliDBMysqli extends DoliDB
             return 'Not connected. Check setup parameters in conf/conf.php file and your mysql client and server versions';
         }
         else {
-            return mysqli_error($this->db);
+            return $this->db->error;
         }
     }
 
@@ -704,11 +448,11 @@ class DoliDBMysqli extends DoliDB
 	 *
 	 * @param   string	$tab    	Table name concerned by insert. Ne sert pas sous MySql mais requis pour compatibilite avec Postgresql
 	 * @param	string	$fieldid	Field name
-	 * @return  int     			Id of row
+	 * @return  int|string			Id of row
      */
     function last_insert_id($tab,$fieldid='rowid')
     {
-        return mysqli_insert_id($this->db);
+        return $this->db->insert_id;
     }
 
     /**
@@ -789,8 +533,12 @@ class DoliDBMysqli extends DoliDB
     function DDLGetConnectId()
     {
         $resql=$this->query('SELECT CONNECTION_ID()');
-        $row=$this->fetch_row($resql);
-        return $row[0];
+        if ($resql)
+        {
+            $row=$this->fetch_row($resql);
+            return $row[0];
+        }
+        else return '?';
     }
 
     /**
@@ -802,7 +550,7 @@ class DoliDBMysqli extends DoliDB
 	 * 	@param	string	$charset		Charset used to store data
 	 * 	@param	string	$collation		Charset used to sort data
 	 * 	@param	string	$owner			Username of database owner
-	 * 	@return	resource				resource defined if OK, null if KO
+	 * 	@return	bool|mysqli_result		resource defined if OK, null if KO
      */
     function DDLCreateDb($database,$charset='',$collation='',$owner='')
     {
@@ -830,7 +578,7 @@ class DoliDBMysqli extends DoliDB
 	 *
 	 *  @param	string		$database	Name of database
 	 *  @param	string		$table		Nmae of table filter ('xxx%')
-	 *  @return	resource				Resource
+	 *  @return	array					List of tables in an array
      */
     function DDLListTables($database, $table='')
     {
@@ -841,9 +589,12 @@ class DoliDBMysqli extends DoliDB
         $sql="SHOW TABLES FROM ".$database." ".$like.";";
         //print $sql;
         $result = $this->query($sql);
-        while($row = $this->fetch_row($result))
+        if ($result)
         {
-            $listtables[] = $row[0];
+            while($row = $this->fetch_row($result))
+            {
+                $listtables[] = $row[0];
+            }
         }
         return $listtables;
     }
@@ -862,9 +613,12 @@ class DoliDBMysqli extends DoliDB
 
         dol_syslog($sql,LOG_DEBUG);
         $result = $this->query($sql);
-        while($row = $this->fetch_row($result))
+        if ($result)
         {
-            $infotables[] = $row;
+            while($row = $this->fetch_row($result))
+            {
+                $infotables[] = $row;
+            }
         }
         return $infotables;
     }
@@ -878,11 +632,13 @@ class DoliDBMysqli extends DoliDB
 	 *	@param	    string	$type 			Type de la table
 	 *	@param	    array	$unique_keys 	Tableau associatifs Nom de champs qui seront clef unique => valeur
 	 *	@param	    array	$fulltext_keys	Tableau des Nom de champs qui seront indexes en fulltext
-	 *	@param	    string	$keys 			Tableau des champs cles noms => valeur
+	 *	@param	    array	$keys 			Tableau des champs cles noms => valeur
 	 *	@return	    int						<0 if KO, >=0 if OK
      */
-    function DDLCreateTable($table,$fields,$primary_key,$type,$unique_keys="",$fulltext_keys="",$keys="")
+    function DDLCreateTable($table,$fields,$primary_key,$type,$unique_keys=null,$fulltext_keys=null,$keys=null)
     {
+	    // FIXME: $fulltext_keys parameter is unused
+
         // cles recherchees dans le tableau des descriptions (fields) : type,value,attribute,null,default,extra
         // ex. : $fields['rowid'] = array('type'=>'int','value'=>'11','null'=>'not null','extra'=> 'auto_increment');
         $sql = "CREATE TABLE ".$table."(";
@@ -917,8 +673,7 @@ class DoliDBMysqli extends DoliDB
         if($primary_key != "")
         $pk = "primary key(".$primary_key.")";
 
-        if($unique_keys != "")
-        {
+        if(is_array($unique_keys)) {
             $i = 0;
             foreach($unique_keys as $key => $value)
             {
@@ -926,7 +681,7 @@ class DoliDBMysqli extends DoliDB
                 $i++;
             }
         }
-        if($keys != "")
+        if(is_array($keys))
         {
             $i = 0;
             foreach($keys as $key => $value)
@@ -940,7 +695,7 @@ class DoliDBMysqli extends DoliDB
         $sql .= ",".$pk;
         if($unique_keys != "")
         $sql .= ",".implode(',',$sqluq);
-        if($keys != "")
+        if(is_array($keys))
         $sql .= ",".implode(',',$sqlk);
         $sql .=") engine=".$type;
 
@@ -956,7 +711,7 @@ class DoliDBMysqli extends DoliDB
 	 *
 	 *	@param	string		$table	Name of table
 	 *	@param	string		$field	Optionnel : Name of field if we want description of field
-	 *	@return	resultset			Resultset x (x->Field, x->Type, ...)
+	 *	@return	bool|mysqli_result	Resultset x (x->Field, x->Type, ...)
      */
     function DDLDescTable($table,$field="")
     {
@@ -1003,14 +758,10 @@ class DoliDBMysqli extends DoliDB
         $sql.= " ".$field_position;
 
         dol_syslog(get_class($this)."::DDLAddField ".$sql,LOG_DEBUG);
-        if(! $this->query($sql))
-        {
-            return -1;
-        }
-        else
-        {
+        if($this->query($sql)) {
             return 1;
         }
+        return -1;
     }
 
     /**
@@ -1048,19 +799,18 @@ class DoliDBMysqli extends DoliDB
     {
         $sql= "ALTER TABLE ".$table." DROP COLUMN `".$field_name."`";
         dol_syslog(get_class($this)."::DDLDropField ".$sql,LOG_DEBUG);
-        if (! $this->query($sql))
-        {
-            $this->error=$this->lasterror();
-            return -1;
+        if ($this->query($sql)) {
+            return 1;
         }
-        else return 1;
+	    $this->error=$this->lasterror();
+	    return -1;
     }
 
 
     /**
 	 * 	Create a user and privileges to connect to database (even if database does not exists yet)
 	 *
-	 *	@param	string	$dolibarr_main_db_host 		Ip serveur
+	 *	@param	string	$dolibarr_main_db_host 		Ip server or '%'
 	 *	@param	string	$dolibarr_main_db_user 		Nom user a creer
 	 *	@param	string	$dolibarr_main_db_pass 		Mot de passe user a creer
 	 *	@param	string	$dolibarr_main_db_name		Database name where user must be granted
@@ -1073,13 +823,12 @@ class DoliDBMysqli extends DoliDB
         $resql=$this->query($sql);
         if (! $resql)
         {
-            if ($this->lasterrno != 'DB_ERROR_USER_ALREADY_EXISTS') 
+            if ($this->lasterrno != 'DB_ERROR_USER_ALREADY_EXISTS')
             {
-            	dol_syslog(get_class($this)."::DDLCreateUser sql=".$sql, LOG_ERR);
             	return -1;
             }
-            else 
-            {
+            else
+			{
             	// If user already exists, we continue to set permissions
             	dol_syslog(get_class($this)."::DDLCreateUser sql=".$sql, LOG_WARNING);
             }
@@ -1089,17 +838,15 @@ class DoliDBMysqli extends DoliDB
         $resql=$this->query($sql);
         if (! $resql)
         {
-            dol_syslog(get_class($this)."::DDLCreateUser sql=".$sql, LOG_ERR);
             return -1;
         }
 
         $sql="FLUSH Privileges";
 
-        dol_syslog(get_class($this)."::DDLCreateUser sql=".$sql);
+        dol_syslog(get_class($this)."::DDLCreateUser", LOG_DEBUG);
         $resql=$this->query($sql);
         if (! $resql)
         {
-            dol_syslog(get_class($this)."::DDLCreateUser sql=".$sql, LOG_ERR);
             return -1;
         }
 
@@ -1107,7 +854,7 @@ class DoliDBMysqli extends DoliDB
     }
 
     /**
-     *	Return charset used to store data in database
+     *	Return charset used to store data in current database (same result than using SELECT default_character_set_name FROM information_schema.SCHEMATA WHERE schema_name = "databasename";)
      *
      *	@return		string		Charset
      */
@@ -1126,7 +873,7 @@ class DoliDBMysqli extends DoliDB
     /**
      *	Return list of available charset that can be used to store data in database
      *
-     *	@return		array		List of Charset
+     *	@return		array|null		List of Charset
      */
     function getListOfCharacterSet()
     {
@@ -1150,7 +897,7 @@ class DoliDBMysqli extends DoliDB
     }
 
     /**
-     *	Return collation used in database
+     *	Return collation used in current database
      *
      *	@return		string		Collation value
      */
@@ -1169,7 +916,7 @@ class DoliDBMysqli extends DoliDB
     /**
      *	Return list of available collation that can be used for database
      *
-     *	@return		array		Liste of Collation
+     *	@return		array|null		Liste of Collation
      */
     function getListOfCollation()
     {
@@ -1230,48 +977,45 @@ class DoliDBMysqli extends DoliDB
     }
 
     /**
-     *	Return value of server parameters
+     * Return value of server parameters
      *
-     * 	@param	string	$filter		Filter list on a particular value
-     * 	@return	string				Value for parameter
+     * @param	string	$filter		Filter list on a particular value
+	 * @return	array				Array of key-values (key=>value)
      */
     function getServerParametersValues($filter='')
     {
         $result=array();
 
         $sql='SHOW VARIABLES';
-        if ($filter) $sql.=" LIKE '".addslashes($filter)."'";
+        if ($filter) $sql.=" LIKE '".$this->escape($filter)."'";
         $resql=$this->query($sql);
         if ($resql)
         {
-            $obj=$this->fetch_object($resql);
-            $result[$obj->Variable_name]=$obj->Value;
+        	while($obj=$this->fetch_object($resql)) $result[$obj->Variable_name]=$obj->Value;
         }
 
         return $result;
     }
 
     /**
-     *	Return value of server status
+     * Return value of server status (current indicators on memory, cache...)
      *
-     * 	@param	string	$filter		Filter list on a particular value
-     * 	@return	string				Value for parameter
+     * @param	string	$filter		Filter list on a particular value
+	 * @return  array				Array of key-values (key=>value)
      */
     function getServerStatusValues($filter='')
     {
         $result=array();
 
         $sql='SHOW STATUS';
-        if ($filter) $sql.=" LIKE '".addslashes($filter)."'";
+        if ($filter) $sql.=" LIKE '".$this->escape($filter)."'";
         $resql=$this->query($sql);
         if ($resql)
         {
-            $obj=$this->fetch_object($resql);
-            $result[$obj->Variable_name]=$obj->Value;
+            while($obj=$this->fetch_object($resql)) $result[$obj->Variable_name]=$obj->Value;
         }
 
         return $result;
     }
 }
 
-?>
