@@ -260,7 +260,7 @@ function run_sql($sqlfile,$silent=1,$entity='',$usesavepoint=1,$handler='',$oker
             $newsql=preg_replace('/__ENTITY__/i',(!empty($entity)?$entity:$conf->entity),$sql);
 
             // Ajout trace sur requete (eventuellement a commenter si beaucoup de requetes)
-            if (! $silent) print '<tr><td valign="top">'.$langs->trans("Request").' '.($i+1)." sql='".dol_htmlentities($newsql,ENT_NOQUOTES)."'</td></tr>\n";
+            if (! $silent) print '<tr><td class="tdtop">'.$langs->trans("Request").' '.($i+1)." sql='".dol_htmlentities($newsql,ENT_NOQUOTES)."'</td></tr>\n";
             dol_syslog('Admin.lib::run_sql Request '.($i+1), LOG_DEBUG);
 			$sqlmodified=0;
 
@@ -568,6 +568,37 @@ function security_prepare_head()
 }
 
 
+/**
+ * Prepare array with list of tabs
+ *
+ * @return  array				Array of tabs to show
+ */
+function translation_prepare_head()
+{
+    global $langs, $conf, $user;
+    $h = 0;
+    $head = array();
+
+    $head[$h][0] = DOL_URL_ROOT."/admin/translation.php?mode=overwrite";
+    $head[$h][1] = $langs->trans("TranslationOverwriteKey");
+    $head[$h][2] = 'overwrite';
+    $h++;
+
+    $head[$h][0] = DOL_URL_ROOT."/admin/translation.php?mode=searchkey";
+    $head[$h][1] = $langs->trans("TranslationKeySearch");
+    $head[$h][2] = 'searchkey';
+    $h++;
+
+    complete_head_from_modules($conf,$langs,null,$head,$h,'translation_admin');
+
+    complete_head_from_modules($conf,$langs,null,$head,$h,'translation_admin','remove');
+
+
+    return $head;
+}
+
+
+
 /**
  * 	Return list of session
  *
@@ -677,16 +708,19 @@ function purgeSessions($mysessionid)
  *
  *  @param      string		$value      Name of module to activate
  *  @param      int			$withdeps   Activate/Disable also all dependencies
- *  @return     string      			Error message or '';
+ *  @return     array      			    array('nbmodules'=>nb modules activated with success, 'errors=>array of error messages, 'nbperms'=>Nb permission added);
  */
 function activateModule($value,$withdeps=1)
 {
     global $db, $modules, $langs, $conf;
 
-    // Check parameters
-    if (empty($value)) return 'ErrorBadParameter';
+	// Check parameters
+	if (empty($value)) {
+		$ret['errors'][] = 'ErrorBadParameter';
+		return $ret;
+	}
 
-    $ret='';
+    $ret=array('nbmodules'=>0, 'errors'=>array(), 'nbperms'=>0);
     $modName = $value;
     $modFile = $modName . ".class.php";
 
@@ -709,71 +743,99 @@ function activateModule($value,$withdeps=1)
     // Test if PHP version ok
     $verphp=versionphparray();
     $vermin=isset($objMod->phpmin)?$objMod->phpmin:0;
-    if (is_array($vermin) && versioncompare($verphp,$vermin) < 0)
-    {
-        return $langs->trans("ErrorModuleRequirePHPVersion",versiontostring($vermin));
-    }
+	if (is_array($vermin) && versioncompare($verphp, $vermin) < 0) {
+		$ret['errors'][] = $langs->trans("ErrorModuleRequirePHPVersion", versiontostring($vermin));
+		return $ret;
+	}
 
     // Test if Dolibarr version ok
     $verdol=versiondolibarrarray();
     $vermin=isset($objMod->need_dolibarr_version)?$objMod->need_dolibarr_version:0;
     //print 'eee '.versioncompare($verdol,$vermin).' - '.join(',',$verdol).' - '.join(',',$vermin);exit;
-    if (is_array($vermin) && versioncompare($verdol,$vermin) < 0)
-    {
-        return $langs->trans("ErrorModuleRequireDolibarrVersion",versiontostring($vermin));
-    }
+	if (is_array($vermin) && versioncompare($verdol, $vermin) < 0) {
+		$ret['errors'][] = $langs->trans("ErrorModuleRequireDolibarrVersion", versiontostring($vermin));
+		return $ret;
+	}
 
-    // Test if javascript requirement ok
-    if (! empty($objMod->need_javascript_ajax) && empty($conf->use_javascript_ajax))
-    {
-        return $langs->trans("ErrorModuleRequireJavascript");
+	// Test if javascript requirement ok
+	if (!empty($objMod->need_javascript_ajax) && empty($conf->use_javascript_ajax)) {
+		$ret['errors'][] = $langs->trans("ErrorModuleRequireJavascript");
+		return $ret;
+	}
+
+	$const_name = $objMod->const_name;
+	if(!empty($conf->global->$const_name)){
+        return $ret;
     }
 
     $result=$objMod->init();
-    if ($result <= 0) $ret=$objMod->error;
-
-    if (! $ret && $withdeps)
+    if ($result <= 0) 
     {
-        if (isset($objMod->depends) && is_array($objMod->depends) && ! empty($objMod->depends))
+        $ret['errors'][]=$objMod->error;
+    }
+    else
+    {
+        if ($withdeps)
         {
-            // Activation des modules dont le module depend
-            $TError=array();
-            $num = count($objMod->depends);
-            for ($i = 0; $i < $num; $i++)
+            if (isset($objMod->depends) && is_array($objMod->depends) && ! empty($objMod->depends))
             {
-            	$activate = false;
-            	foreach ($modulesdir as $dir)
-            	{
-            		if (file_exists($dir.$objMod->depends[$i].".class.php"))
-            		{
-            			activateModule($objMod->depends[$i]);
-						$activate = true;
-            		}
-            	}
-				
-				if (!$activate) $TError[] = $langs->trans('activateModuleDependNotSatisfied', $objMod->name, $objMod->depends[$i]);
+                // Activation des modules dont le module depend
+                $num = count($objMod->depends);
+                for ($i = 0; $i < $num; $i++)
+                {
+                	$activate = false;
+                	foreach ($modulesdir as $dir)
+                	{
+                		if (file_exists($dir.$objMod->depends[$i].".class.php"))
+                		{
+                			$resarray = activateModule($objMod->depends[$i]);
+    						if (empty($resarray['errors'])){
+    						    $activate = true;
+                            }else{
+    						    foreach ($resarray['errors'] as $errorMessage){
+                                    dol_syslog($errorMessage, LOG_ERR);
+                                }
+                            }
+    						break;
+                		}
+                	}
+    				
+    				if ($activate)
+    				{
+    				    $ret['nbmodules']+=$resarray['nbmodules'];
+    				    $ret['nbperms']+=$resarray['nbperms'];
+    				}
+    				else 
+    				{
+    				    $ret['errors'][] = $langs->trans('activateModuleDependNotSatisfied', $objMod->name, $objMod->depends[$i]);
+    				}
+                }
             }
-            
-            setEventMessages('', $TError, 'errors');
-        }
-
-        if (isset($objMod->conflictwith) && is_array($objMod->conflictwith) && ! empty($objMod->conflictwith))
-        {
-            // Desactivation des modules qui entrent en conflit
-            $num = count($objMod->conflictwith);
-            for ($i = 0; $i < $num; $i++)
+    
+            if (isset($objMod->conflictwith) && is_array($objMod->conflictwith) && ! empty($objMod->conflictwith))
             {
-            	foreach ($modulesdir as $dir)
-            	{
-            		if (file_exists($dir.$objMod->conflictwith[$i].".class.php"))
-            		{
-            			unActivateModule($objMod->conflictwith[$i],0);
-            		}
-            	}
+                // Desactivation des modules qui entrent en conflit
+                $num = count($objMod->conflictwith);
+                for ($i = 0; $i < $num; $i++)
+                {
+                	foreach ($modulesdir as $dir)
+                	{
+                		if (file_exists($dir.$objMod->conflictwith[$i].".class.php"))
+                		{
+                			unActivateModule($objMod->conflictwith[$i],0);
+                		}
+                	}
+                }
             }
         }
     }
 
+    if (! count($ret['errors'])) 
+    {
+        $ret['nbmodules']++;
+        $ret['nbperms']+=count($objMod->rights);
+    }
+    
     return $ret;
 }
 
@@ -926,7 +988,7 @@ function complete_dictionary_with_modules(&$taborder,&$tabname,&$tablib,&$tabsql
                             {
                                 //var_dump($objMod->dictionaries['tabname']);
                                 $nbtabname=$nbtablib=$nbtabsql=$nbtabsqlsort=$nbtabfield=$nbtabfieldvalue=$nbtabfieldinsert=$nbtabrowid=$nbtabcond=$nbtabfieldcheck=$nbtabhelp=0;
-                                foreach($objMod->dictionaries['tabname'] as $val)        { $nbtabname++; $taborder[] = count($tabname)+1; $tabname[] = $val; }
+                                foreach($objMod->dictionaries['tabname'] as $val)        { $nbtabname++; $taborder[] = max($taborder)+1; $tabname[] = $val; }
                                 foreach($objMod->dictionaries['tablib'] as $val)         { $nbtablib++; $tablib[] = $val; }
                                 foreach($objMod->dictionaries['tabsql'] as $val)         { $nbtabsql++; $tabsql[] = $val; }
                                 foreach($objMod->dictionaries['tabsqlsort'] as $val)     { $nbtabsqlsort++; $tabsqlsort[] = $val; }
@@ -1185,7 +1247,7 @@ function form_constantes($tableau,$strictw3c=0)
                 else if (in_array($const,array('ADHERENT_AUTOREGISTER_NOTIF_MAIL','ADHERENT_AUTOREGISTER_MAIL','ADHERENT_MAIL_VALID','ADHERENT_MAIL_COTIS','ADHERENT_MAIL_RESIL')))
                 {
                     require_once DOL_DOCUMENT_ROOT.'/core/class/doleditor.class.php';
-                    $doleditor=new DolEditor('constvalue_'.$const.(empty($strictw3c)?'':'[]'),$obj->value,'',160,'dolibarr_notes','',false,false,$conf->fckeditor->enabled,5,60);
+                    $doleditor=new DolEditor('constvalue_'.$const.(empty($strictw3c)?'':'[]'),$obj->value,'',160,'dolibarr_notes','',false,false,$conf->fckeditor->enabled,ROWS_5,'90%');
                     $doleditor->Create();
                     print '<input type="hidden" name="consttype'.(empty($strictw3c)?'':'[]').'" value="texte">';
                 }
@@ -1244,7 +1306,8 @@ function showModulesExludedForExternal($modules)
 
 			//if (empty($conf->global->$moduleconst)) continue;
 			if (! in_array($modulename,$listofmodules)) continue;
-
+			//var_dump($modulename.'eee'.$langs->trans('Module'.$module->numero.'Name'));
+				
 			if ($i > 0) $text.=', ';
 			else $text.=' ';
 			$i++;
