@@ -1,5 +1,5 @@
 <?php
-/* Copyright (C) 2006-2015	Laurent Destailleur	<eldy@users.sourceforge.net>
+/* Copyright (C) 2006-2016	Laurent Destailleur	<eldy@users.sourceforge.net>
  * Copyright (C) 2012		Regis Houssin		<regis.houssin@capnetworks.com>
  * Copyright (C) 2015		Alexandre Spangaro	<aspangaro.dolibarr@gmail.com>
  * Copyright (C) 2016		Juanjo Menent   	<jmenent@2byte.es>
@@ -38,12 +38,12 @@ function bank_prepare_head(Account $object)
     $head = array();
 
     $head[$h][0] = DOL_URL_ROOT . '/compta/bank/card.php?id=' . $object->id;
-    $head[$h][1] = $langs->trans("AccountCard");
+    $head[$h][1] = $langs->trans("Card");
     $head[$h][2] = 'bankname';
     $h++;
 
-    $head[$h][0] = DOL_URL_ROOT . "/compta/bank/account.php?id=" . $object->id;
-    $head[$h][1] = $langs->trans("Transactions");
+    $head[$h][0] = DOL_URL_ROOT . "/compta/bank/bankentries.php?id=" . $object->id;
+    $head[$h][1] = $langs->trans("BankTransactions");
     $head[$h][2] = 'journal';
     $h++;
 
@@ -197,9 +197,10 @@ function checkBanForAccount($account)
         $rib = strtr($rib, "abcdefghijklmnopqrstuvwxyz", "12345678912345678923456789");
         // Separation du rib en 3 groupes de 7 + 1 groupe de 2.
         // Multiplication de chaque groupe par les coef du tableau
+    
         for ($i = 0, $s = 0; $i < 3; $i++) {
             $code = substr($rib, 7 * $i, 7);
-            $s += (0 + $code) * $coef[$i];
+            $s += (0 + (int) $code) * $coef[$i];
         }
         // Soustraction du modulo 97 de $s a 97 pour obtenir la cle
         $cle_rib = 97 - ($s % 97);
