@@ -1,7 +1,7 @@
 <?php
 /* Copyright (C) 2004-2011 Laurent Destailleur  <eldy@users.sourceforge.net>
  * Copyright (C) 2005-2011 Regis Houssin        <regis.houssin@capnetworks.com>
- * Copyright (C) 2011	   Juanjo Menent        <jmenent@2byte.es>
+ * Copyright (C) 2011-2015 Juanjo Menent        <jmenent@2byte.es>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -69,13 +69,11 @@ function get_tz_array()
  */
 function getServerTimeZoneString()
 {
-    if (function_exists('date_default_timezone_get')) return date_default_timezone_get();
-    else return '';
+    return @date_default_timezone_get();
 }
 
 /**
  * Return server timezone int.
- * If $conf->global->MAIN_OLD_DATE is set or PHP too old, we use old behaviour: All convertions does not take care of dayling saving time.
  *
  * @param	string	$refgmtdate		Reference period for timezone (timezone differs on winter and summer. May be 'now', 'winter' or 'summer')
  * @return 	int						An offset in hour (+1 for Europe/Paris on winter and +2 for Europe/Paris on summer)
@@ -83,13 +81,14 @@ function getServerTimeZoneString()
 function getServerTimeZoneInt($refgmtdate='now')
 {
     global $conf;
-    if (method_exists('DateTimeZone','getOffset') && empty($conf->global->MAIN_OLD_DATE))
+    if (method_exists('DateTimeZone','getOffset'))
     {
         // Method 1 (include daylight)
         $gmtnow=dol_now('gmt'); $yearref=dol_print_date($gmtnow,'%Y'); $monthref=dol_print_date($gmtnow,'%m'); $dayref=dol_print_date($gmtnow,'%d');
         if ($refgmtdate == 'now') $newrefgmtdate=$yearref.'-'.$monthref.'-'.$dayref;
         elseif ($refgmtdate == 'summer') $newrefgmtdate=$yearref.'-08-01';
         else $newrefgmtdate=$yearref.'-01-01';
+        $newrefgmtdate.='T00:00:00+00:00';
         $localtz = new DateTimeZone(getServerTimeZoneString());
         $localdt = new DateTime($newrefgmtdate, $localtz);
         $tmp=-1*$localtz->getOffset($localdt);
@@ -97,90 +96,45 @@ function getServerTimeZoneInt($refgmtdate='now')
     }
     else
     {
-        // Method 2 (does not include daylight, not supported by adodb)
-        if ($refgmtdate == 'now')
-        {
-            if (ini_get("date.timezone")=='UTC') return 0;
-            // We don't know server timezone string, so we don't know location, so we can't guess daylight. We assume we use same than client. Fix is to use new PHP with not MAIN_OLD_DATE.
-            $gmtnow=dol_now('gmt'); $yearref=dol_print_date($gmtnow,'%Y'); $monthref=dol_print_date($gmtnow,'%m'); $dayref=dol_print_date($gmtnow,'%d');
-            if (dol_stringtotime($_SESSION['dol_dst_first']) <= $gmtnow && $gmtnow < dol_stringtotime($_SESSION['dol_dst_second'])) $daylight=1;
-            else $daylight=0;
-            $tmp=dol_mktime(0,0,0,$monthref,$dayref,$yearref,false,0)-dol_mktime(0,0,0,$monthref,$dayref,$yearref,true,0)-($daylight*3600);
-            return 'unknown';    // For true result
-        }
-        elseif ($refgmtdate == 'summer')
-        {
-            if (ini_get("date.timezone")=='UTC') return 0;
-            // We don't know server timezone string, so we don't know location, so we can't guess daylight. We assume we use same than client. Fix is to use new PHP with not MAIN_OLD_DATE.
-            $gmtnow=dol_now('gmt'); $yearref=dol_print_date($gmtnow,'%Y'); $monthref='08'; $dayref='01';
-            if (dol_stringtotime($_SESSION['dol_dst_first']) <= dol_stringtotime($yearref.'-'.$monthref.'-'.$dayref) && dol_stringtotime($yearref.'-'.$monthref.'-'.$dayref) < dol_stringtotime($_SESSION['dol_dst_second'])) $daylight=1;
-            else $daylight=0;
-            $tmp=dol_mktime(0,0,0,$monthref,$dayref,$yearref,false,0)-dol_mktime(0,0,0,$monthref,$dayref,$yearref,true,0)-($daylight*3600);
-            return 'unknown';    // For true result
-        }
-        else $tmp=dol_mktime(0,0,0,1,1,1970);
+    	$tmp=0;
+    	dol_print_error('','PHP version must be 5.3+');
     }
     $tz=round(($tmp<0?1:-1)*abs($tmp/3600));
     return $tz;
 }
 
-/**
- * Return server timezone string
- *
- * @return string			Parent company timezone string ('Europe/Paris')
- *
-function getParentCompanyTimeZoneString()
-{
-    if (function_exists('date_default_timezone_get')) return date_default_timezone_get();
-    else return '';
-}
-*/
-
-/**
- * Return parent company timezone int.
- * If $conf->global->MAIN_NEW_DATE is set, we use new behaviour: All convertions take care of dayling saving time.
- *
- * @param	string	$refgmtdate		Reference date for timezone (timezone differs on winter and summer)
- * @return 	int						An offset in hour (+1 for Europe/Paris on winter and +2 for Europe/Paris on summer)
- *
-function getParentCompanyTimeZoneInt($refgmtdate='now')
-{
-    global $conf;
-    if (class_exists('DateTime') && empty($conf->global->MAIN_OLD_DATE))
-    {
-        // Method 1 (include daylight)
-        $localtz = new DateTimeZone(getParentCompanyTimeZoneString());
-        $localdt = new DateTime($refgmtdate, $localtz);
-        $tmp=-1*$localtz->getOffset($localdt);
-    }
-    else
-    {
-        // Method 2 (does not include daylight)
-        $tmp=dol_mktime(0,0,0,1,1,1970);
-    }
-    $tz=($tmp<0?1:-1)*abs($tmp/3600);
-    return $tz;
-}*/
-
 
 /**
  *  Add a delay to a date
  *
  *  @param      int			$time               Date timestamp (or string with format YYYY-MM-DD)
  *  @param      int			$duration_value     Value of delay to add
- *  @param      int			$duration_unit      Unit of added delay (d, m, y, w)
- *  @return     int      			        New timestamp
+ *  @param      int			$duration_unit      Unit of added delay (d, m, y, w, h)
+ *  @return     int      			        	New timestamp
  */
-function dol_time_plus_duree($time,$duration_value,$duration_unit)
+function dol_time_plus_duree($time, $duration_value, $duration_unit)
 {
 	if ($duration_value == 0)  return $time;
+	if ($duration_unit == 'h') return $time + (3600*$duration_value);
 	if ($duration_unit == 'w') return $time + (3600*24*7*$duration_value);
-	if ($duration_value > 0) $deltastring="+".abs($duration_value);
-	if ($duration_value < 0) $deltastring="-".abs($duration_value);
-	if ($duration_unit == 'd') { $deltastring.=" day"; }
-	if ($duration_unit == 'm') { $deltastring.=" month"; }
-	if ($duration_unit == 'y') { $deltastring.=" year"; }
-	return strtotime($deltastring,$time);
+	
+	$deltastring='P';
+	
+	if ($duration_value > 0){ $deltastring.=abs($duration_value); $sub= false; }
+	if ($duration_value < 0){ $deltastring.=abs($duration_value); $sub= true; }
+	if ($duration_unit == 'd') { $deltastring.="D"; }
+	if ($duration_unit == 'm') { $deltastring.="M"; }
+	if ($duration_unit == 'y') { $deltastring.="Y"; }
+	
+	$date = new DateTime();
+	$date->setTimezone(new DateTimeZone('UTC'));
+	$date->setTimestamp($time);
+	$interval = new DateInterval($deltastring);
+	
+	if($sub) $date->sub($interval);
+	else $date->add( $interval );
+	
+	return $date->getTimestamp();
 }
 
 
@@ -202,10 +156,10 @@ function convertTime2Seconds($iHours=0,$iMinutes=0,$iSeconds=0)
 /**	  	Return, in clear text, value of a number of seconds in days, hours and minutes
  *
  *    	@param      int		$iSecond		Number of seconds
- *    	@param      string	$format		    Output format (all: total delay days hour:min like "2 days 12:30"", allhourmin: total delay hours:min like "60:30", allhour: total delay hours without min/sec like "60:30", fullhour: total delay hour decimal like "60.5" for 60:30, hour: only hours part "12", min: only minutes part "30", sec: only seconds part, month: only month part, year: only year part);
+ *    	@param      string	$format		    Output format ('all': total delay days hour:min like "2 days 12:30", 'allwithouthour': total delay days without hour part like "2 days", 'allhourmin': total delay with format hours:min like "60:30", 'allhour': total delay hours without min/sec like "60:30", 'fullhour': total delay hour decimal like "60.5" for 60:30, 'hour': only hours part "12", 'min': only minutes part "30", 'sec': only seconds part, 'month': only month part, 'year': only year part);
  *      @param      int		$lengthOfDay    Length of day (default 86400 seconds for 1 day, 28800 for 8 hour)
  *      @param      int		$lengthOfWeek   Length of week (default 7)
- *    	@return     sTime		 		 	Formated text of duration
+ *    	@return     string		 		 	Formated text of duration
  * 	                                		Example: 0 return 00:00, 3600 return 1:00, 86400 return 1d, 90000 return 1 Day 01:00
  */
 function convertSecondToTime($iSecond, $format='all', $lengthOfDay=86400, $lengthOfWeek=7)
@@ -215,13 +169,13 @@ function convertSecondToTime($iSecond, $format='all', $lengthOfDay=86400, $lengt
 	if (empty($lengthOfDay))  $lengthOfDay = 86400;         // 1 day = 24 hours
     if (empty($lengthOfWeek)) $lengthOfWeek = 7;            // 1 week = 7 days
 
-	if ($format == 'all' || $format == 'allhour' || $format == 'allhourmin')
+	if ($format == 'all' || $format == 'allwithouthour' || $format == 'allhour' || $format == 'allhourmin')
 	{
-		if ($iSecond === 0) return '0';	// This is to avoid having 0 return a 12:00 AM for en_US
+		if ((int) $iSecond === 0) return '0';	// This is to avoid having 0 return a 12:00 AM for en_US
 
         $sTime='';
         $sDay=0;
-        $sWeek='';
+        $sWeek=0;
 
 		if ($iSecond >= $lengthOfDay)
 		{
@@ -264,7 +218,7 @@ function convertSecondToTime($iSecond, $format='all', $lengthOfDay=86400, $lengt
 		}
 		if ($format == 'allhourmin')
 		{
-			return sprintf("%02d",($sWeek*$lengthOfWeek*24 + $sDay*24 + (int) floor($iSecond/3600))).':'.sprintf("%02d",((int) floor(($iSecond % 3600)/60)));
+		    return sprintf("%02d",($sWeek*$lengthOfWeek*24 + $sDay*24 + (int) floor($iSecond/3600))).':'.sprintf("%02d",((int) floor(($iSecond % 3600)/60)));
 		}
 		if ($format == 'allhour')
 		{
@@ -307,14 +261,15 @@ function convertSecondToTime($iSecond, $format='all', $lengthOfDay=86400, $lengt
 
 /**
  *	Convert a string date into a GM Timestamps date
+ *	Warning: YYYY-MM-DDTHH:MM:SS+02:00 (RFC3339) is not supported. If parameter gm is 1, we will use no TZ, if not we will use TZ of server, not the one inside string.
  *
  *	@param	string	$string		Date in a string
  *				     	        YYYYMMDD
  *	                 			YYYYMMDDHHMMSS
  *								YYYYMMDDTHHMMSSZ
  *								YYYY-MM-DDTHH:MM:SSZ (RFC3339)
- *		                		DD/MM/YY or DD/MM/YYYY (this format should not be used anymore)
- *		                		DD/MM/YY HH:MM:SS or DD/MM/YYYY HH:MM:SS (this format should not be used anymore)
+ *		                		DD/MM/YY or DD/MM/YYYY (deprecated)
+ *		                		DD/MM/YY HH:MM:SS or DD/MM/YYYY HH:MM:SS (deprecated)
  *  @param	int		$gm         1 =Input date is GM date,
  *                              0 =Input date is local date using PHP server timezone
  *  @return	int					Date as a timestamp
@@ -327,7 +282,7 @@ function dol_stringtotime($string, $gm=1)
     // Convert date with format DD/MM/YYY HH:MM:SS. This part of code should not be used.
     if (preg_match('/^([0-9]+)\/([0-9]+)\/([0-9]+)\s?([0-9]+)?:?([0-9]+)?:?([0-9]+)?/i',$string,$reg))
     {
-        dol_syslog("dol_stringtotime call to function with deprecated parameter", LOG_WARNING);
+        dol_syslog("dol_stringtotime call to function with deprecated parameter format", LOG_WARNING);
         // Date est au format 'DD/MM/YY' ou 'DD/MM/YY HH:MM:SS'
         // Date est au format 'DD/MM/YYYY' ou 'DD/MM/YYYY HH:MM:SS'
         $sday = $reg[1];
@@ -341,8 +296,8 @@ function dol_stringtotime($string, $gm=1)
         $string=sprintf("%04d%02d%02d%02d%02d%02d",$syear,$smonth,$sday,$shour,$smin,$ssec);
     }
     else if (
-    	   preg_match('/^([0-9]{4})-([0-9]{2})-([0-9]{2})T([0-9]{2}):([0-9]{2}):([0-9]{2})Z$/i',$string,$reg)	// Convert date with format RFC3339
-		|| preg_match('/^([0-9]{4})-([0-9]{2})-([0-9]{2}) ([0-9]{2}):([0-9]{2}):([0-9]{2})$/i',$string,$reg)	// Convert date with format YYYY-MM-DD HH:MM:SS
+    	   preg_match('/^([0-9]{4})-([0-9]{2})-([0-9]{2})T([0-9]{2}):([0-9]{2}):([0-9]{2})Z$/i',$string,$reg)	// Convert date with format YYYY-MM-DDTHH:MM:SSZ (RFC3339)
+    	|| preg_match('/^([0-9]{4})-([0-9]{2})-([0-9]{2}) ([0-9]{2}):([0-9]{2}):([0-9]{2})$/i',$string,$reg)	// Convert date with format YYYY-MM-DD HH:MM:SS
    		|| preg_match('/^([0-9]{4})([0-9]{2})([0-9]{2})T([0-9]{2})([0-9]{2})([0-9]{2})Z$/i',$string,$reg)		// Convert date with format YYYYMMDDTHHMMSSZ
     )
     {
@@ -476,13 +431,14 @@ function dol_get_next_week($day, $week, $month, $year)
  *
  *	@param		int			$year		Year
  * 	@param		int			$month		Month
- * 	@param		boolean		$gm			False = Return date to compare with server TZ, True to compare with GM date.
+ * 	@param		mixed		$gm			False or 0 or 'server' = Return date to compare with server TZ, True or 1 to compare with GM date.
  *                          			Exemple: dol_get_first_day(1970,1,false) will return -3600 with TZ+1, after a dol_print_date will return 1970-01-01 00:00:00
  *                          			Exemple: dol_get_first_day(1970,1,true) will return 0 whatever is TZ, after a dol_print_date will return 1970-01-01 00:00:00
- *  @return		timestamp				Date for first day
+ *  @return		int						Date for first day, '' if error
  */
 function dol_get_first_day($year,$month=1,$gm=false)
 {
+	if ($year > 9999) return '';
 	return dol_mktime(0,0,0,$month,1,$year,$gm);
 }
 
@@ -491,11 +447,12 @@ function dol_get_first_day($year,$month=1,$gm=false)
  *
  *	@param		int			$year		Year
  * 	@param		int			$month		Month
- * 	@param		boolean		$gm			False = Return date to compare with server TZ, True to compare with GM date.
- *	@return		timestamp				Date for first day
+ * 	@param		boolean		$gm			False or 0 or 'server' = Return date to compare with server TZ, True or 1 to compare with GM date.
+ *	@return		int						Date for first day, '' if error
  */
 function dol_get_last_day($year,$month=12,$gm=false)
 {
+	if ($year > 9999) return '';
 	if ($month == 12)
 	{
 		$month = 1;
@@ -513,34 +470,36 @@ function dol_get_last_day($year,$month=12,$gm=false)
 	return $datelim;
 }
 
-/**	Return first day of week for a date
+/**	Return first day of week for a date. First day of week may be monday if option MAIN_START_WEEK is 1.
  *
  *	@param		int		$day		Day
  * 	@param		int		$month		Month
  *  @param		int		$year		Year
  * 	@param		int		$gm			False or 0 or 'server' = Return date to compare with server TZ, True or 1 to compare with GM date.
- *	@return		array				year,month,week,first_day,prev_year,prev_month,prev_day
+ *	@return		array				year,month,week,first_day,first_month,first_year,prev_day,prev_month,prev_year
  */
 function dol_get_first_day_week($day,$month,$year,$gm=false)
 {
 	global $conf;
 
+	//$day=2; $month=2; $year=2015;
 	$date = dol_mktime(0,0,0,$month,$day,$year,$gm);
 
 	//Checking conf of start week
 	$start_week = (isset($conf->global->MAIN_START_WEEK)?$conf->global->MAIN_START_WEEK:1);
 
-	$tmparray = dol_getdate($date,true);
+	$tmparray = dol_getdate($date,true);	// detail of current day
 
-	//Calculate days to count
+	//Calculate days = offset from current day
 	$days = $start_week - $tmparray['wday'];
  	if ($days>=1) $days=7-$days;
  	$days = abs($days);
     $seconds = $days*24*60*60;
+	//print 'start_week='.$start_week.' tmparray[wday]='.$tmparray['wday'].' day offset='.$days.' seconds offset='.$seconds.'<br>';
 
     //Get first day of week
-    $tmpday = date($tmparray[0])-$seconds;
-	$tmpday = date("d",$tmpday);
+    $tmpdaytms = date($tmparray[0])-$seconds; // $tmparray[0] is day of parameters
+	$tmpday = date("d",$tmpdaytms);
 
 	//Check first day of week is in same month than current day or not
 	if ($tmpday>$day)
@@ -587,19 +546,26 @@ function dol_get_first_day_week($day,$month,$year,$gm=false)
 }
 
 /**
- *	Fonction retournant le nombre de jour feries samedis et dimanches entre 2 dates entrees en timestamp
+ *	Fonction retournant le nombre de jour feries, samedis et dimanches entre 2 dates entrees en timestamp. Dates must be UTC with hour, day, min to 0
  *	Called by function num_open_day
  *
- *	@param	    timestamp	$timestampStart     Timestamp de debut
- *	@param	    timestamp	$timestampEnd       Timestamp de fin
+ *	@param	    int			$timestampStart     Timestamp de debut
+ *	@param	    int			$timestampEnd       Timestamp de fin
  *  @param      string		$countrycode        Country code
+ *	@param      int			$lastday            Last day is included, 0: no, 1:yes
  *	@return   	int								Nombre de jours feries
+ *  @see num_between_day, num_open_day
  */
-function num_public_holiday($timestampStart, $timestampEnd, $countrycode='FR')
+function num_public_holiday($timestampStart, $timestampEnd, $countrycode='FR', $lastday=0)
 {
 	$nbFerie = 0;
 
-	while ($timestampStart != $timestampEnd)
+	// Check to ensure we use correct parameters
+	if ((($timestampEnd - $timestampStart) % 86400) != 0) return 'ErrorDates must use same hours and must be GMT dates';
+
+	$i=0;
+	while (( ($lastday == 0 && $timestampStart < $timestampEnd) || ($lastday && $timestampStart <= $timestampEnd) )
+	    && ($i < 50000))		// Loop end when equals (Test on i is a security loop to avoid infinite loop)
 	{
 		$ferie=false;
 		$countryfound=0;
@@ -607,7 +573,6 @@ function num_public_holiday($timestampStart, $timestampEnd, $countrycode='FR')
 		$jour  = date("d", $timestampStart);
 		$mois  = date("m", $timestampStart);
 		$annee = date("Y", $timestampStart);
-
 		if ($countrycode == 'FR')
 		{
 			$countryfound=1;
@@ -696,6 +661,49 @@ function num_public_holiday($timestampStart, $timestampEnd, $countrycode='FR')
 			//Samedi (6) et dimanche (0)
 		}
 
+		if ($countrycode == 'ES')
+		{
+			$countryfound=1;
+
+			// Definition des dates feriees fixes
+			if($jour == 1 && $mois == 1)   $ferie=true; // Año nuevo
+			if($jour == 6 && $mois == 1)   $ferie=true; // Día Reyes
+			if($jour == 1 && $mois == 5)   $ferie=true; // 1 Mayo
+			if($jour == 15 && $mois == 8)  $ferie=true; // 15 Agosto
+			if($jour == 12 && $mois == 10)  $ferie=true; // Día Hispanidad
+			if($jour == 1 && $mois == 11)  $ferie=true; // 1 noviembre
+			if($jour == 6 && $mois == 12) $ferie=true; // Constitución
+			if($jour == 8 && $mois == 12)  $ferie=true; // Inmaculada
+			if($jour == 25 && $mois == 12) $ferie=true; // 25 diciembre
+
+			// Calcul día de Pascua
+			$date_paques = easter_date($annee);
+			$jour_paques = date("d", $date_paques);
+			$mois_paques = date("m", $date_paques);
+			if($jour_paques == $jour && $mois_paques == $mois) $ferie=true;
+			// Paques
+
+			// Viernes Santo
+            $date_viernes = mktime(
+                date("H", $date_paques),
+                date("i", $date_paques),
+                date("s", $date_paques),
+                date("m", $date_paques),
+                date("d", $date_paques) -2,
+                date("Y", $date_paques)
+            );
+			$jour_viernes = date("d", $date_viernes);
+			$mois_viernes = date("m", $date_viernes);
+			if($jour_viernes == $jour && $mois_viernes == $mois) $ferie=true;
+			//Viernes Santo
+
+			// Calul des samedis et dimanches
+			$jour_julien = unixtojd($timestampStart);
+			$jour_semaine = jddayofweek($jour_julien, 0);
+			if($jour_semaine == 0 || $jour_semaine == 6) $ferie=true;
+			//Samedi (6) et dimanche (0)
+		}
+
 		// Cas pays non defini
 		if (! $countryfound)
 		{
@@ -709,22 +717,25 @@ function num_public_holiday($timestampStart, $timestampEnd, $countrycode='FR')
 		// On incremente compteur
 		if ($ferie) $nbFerie++;
 
-		// Incrementation du nombre de jour (on avance dans la boucle)
-		$jour++;
-		$timestampStart=mktime(0,0,0,$mois,$jour,$annee);
+		// Increase number of days (on go up into loop)
+		$timestampStart=dol_time_plus_duree($timestampStart, 1, 'd');
+		//var_dump($jour.' '.$mois.' '.$annee.' '.$timestampStart);
+
+		$i++;
 	}
 
 	return $nbFerie;
 }
 
 /**
- *	Fonction retournant le nombre de jour entre deux dates
+ *	Function to return number of days between two dates (date must be UTC date !)
  *  Example: 2012-01-01 2012-01-02 => 1 if lastday=0, 2 if lastday=1
  *
- *	@param	   timestamp	$timestampStart     Timestamp de debut
- *	@param	   timestamp	$timestampEnd       Timestamp de fin
- *	@param     int			$lastday            Last day is included, 0: non, 1:oui
+ *	@param	   int			$timestampStart     Timestamp start UTC
+ *	@param	   int			$timestampEnd       Timestamp end UTC
+ *	@param     int			$lastday            Last day is included, 0: no, 1:yes
  *	@return    int								Number of days
+ *  @see also num_public_holiday, num_open_day
  */
 function num_between_day($timestampStart, $timestampEnd, $lastday=0)
 {
@@ -747,18 +758,22 @@ function num_between_day($timestampStart, $timestampEnd, $lastday=0)
 /**
  *	Function to return number of working days (and text of units) between two dates (working days)
  *
- *	@param	   	timestamp	$timestampStart     Timestamp for start date
- *	@param	   	timestamp	$timestampEnd       Timestamp for end date
- *	@param     	int			$inhour             0: return number of days, 1: return number of hours (72h max)
+ *	@param	   	int			$timestampStart     Timestamp for start date (date must be UTC to avoid calculation errors)
+ *	@param	   	int			$timestampEnd       Timestamp for end date (date must be UTC to avoid calculation errors)
+ *	@param     	int			$inhour             0: return number of days, 1: return number of hours
  *	@param		int			$lastday            We include last day, 0: no, 1:yes
  *  @param		int			$halfday			Tag to define half day when holiday start and end
+ *  @param      string		$country_code       Country code (company country code if not defined)
  *	@return    	int								Number of days or hours
+ *  @see also num_between_day, num_public_holiday
  */
-function num_open_day($timestampStart, $timestampEnd, $inhour=0, $lastday=0, $halfday=0)
+function num_open_day($timestampStart, $timestampEnd, $inhour=0, $lastday=0, $halfday=0, $country_code='')
 {
-	global $langs;
+	global $langs,$mysoc;
 
-	dol_syslog('num_open_day timestampStart='.$timestampStart.' timestampEnd='.$timestampEnd.' bit='.$lastday);
+	if (empty($country_code)) $country_code=$mysoc->country_code;
+
+	dol_syslog('num_open_day timestampStart='.$timestampStart.' timestampEnd='.$timestampEnd.' bit='.$lastday.' country_code='.$country_code);
 
 	// Check parameters
 	if (! is_int($timestampStart) && ! is_float($timestampStart)) return 'ErrorBadParameter_num_open_day';
@@ -767,8 +782,9 @@ function num_open_day($timestampStart, $timestampEnd, $inhour=0, $lastday=0, $ha
 	//print 'num_open_day timestampStart='.$timestampStart.' timestampEnd='.$timestampEnd.' bit='.$lastday;
 	if ($timestampStart < $timestampEnd)
 	{
-		//print num_between_day($timestampStart, $timestampEnd, $lastday).' - '.num_public_holiday($timestampStart, $timestampEnd);
-		$nbOpenDay = num_between_day($timestampStart, $timestampEnd, $lastday) - num_public_holiday($timestampStart, $timestampEnd, $lastday);
+		$numdays = num_between_day($timestampStart, $timestampEnd, $lastday);
+		$numholidays = num_public_holiday($timestampStart, $timestampEnd, $country_code, $lastday);
+		$nbOpenDay = $numdays - $numholidays;
 		$nbOpenDay.= " " . $langs->trans("Days");
 		if ($inhour == 1 && $nbOpenDay <= 3) $nbOpenDay = $nbOpenDay*24 . $langs->trans("HourShort");
 		return $nbOpenDay - (($inhour == 1 ? 12 : 0.5) * abs($halfday));
@@ -792,11 +808,12 @@ function num_open_day($timestampStart, $timestampEnd, $inhour=0, $lastday=0, $ha
  *  This replace old function monthArrayOrSelected.
  *
  *	@param	Translate	$outputlangs	Object langs
+ *  @param	int			$short			1=Return short label
  *	@return array						Month string or array if selected < 0
  */
-function monthArray($outputlangs)
+function monthArray($outputlangs,$short=0)
 {
-    $montharray = array (
+	$montharray = array (
 	    1  => $outputlangs->trans("January"),
 	    2  => $outputlangs->trans("February"),
 	    3  => $outputlangs->trans("March"),
@@ -811,7 +828,24 @@ function monthArray($outputlangs)
 	    12 => $outputlangs->trans("December")
     );
 
-    return $montharray;
+	if (! empty($short))
+	{
+		$montharray = array (
+		    1  => $outputlangs->trans("JanuaryMin"),
+		    2  => $outputlangs->trans("FebruaryMin"),
+		    3  => $outputlangs->trans("MarchMin"),
+		    4  => $outputlangs->trans("AprilMin"),
+		    5  => $outputlangs->trans("MayMin"),
+		    6  => $outputlangs->trans("JuneMin"),
+		    7  => $outputlangs->trans("JulyMin"),
+		    8  => $outputlangs->trans("AugustMin"),
+		    9  => $outputlangs->trans("SeptemberMin"),
+		    10 => $outputlangs->trans("OctoberMin"),
+		    11 => $outputlangs->trans("NovemberMin"),
+		    12 => $outputlangs->trans("DecemberMin")
+			);
+	}
+
+	return $montharray;
 }
 
-?>
