@@ -59,9 +59,11 @@ function getURLContent($url,$postorget='GET',$param='',$followlocation=1,$addhea
 	if (count($addheaders)) curl_setopt($ch, CURLOPT_HTTPHEADER, $addheaders);
 	curl_setopt($ch, CURLINFO_HEADER_OUT, true);	// To be able to retrieve request header and log it
 
-	// TLSv1 by default or change to TLSv1.2 in module configuration
-    //curl_setopt($ch, CURLOPT_SSLVERSION, (empty($conf->global->MAIN_CURL_SSLVERSION)?1:$conf->global->MAIN_CURL_SSLVERSION));
-    
+	// By default use tls decied by PHP.
+	// You can force, if supported a version like TLSv1 or TLSv1.2
+	if (! empty($conf->global->MAIN_CURL_SSLVERSION)) curl_setopt($ch, CURLOPT_SSLVERSION, $conf->global->MAIN_CURL_SSLVERSION);
+	//curl_setopt($ch, CURLOPT_SSLVERSION, 6); for tls 1.2
+	
     //turning off the server and peer verification(TrustManager Concept).
     curl_setopt($ch, CURLOPT_SSL_VERIFYPEER, FALSE);
     curl_setopt($ch, CURLOPT_SSL_VERIFYHOST, FALSE);
@@ -117,29 +119,38 @@ function getURLContent($url,$postorget='GET',$param='',$followlocation=1,$addhea
     //getting response from server
     $response = curl_exec($ch);
 
-    $status = curl_getinfo($ch, CURLINFO_HEADER_OUT);	// Reading of request must be done after sending request
-    dol_syslog("getURLContent request=".$status);
-
+    $request = curl_getinfo($ch, CURLINFO_HEADER_OUT);	// Reading of request must be done after sending request
+    
+    dol_syslog("getURLContent request=".$request);
     dol_syslog("getURLContent response=".$response);
 
     $rep=array();
-    $rep['content']=$response;
-    $rep['curl_error_no']='';
-    $rep['curl_error_msg']='';
-
     if (curl_errno($ch))
     {
+        // Ad keys to $rep
+        $rep['content']=$response;
+        
         // moving to display page to display curl errors
 		$rep['curl_error_no']=curl_errno($ch);
         $rep['curl_error_msg']=curl_error($ch);
 
-		dol_syslog("getURLContent curl_error array is ".join(',',$rep));
+		dol_syslog("getURLContent response array is ".join(',',$rep));
     }
     else
     {
     	$info = curl_getinfo($ch);
-    	$rep['header_size']=$info['header_size'];
 
+    	// Ad keys to $rep
+    	$rep = $info;
+    	//$rep['header_size']=$info['header_size'];
+    	//$rep['http_code']=$info['http_code'];
+    	dol_syslog("getURLContent http_code=".$rep['http_code']);
+    	
+        // Add more keys to $rep
+        $rep['content']=$response;
+    	$rep['curl_error_no']='';
+    	$rep['curl_error_msg']='';
+    	 
     	//closing the curl
         curl_close($ch);
     }
