@@ -91,7 +91,7 @@ class modContrat extends DolibarrModules
 		$this->rights[$r][0] = 161;
 		$this->rights[$r][1] = 'Lire les contrats';
 		$this->rights[$r][2] = 'r';
-		$this->rights[$r][3] = 1;
+		$this->rights[$r][3] = 0;
 		$this->rights[$r][4] = 'lire';
 
 		$r++;
@@ -130,6 +130,11 @@ class modContrat extends DolibarrModules
 		$this->rights[$r][4] = 'export';
 
 		
+		// Menus
+		//-------
+		$this->menu = 1;        // This module add menu entries. They are coded into menu manager.
+		
+		
 		// Exports
 		//--------
 		$langs->load("contracts");
