@@ -76,5 +76,10 @@ class modMailmanSpip extends DolibarrModules
 		// Permissions
 		$this->rights = array();
 		$this->rights_class = 'clicktodial';
+		
+		// Menus
+		//-------
+		$this->menu = 1;        // This module add menu entries. They are coded into menu manager.
+		
 	}
 }
