@@ -73,7 +73,16 @@ class modPrelevement extends DolibarrModules
 
 		// Constants
 		$this->const = array();
-
+		$r=0;
+		
+		$this->const[$r][0] = "BANK_ADDON_PDF";
+		$this->const[$r][1] = "chaine";
+		$this->const[$r][2] = "sepamandate";
+		$this->const[$r][3] = 'Name of manager to generate SEPA mandate';
+		$this->const[$r][4] = 0;
+		$r++;
+		
+		
 		// Boxes
 		$this->boxes = array();
 
@@ -83,15 +92,15 @@ class modPrelevement extends DolibarrModules
 		$r=0;
 		$r++;
 		$this->rights[$r][0] = 151;
-		$this->rights[$r][1] = 'Read withdrawals';
+		$this->rights[$r][1] = 'Read direct debit payment orders';
 		$this->rights[$r][2] = 'r';
-		$this->rights[$r][3] = 1;
+		$this->rights[$r][3] = 0;
 		$this->rights[$r][4] = 'bons';
 		$this->rights[$r][5] = 'lire';
 
 		$r++;
 		$this->rights[$r][0] = 152;
-		$this->rights[$r][1] = 'Create/modify a withdrawals';
+		$this->rights[$r][1] = 'Create/modify a direct debit payment order';
 		$this->rights[$r][2] = 'w';
 		$this->rights[$r][3] = 0;
 		$this->rights[$r][4] = 'bons';
@@ -99,7 +108,7 @@ class modPrelevement extends DolibarrModules
 
 		$r++;
 		$this->rights[$r][0] = 153;
-		$this->rights[$r][1] = 'Send withdrawals to bank';
+		$this->rights[$r][1] = 'Send/Transmit direct debit payment orders';
 		$this->rights[$r][2] = 'a';
 		$this->rights[$r][3] = 0;
 		$this->rights[$r][4] = 'bons';
@@ -107,7 +116,7 @@ class modPrelevement extends DolibarrModules
 
 		$r++;
 		$this->rights[$r][0] = 154;
-		$this->rights[$r][1] = 'credit/refuse withdrawals';
+		$this->rights[$r][1] = 'Record Credits/Rejects of direct debit payment orders';
 		$this->rights[$r][2] = 'a';
 		$this->rights[$r][3] = 0;
 		$this->rights[$r][4] = 'bons';
@@ -120,6 +129,11 @@ class modPrelevement extends DolibarrModules
         $this->rights[2][4] = 'bons';
         $this->rights[2][5] = 'configurer';
 */
+		
+		// Menus
+		//-------
+		$this->menu = 1;        // This module add menu entries. They are coded into menu manager.
+		
 	}
 
 
@@ -138,7 +152,10 @@ class modPrelevement extends DolibarrModules
 		// Permissions
 		$this->remove($options);
 
-		$sql = array();
+		$sql = array(
+		    "DELETE FROM ".MAIN_DB_PREFIX."document_model WHERE nom = '".$this->const[0][2]."' AND type = 'bankaccount' AND entity = ".$conf->entity,
+		    "INSERT INTO ".MAIN_DB_PREFIX."document_model (nom, type, entity) VALUES('".$this->const[0][2]."','bankaccount',".$conf->entity.")",
+		);		
 
 		return $this->_init($sql,$options);
 	}
