@@ -25,6 +25,7 @@
 
 include_once DOL_DOCUMENT_ROOT.'/core/modules/printing/modules_printing.php';
 require_once DOL_DOCUMENT_ROOT.'/includes/OAuth/bootstrap.php';
+
 use OAuth\Common\Storage\DoliStorage;
 use OAuth\Common\Consumer\Credentials;
 use OAuth\OAuth2\Service\Google;
@@ -45,6 +46,8 @@ class printing_printgcp extends PrintingDriver
     var $errors = array();
     var $db;
 
+    private $OAUTH_SERVICENAME_GOOGLE = 'Google';
+    
     const LOGIN_URL = 'https://accounts.google.com/o/oauth2/token';
     const PRINTERS_SEARCH_URL = 'https://www.google.com/cloudprint/search';
     const PRINTERS_GET_JOBS = 'https://www.google.com/cloudprint/jobs';
@@ -63,6 +66,7 @@ class printing_printgcp extends PrintingDriver
         $urlwithouturlroot=preg_replace('/'.preg_quote(DOL_URL_ROOT,'/').'$/i','',trim($dolibarr_main_url_root));
         $urlwithroot=$urlwithouturlroot.DOL_URL_ROOT;		// This is to use external domain name found into config file
         //$urlwithroot=DOL_MAIN_URL_ROOT;					// This is to use same domain name than current
+
         $this->db = $db;
         
         if (!$conf->oauth->enabled) {
@@ -73,19 +77,19 @@ class printing_printgcp extends PrintingDriver
         	$this->google_secret = $conf->global->OAUTH_GOOGLE_SECRET;
         	// Token storage
         	$storage = new DoliStorage($this->db, $this->conf);
-        	//$storage->clearToken('Google');
+        	//$storage->clearToken($this->OAUTH_SERVICENAME_GOOGLE);
         	// Setup the credentials for the requests
         	$credentials = new Credentials(
             	$this->google_id,
             	$this->google_secret,
             	$urlwithroot.'/core/modules/oauth/google_oauthcallback.php'
         	);
-        	$access = ($storage->hasAccessToken('Google')?'HasAccessToken':'NoAccessToken');
+        	$access = ($storage->hasAccessToken($this->OAUTH_SERVICENAME_GOOGLE)?'HasAccessToken':'NoAccessToken');
         	$serviceFactory = new \OAuth\ServiceFactory();
-        	$apiService = $serviceFactory->createService('Google', $credentials, $storage, array());
+        	$apiService = $serviceFactory->createService($this->OAUTH_SERVICENAME_GOOGLE, $credentials, $storage, array());
         	$token_ok=true;
         	try {
-            	$token = $storage->retrieveAccessToken('Google');
+            	$token = $storage->retrieveAccessToken($this->OAUTH_SERVICENAME_GOOGLE);
         	} catch (Exception $e) {
             	$this->errors[] = $e->getMessage();
             	$token_ok = false;
@@ -105,24 +109,42 @@ class printing_printgcp extends PrintingDriver
                 	$refreshtoken = $token->getRefreshToken();
                 	$token = $apiService->refreshAccessToken($token);
                 	$token->setRefreshToken($refreshtoken);
-                	$storage->storeAccessToken('Google', $token);
+                	$storage->storeAccessToken($this->OAUTH_SERVICENAME_GOOGLE, $token);
             	} catch (Exception $e) {
                 	$this->errors[] = $e->getMessage();
             	}
         	}
             if ($this->google_id != '' && $this->google_secret != '') {
                 $this->conf[] = array('varname'=>'PRINTGCP_INFO', 'info'=>'GoogleAuthConfigured', 'type'=>'info');
-                $this->conf[] = array('varname'=>'PRINTGCP_TOKEN_ACCESS', 'info'=>$access, 'type'=>'info', 'renew'=>$urlwithroot.'/core/modules/oauth/google_oauthcallback.php?state=userinfo_email,userinfo_profile,cloud_print&backtourl='.urlencode(DOL_URL_ROOT.'/printing/admin/printing.php?mode=setup&driver=printgcp'), 'delete'=>($storage->hasAccessToken('Google')?$urlwithroot.'/core/modules/oauth/google_oauthcallback.php?action=delete&backtourl='.urlencode(DOL_URL_ROOT.'/printing/admin/printing.php?mode=setup&driver=printgcp'):''));
+                $this->conf[] = array('varname'=>'PRINTGCP_TOKEN_ACCESS', 'info'=>$access, 'type'=>'info', 'renew'=>$urlwithroot.'/core/modules/oauth/google_oauthcallback.php?state=userinfo_email,userinfo_profile,cloud_print&backtourl='.urlencode(DOL_URL_ROOT.'/printing/admin/printing.php?mode=setup&driver=printgcp'), 'delete'=>($storage->hasAccessToken($this->OAUTH_SERVICENAME_GOOGLE)?$urlwithroot.'/core/modules/oauth/google_oauthcallback.php?action=delete&backtourl='.urlencode(DOL_URL_ROOT.'/printing/admin/printing.php?mode=setup&driver=printgcp'):''));
                 if ($token_ok) {
+                    $expiredat='';
+                    
                     $refreshtoken = $token->getRefreshToken();
-                    $this->conf[] = array('varname'=>'PRINTGCP_TOKEN_REFRESH',   'info'=>((! empty($refreshtoken))?'Yes':'No'), 'type'=>'info');
-                    $this->conf[] = array('varname'=>'PRINTGCP_TOKEN_EXPIRED',   'info'=>($expire?'Yes':'No'), 'type'=>'info');
-                    $this->conf[] = array('varname'=>'PRINTGCP_TOKEN_EXPIRE_AT', 'info'=>(dol_print_date($token->getEndOfLife(), "dayhour")), 'type'=>'info');
+                    
+                    $endoflife=$token->getEndOfLife();
+
+                    if ($endoflife == $token::EOL_NEVER_EXPIRES)
+                    {
+                        $expiredat = $langs->trans("Never");
+                    }
+                    elseif ($endoflife == $token::EOL_UNKNOWN)
+                    {
+                        $expiredat = $langs->trans("Unknown");
+                    }
+                    else
+                    {
+                        $expiredat=dol_print_date($endoflife, "dayhour");
+                    }
+                    
+                    $this->conf[] = array('varname'=>'TOKEN_REFRESH',   'info'=>((! empty($refreshtoken))?'Yes':'No'), 'type'=>'info');
+                    $this->conf[] = array('varname'=>'TOKEN_EXPIRED',   'info'=>($expire?'Yes':'No'), 'type'=>'info');
+                    $this->conf[] = array('varname'=>'TOKEN_EXPIRE_AT', 'info'=>($expiredat), 'type'=>'info');
                 }
                 /*
-                if ($storage->hasAccessToken('Google')) {
+                if ($storage->hasAccessToken($this->OAUTH_SERVICENAME_GOOGLE)) {
                     $this->conf[] = array('varname'=>'PRINTGCP_AUTHLINK', 'link'=>$urlwithroot.'/core/modules/oauth/google_oauthcallback.php?backtourl='.urlencode(DOL_URL_ROOT.'/printing/admin/printing.php?mode=setup&driver=printgcp'), 'type'=>'authlink');
-                    $this->conf[] = array('varname'=>'PRINTGCP_DELETE_TOKEN', 'link'=>$urlwithroot.'/core/modules/oauth/google_oauthcallback.php?action=delete&backtourl='.urlencode(DOL_URL_ROOT.'/printing/admin/printing.php?mode=setup&driver=printgcp'), 'type'=>'delete');
+                    $this->conf[] = array('varname'=>'DELETE_TOKEN', 'link'=>$urlwithroot.'/core/modules/oauth/google_oauthcallback.php?action=delete&backtourl='.urlencode(DOL_URL_ROOT.'/printing/admin/printing.php?mode=setup&driver=printgcp'), 'type'=>'delete');
                 } else {
                     $this->conf[] = array('varname'=>'PRINTGCP_AUTHLINK', 'link'=>$urlwithroot.'/core/modules/oauth/google_oauthcallback.php?backtourl='.urlencode(DOL_URL_ROOT.'/printing/admin/printing.php?mode=setup&driver=printgcp'), 'type'=>'authlink');
                 }*/
@@ -202,11 +224,11 @@ class printing_printgcp extends PrintingDriver
             DOL_MAIN_URL_ROOT.'/core/modules/oauth/google_oauthcallback.php'
         );
         $serviceFactory = new \OAuth\ServiceFactory();
-        $apiService = $serviceFactory->createService('Google', $credentials, $storage, array());
+        $apiService = $serviceFactory->createService($this->OAUTH_SERVICENAME_GOOGLE, $credentials, $storage, array());
         // Check if we have auth token
         $token_ok=true;
         try {
-            $token = $storage->retrieveAccessToken('Google');
+            $token = $storage->retrieveAccessToken($this->OAUTH_SERVICENAME_GOOGLE);
         } catch (Exception $e) {
             $this->errors[] = $e->getMessage();
             $token_ok = false;
@@ -224,7 +246,7 @@ class printing_printgcp extends PrintingDriver
                 $refreshtoken = $token->getRefreshToken();
                 $token = $apiService->refreshAccessToken($token);
                 $token->setRefreshToken($refreshtoken);
-                $storage->storeAccessToken('Google', $token);
+                $storage->storeAccessToken($this->OAUTH_SERVICENAME_GOOGLE, $token);
             } catch (Exception $e) {
                 $this->errors[] = $e->getMessage();
             }
@@ -340,12 +362,12 @@ class printing_printgcp extends PrintingDriver
             DOL_MAIN_URL_ROOT.'/core/modules/oauth/google_oauthcallback.php?service=google'
         );
         $serviceFactory = new \OAuth\ServiceFactory();
-        $apiService = $serviceFactory->createService('Google', $credentials, $storage, array());
+        $apiService = $serviceFactory->createService($this->OAUTH_SERVICENAME_GOOGLE, $credentials, $storage, array());
 
         // Check if we have auth token and refresh it
         $token_ok=true;
         try {
-            $token = $storage->retrieveAccessToken('Google');
+            $token = $storage->retrieveAccessToken($this->OAUTH_SERVICENAME_GOOGLE);
         } catch (Exception $e) {
             $this->errors[] = $e->getMessage();
             $token_ok = false;
@@ -356,7 +378,7 @@ class printing_printgcp extends PrintingDriver
                 $refreshtoken = $token->getRefreshToken();
                 $token = $apiService->refreshAccessToken($token);
                 $token->setRefreshToken($refreshtoken);
-                $storage->storeAccessToken('Google', $token);
+                $storage->storeAccessToken($this->OAUTH_SERVICENAME_GOOGLE, $token);
             } catch (Exception $e) {
                 $this->errors[] = $e->getMessage();
             }
@@ -389,11 +411,11 @@ class printing_printgcp extends PrintingDriver
             DOL_MAIN_URL_ROOT.'/core/modules/oauth/google_oauthcallback.php'
         );
         $serviceFactory = new \OAuth\ServiceFactory();
-        $apiService = $serviceFactory->createService('Google', $credentials, $storage, array());
+        $apiService = $serviceFactory->createService($this->OAUTH_SERVICENAME_GOOGLE, $credentials, $storage, array());
         // Check if we have auth token
         $token_ok=true;
         try {
-            $token = $storage->retrieveAccessToken('Google');
+            $token = $storage->retrieveAccessToken($this->OAUTH_SERVICENAME_GOOGLE);
         } catch (Exception $e) {
             $this->errors[] = $e->getMessage();
             $token_ok = false;
@@ -412,7 +434,7 @@ class printing_printgcp extends PrintingDriver
                 $refreshtoken = $token->getRefreshToken();
                 $token = $apiService->refreshAccessToken($token);
                 $token->setRefreshToken($refreshtoken);
-                $storage->storeAccessToken('Google', $token);
+                $storage->storeAccessToken($this->OAUTH_SERVICENAME_GOOGLE, $token);
             } catch (Exception $e) {
                 $this->errors[] = $e->getMessage();
                 $error++;
@@ -428,14 +450,16 @@ class printing_printgcp extends PrintingDriver
         }
         $responsedata = json_decode($response, true);
         //$html .= '<pre>'.print_r($responsedata,true).'</pre>';
+        $html .= '<div class="div-table-responsive">';
         $html .= '<table width="100%" class="noborder">';
         $html .= '<tr class="liste_titre">';
-        $html .= "<td>Id</td>";
-        $html .= "<td>Owner</td>";
-        $html .= '<td>Printer</td>';
-        $html .= '<td>File</td>';
-        $html .= '<td>Status</td>';
-        $html .= '<td>Cancel</td>';
+        $html .= '<td>'.$langs->trans("Id").'</td>';
+        $html .= '<td>'.$langs->trans("Date").'</td>';
+        $html .= '<td>'.$langs->trans("Owner").'</td>';
+        $html .= '<td>'.$langs->trans("Printer").'</td>';
+        $html .= '<td>'.$langs->trans("Filename").'</td>';
+        $html .= '<td>'.$langs->trans("Status").'</td>';
+        $html .= '<td>'.$langs->trans("Cancel").'</td>';
         $html .= '</tr>'."\n";
         $var = True;
         $jobs = $responsedata['jobs'];
@@ -447,6 +471,8 @@ class printing_printgcp extends PrintingDriver
                 $var = !$var;
                 $html .= '<tr '.$bc[$var].'>';
                 $html .= '<td>'.$value['id'].'</td>';
+                $dates=dol_print_date((int) substr($value['createTime'], 0, 10), 'dayhour');
+                $html .= '<td>'.$dates.'</td>';
                 $html .= '<td>'.$value['ownerId'].'</td>';
                 $html .= '<td>'.$value['printerName'].'</td>';
                 $html .= '<td>'.$value['title'].'</td>';
@@ -458,10 +484,11 @@ class printing_printgcp extends PrintingDriver
         else
         {
                 $html .= '<tr '.$bc[$var].'>';
-                $html .= '<td colspan="6" class="opacitymedium">'.$langs->trans("None").'</td>';
+                $html .= '<td colspan="7" class="opacitymedium">'.$langs->trans("None").'</td>';
                 $html .= '</tr>';
         }
         $html .= '</table>';
+        $html .= '</div>';
         
         $this->resprint = $html;
         
