@@ -417,9 +417,6 @@ class Cronjob extends CommonObject
 
     	$sqlwhere = array();
 
-    	if (!empty($module_name)) {
-    		$sqlwhere[]='(t.module_name='.$module_name.')';
-    	}
     	if (count($sqlwhere)>0) {
     		$sql.= " WHERE ".implode(' AND ',$sqlwhere);
     	}
@@ -962,7 +959,7 @@ class Cronjob extends CommonObject
 				// Create Object for the call module
 				$object = new $this->objectname($this->db);
 	
-				$params_arr = explode(", ",$this->params);
+				$params_arr = array_map('trim', explode(",",$this->params));
 				if (!is_array($params_arr))
 				{
 					$result = call_user_func(array($object, $this->methodename), $this->params);
