@@ -37,7 +37,7 @@ if (! empty($conf->propal->enabled)) require_once DOL_DOCUMENT_ROOT.'/comm/propa
 if (! empty($conf->commande->enabled)) require_once DOL_DOCUMENT_ROOT.'/commande/class/commande.class.php';
 if (! empty($conf->productbatch->enabled)) require_once DOL_DOCUMENT_ROOT.'/expedition/class/expeditionbatch.class.php';
 
- 
+
 /**
  *	Class to manage shipments
  */
@@ -48,6 +48,7 @@ class Expedition extends CommonObject
 	public $table_element="expedition";
 	public $table_element_line="expeditiondet";
 	protected $ismultientitymanaged = 1;	// 0=No test on entity, 1=Test with field entity, 2=Test with link by societe
+    public $picto = 'sending';
 
 	var $socid;
 	var $ref_customer;
@@ -93,13 +94,13 @@ class Expedition extends CommonObject
 	var $meths;
 	var $listmeths;			// List of carriers
 
-	
+
 	const STATUS_DRAFT = 0;
 	const STATUS_VALIDATED = 1;
 	const STATUS_CLOSED = 2;
-	
-	
-	
+
+
+
 	/**
 	 *	Constructor
 	 *
@@ -179,7 +180,7 @@ class Expedition extends CommonObject
 	 *  Create expedition en base
 	 *
 	 *  @param	User	$user       Objet du user qui cree
-   * 	@param		int		$notrigger	1=Does not execute triggers, 0= execuete triggers
+   * 	@param		int		$notrigger	1=Does not execute triggers, 0= execute triggers
 	 *  @return int 				<0 si erreur, id expedition creee si ok
 	 */
 	function create($user, $notrigger=0)
@@ -290,7 +291,7 @@ class Expedition extends CommonObject
 						$error++;
 					}
 				}
-				
+
 				// Actions on extra fields (by external module or standard code)
 				// TODO le hook fait double emploi avec le trigger !!
 				$hookmanager->initHooks(array('expeditiondao'));
@@ -364,7 +365,7 @@ class Expedition extends CommonObject
 	 * @param 	int		$entrepot_id		Id of warehouse
 	 * @param 	int		$origin_line_id		Id of source line
 	 * @param 	int		$qty				Quantity
-	 * @param	array		$array_options		extrafields array
+	 * @param	array	$array_options		extrafields array
 	 * @return	int							<0 if KO, line_id if OK
 	 */
 	function create_line($entrepot_id, $origin_line_id, $qty,$array_options=0)
@@ -386,14 +387,17 @@ class Expedition extends CommonObject
 		$sql.= ")";
 
 		dol_syslog(get_class($this)."::create_line", LOG_DEBUG);
-		if (! $this->db->query($sql))
+		$resql = $this->db->query($sql);
+		if ($resql)
+		{
+		    $line_id = $this->db->last_insert_id(MAIN_DB_PREFIX."expeditiondet");
+		}
+		else
 		{
 			$error++;
 		}
-		
-		if (! $error) $line_id = $this->db->last_insert_id(MAIN_DB_PREFIX."expeditiondet");
-		
-		if (!$error && empty($conf->global->MAIN_EXTRAFIELDS_DISABLED) && is_array($array_options) && count($array_options)>0) // For avoid conflicts if trigger used
+
+		if (! $error && empty($conf->global->MAIN_EXTRAFIELDS_DISABLED) && is_array($array_options) && count($array_options)>0) // For avoid conflicts if trigger used
 		{
 			$expeditionline = new ExpeditionLigne($this->db);
 			$expeditionline->array_options=$array_options;
@@ -422,7 +426,7 @@ class Expedition extends CommonObject
 	{
 		$error = 0;
 		$stockLocationQty = array(); // associated array with batch qty in stock location
-		
+
 		$tab=$line_ext->detail_batch;
 		// create stockLocation Qty array
 		foreach ($tab as $detbatch)
@@ -449,7 +453,7 @@ class Expedition extends CommonObject
 						{
 							$error++;
 						}
-					}					
+					}
 				}
 			}
 		}
@@ -556,7 +560,7 @@ class Expedition extends CommonObject
 				 * Thirparty
 				 */
 				$result=$this->fetch_thirdparty();
-				
+
 				// Retrieve all extrafields for expedition
 				// fetch optionals attributes and labels
 				require_once DOL_DOCUMENT_ROOT.'/core/class/extrafields.class.php';
@@ -593,7 +597,7 @@ class Expedition extends CommonObject
 	 *  Validate object and update stock if option enabled
 	 *
 	 *  @param      User		$user       Object user that validate
-     *  @param		int			$notrigger	1=Does not execute triggers, 0= execuete triggers
+     *  @param		int			$notrigger	1=Does not execute triggers, 0= execute triggers
 	 *  @return     int						<0 if OK, >0 if KO
 	 */
 	function valid($user, $notrigger=0)
@@ -699,29 +703,29 @@ class Expedition extends CommonObject
 					//var_dump($this->lines[$i]);
 					$mouvS = new MouvementStock($this->db);
 					$mouvS->origin = &$this;
-					
+
 					if (empty($obj->edbrowid))
 					{
 						// line without batch detail
-						
+
 						// We decrement stock of product (and sub-products) -> update table llx_product_stock (key of this table is fk_product+fk_entrepot) and add a movement record.
 						$result=$mouvS->livraison($user, $obj->fk_product, $obj->fk_entrepot, $qty, $obj->subprice, $langs->trans("ShipmentValidatedInDolibarr",$numref));
 						if ($result < 0) {
-							$error++; 
-							$this->errors[]=$mouvS->error; 
+							$error++;
+							$this->errors[]=$mouvS->error;
 							break;
 						}
 					}
 					else
 					{
 						// line with batch detail
-						
+
 						// We decrement stock of product (and sub-products) -> update table llx_product_stock (key of this table is fk_product+fk_entrepot) and add a movement record.
 					    // Note: ->fk_origin_stock = id into table llx_product_batch (may be rename into llx_product_stock_batch in another version)
 						$result=$mouvS->livraison($user, $obj->fk_product, $obj->fk_entrepot, $qty, $obj->subprice, $langs->trans("ShipmentValidatedInDolibarr",$numref), '', $this->db->jdate($obj->eatby), $this->db->jdate($obj->sellby), $obj->batch, $obj->fk_origin_stock);
 						if ($result < 0) {
-							$error++; 
-							$this->errors[]=$mouvS->error; 
+							$error++;
+							$this->errors[]=$mouvS->error;
 							break;
 						}
 					}
@@ -733,18 +737,17 @@ class Expedition extends CommonObject
 				$this->error=$this->db->error();
 				return -2;
 			}
-			
-			// FIXME Set status of order to "delivered" if check box "set order as delivered if remain to ship is 0" is on and if sum of all validated shipment = products or order to ship (because we are in case of stock movement on shipment validation)
-			
+
 		}
 
 		// Change status of order to "shipment in process"
 		$ret = $this->setStatut(Commande::STATUS_SHIPMENTONPROCESS, $this->origin_id, $this->origin);
-		if (! $ret)
+
+        if (! $ret)
 		{
 		    $error++;
 		}
-		
+
 		if (! $error && ! $notrigger)
 		{
             // Call trigger
@@ -847,14 +850,14 @@ class Expedition extends CommonObject
 	}
 
 	/**
-	 * Add a expedition line.
+	 * Add an expedition line.
 	 * If STOCK_WAREHOUSE_NOT_REQUIRED_FOR_SHIPMENTS is set, you can add a shipment line, with no stock source defined
 	 * If STOCK_MUST_BE_ENOUGH_FOR_SHIPMENT is not set, you can add a shipment line, even if not enough into stock
 	 *
 	 * @param 	int		$entrepot_id		Id of warehouse
 	 * @param 	int		$id					Id of source line (order line)
 	 * @param 	int		$qty				Quantity
-	 * @param	array		$array_options		extrafields array
+	 * @param	array	$array_options		extrafields array
 	 * @return	int							<0 if KO, >0 if OK
 	 */
 	function addline($entrepot_id, $id, $qty,$array_options=0)
@@ -889,7 +892,7 @@ class Expedition extends CommonObject
 				$result=$product->fetch($fk_product);
 
 				if ($entrepot_id > 0) {
-					$product->load_stock();
+					$product->load_stock('warehouseopen');
 					$product_stock = $product->stock_warehouse[$entrepot_id]->real;
 				}
 				else
@@ -905,11 +908,18 @@ class Expedition extends CommonObject
 				}
 			}
 		}
-		
+
+		// If product need a batch number, we should not have called this function but addline_batch instead.
+		if (! empty($conf->productbatch->enabled) && ! empty($orderline->fk_product) && ! empty($orderline->product_tobatch))
+		{
+		    $this->error='ADDLINE_WAS_CALLED_INSTEAD_OF_ADDLINEBATCH';
+		    return -4;
+		}
+
 		// extrafields
 		if (empty($conf->global->MAIN_EXTRAFIELDS_DISABLED) && is_array($array_options) && count($array_options)>0) // For avoid conflicts if trigger used
 			$line->array_options = $array_options;
-		
+
 		$this->lines[$num] = $line;
 	}
 
@@ -962,7 +972,7 @@ class Expedition extends CommonObject
 							return -1;
 						}
 					}
-					
+
 					//var_dump($linebatch);
 				}
 			}
@@ -974,7 +984,7 @@ class Expedition extends CommonObject
 			// extrafields
 			if (empty($conf->global->MAIN_EXTRAFIELDS_DISABLED) && is_array($array_options) && count($array_options)>0) // For avoid conflicts if trigger used
 				$line->array_options = $array_options;
-			
+
 			//var_dump($line);
 			$this->lines[$num] = $line;
 			return 1;
@@ -1134,13 +1144,13 @@ class Expedition extends CommonObject
 				{
 					dol_syslog(get_class($this)."::delete movement index ".$i);
 					$obj = $this->db->fetch_object($resql);
-					
+
 					$mouvS = new MouvementStock($this->db);
 					// we do not log origin because it will be deleted
 					$mouvS->origin = null;
 					// get lot/serial
 					$lotArray = null;
-					if ($conf->productbatch->enabled) 
+					if ($conf->productbatch->enabled)
 					{
 						$lotArray = ExpeditionLineBatch::fetchAll($this->db,$obj->expeditiondet_id);
 						if (! is_array($lotArray))
@@ -1159,7 +1169,7 @@ class Expedition extends CommonObject
 							break;
 						}
 					}
-					else 
+					else
 					{
 						// We increment stock of batches
 						// We use warehouse selected for each line
@@ -1173,7 +1183,7 @@ class Expedition extends CommonObject
 							}
 						}
 						if ($error) break; // break for loop incase of error
-					} 
+					}
 				}
 			}
 			else
@@ -1181,7 +1191,7 @@ class Expedition extends CommonObject
 				$error++;$this->errors[]="Error ".$this->db->lasterror();
 			}
 		}
-		
+
 		// delete batch expedition line
 		if (! $error && $conf->productbatch->enabled)
 		{
@@ -1190,7 +1200,7 @@ class Expedition extends CommonObject
 				$error++;$this->errors[]="Error ".$this->db->lasterror();
 			}
 		}
-		
+
 		if (! $error)
 		{
 			$sql = "DELETE FROM ".MAIN_DB_PREFIX."expeditiondet";
@@ -1229,7 +1239,7 @@ class Expedition extends CommonObject
 						        }
 						    }
 						}
-						
+
 						if (! $error)
 						{
 							$this->db->commit();
@@ -1306,7 +1316,8 @@ class Expedition extends CommonObject
 
 		$sql = "SELECT cd.rowid, cd.fk_product, cd.label as custom_label, cd.description, cd.qty as qty_asked, cd.product_type";
 		$sql.= ", cd.total_ht, cd.total_localtax1, cd.total_localtax2, cd.total_ttc, cd.total_tva";
-		$sql.= ", cd.tva_tx, cd.localtax1_tx, cd.localtax2_tx, cd.price, cd.subprice, cd.remise_percent,cd.buy_price_ht as pa_ht";
+		$sql.= ", cd.vat_src_code, cd.tva_tx, cd.localtax1_tx, cd.localtax2_tx, cd.localtax1_type, cd.localtax2_type, cd.price, cd.subprice, cd.remise_percent,cd.buy_price_ht as pa_ht";
+		$sql.= ", cd.fk_multicurrency, cd.multicurrency_code, cd.multicurrency_subprice, cd.multicurrency_total_ht, cd.multicurrency_total_tva, cd.multicurrency_total_ttc";
 		$sql.= ", ed.rowid as line_id, ed.qty as qty_shipped, ed.fk_origin_line, ed.fk_entrepot";
 		$sql.= ", p.ref as product_ref, p.label as product_label, p.fk_product_type";
 		$sql.= ", p.weight, p.weight_units, p.length, p.length_units, p.surface, p.surface_units, p.volume, p.volume_units, p.tobatch as product_tobatch";
@@ -1378,9 +1389,11 @@ class Expedition extends CommonObject
 				$line->volume_units   	= $obj->volume_units;
 
 				$line->pa_ht 			= $obj->pa_ht;
-		    	
+
+				$localtax_array=array(0=>$obj->localtax1_type, 1=>$obj->localtax1_tx, 2=>$obj->localtax2_type, 3=>$obj->localtax2_tx);
+
 				// For invoicing
-				$tabprice = calcul_price_total($obj->qty_shipped, $obj->subprice, $obj->remise_percent, $obj->tva_tx, $obj->localtax1_tx, $obj->localtax2_tx, 0, 'HT', $obj->info_bits, $obj->fk_product_type, $mysoc);	// We force type to 0
+				$tabprice = calcul_price_total($obj->qty_shipped, $obj->subprice, $obj->remise_percent, $obj->tva_tx, $obj->localtax1_tx, $obj->localtax2_tx, 0, 'HT', $obj->info_bits, $obj->fk_product_type, $mysoc, $localtax_array);	// We force type to 0
 				$line->desc	         	= $obj->description;		// We need ->desc because some code into CommonObject use desc (property defined for other elements)
 				$line->qty 				= $line->qty_shipped;
 				$line->total_ht			= $tabprice[0];
@@ -1388,6 +1401,7 @@ class Expedition extends CommonObject
 				$line->total_localtax2 	= $tabprice[10];
 				$line->total_ttc	 	= $tabprice[2];
 				$line->total_tva	 	= $tabprice[1];
+				$line->vat_src_code	 	= $obj->vat_src_code;
 				$line->tva_tx 		 	= $obj->tva_tx;
 				$line->localtax1_tx 	= $obj->localtax1_tx;
 				$line->localtax2_tx 	= $obj->localtax2_tx;
@@ -1400,8 +1414,16 @@ class Expedition extends CommonObject
 				$this->total_ttc+= $tabprice[2];
 				$this->total_localtax1+= $tabprice[9];
 				$this->total_localtax2+= $tabprice[10];
-				
-				if ($originline != $obj->fk_origin_line) 
+
+				// Multicurrency
+				$this->fk_multicurrency 		= $obj->fk_multicurrency;
+				$this->multicurrency_code 		= $obj->multicurrency_code;
+				$this->multicurrency_subprice 	= $obj->multicurrency_subprice;
+				$this->multicurrency_total_ht 	= $obj->multicurrency_total_ht;
+				$this->multicurrency_total_tva 	= $obj->multicurrency_total_tva;
+				$this->multicurrency_total_ttc 	= $obj->multicurrency_total_ttc;
+
+				if ($originline != $obj->fk_origin_line)
 				{
 					$line->detail_batch = array();
 				}
@@ -1458,27 +1480,40 @@ class Expedition extends CommonObject
      *	@param      int			$option         Where point the link
      *	@param      int			$max          	Max length to show
      *	@param      int			$short			Use short labels
+     *  @param      int         $notooltip      1=No tooltip
      *	@return     string          			String with URL
      */
-	function getNomUrl($withpicto=0,$option=0,$max=0,$short=0)
+	function getNomUrl($withpicto=0,$option=0,$max=0,$short=0,$notooltip=0)
 	{
 		global $langs;
 
 		$result='';
         $label = '<u>' . $langs->trans("ShowSending") . '</u>';
-        if (! empty($this->ref))
-            $label .= '<br><b>' . $langs->trans('Ref') . ':</b> '.$this->ref;
+        $label .= '<br><b>' . $langs->trans('Ref') . ':</b> '.$this->ref;
+        $label .= '<br><b>'.$langs->trans('RefCustomer').':</b> '.($this->ref_customer ? $this->ref_customer : $this->ref_client);
 
 		$url = DOL_URL_ROOT.'/expedition/card.php?id='.$this->id;
 
 		if ($short) return $url;
 
+		$linkclose='';
+		if (empty($notooltip))
+		{
+		    if (! empty($conf->global->MAIN_OPTIMIZEFORTEXTBROWSER))
+		    {
+		        $label=$langs->trans("ShowSending");
+		        $linkclose.=' alt="'.dol_escape_htmltag($label, 1).'"';
+		    }
+		    $linkclose.= ' title="'.dol_escape_htmltag($label, 1).'"';
+		    $linkclose.=' class="classfortooltip"';
+		}
+
         $linkstart = '<a href="'.$url.'" title="'.dol_escape_htmltag($label, 1).'" class="classfortooltip">';
 		$linkend='</a>';
 
 		$picto='sending';
 
-		if ($withpicto) $result.=($linkstart.img_object($label, $picto, 'class="classfortooltip"').$linkend);
+		if ($withpicto) $result.=($linkstart.img_object(($notooltip?'':$label), $picto, ($notooltip?'':'class="classfortooltip"'), 0, 0, $notooltip?0:1).$linkend);
 		if ($withpicto && $withpicto != 2) $result.=' ';
 		$result.=$linkstart.$this->ref.$linkend;
 		return $result;
@@ -1772,7 +1807,7 @@ class Expedition extends CommonObject
 
     }
 
-    
+
 	/**
 	 * Forge an set tracking url
 	 *
@@ -1818,9 +1853,9 @@ class Expedition extends CommonObject
 		global $conf,$langs,$user;
 
 		$error=0;
-		
+
 		$this->db->begin();
-		
+
 		$sql = 'UPDATE '.MAIN_DB_PREFIX.'expedition SET fk_statut='.self::STATUS_CLOSED;
 		$sql .= ' WHERE rowid = '.$this->id.' AND fk_statut > 0';
 
@@ -1832,9 +1867,9 @@ class Expedition extends CommonObject
 			{
 				$order = new Commande($this->db);
 				$order->fetch($this->origin_id);
-				
+
 				$order->loadExpeditions(self::STATUS_CLOSED);		// Fill $order->expeditions = array(orderlineid => qty)
-				
+
 				$shipments_match_order = 1;
 				foreach($order->lines as $line)
 				{
@@ -1850,21 +1885,21 @@ class Expedition extends CommonObject
 				}
 				if ($shipments_match_order)
 				{
-					dol_syslog("Qty for the ".count($order->lines)." lines of order have same value for shipments with status Expedition::STATUS_CLOSED=".self::STATUS_CLOSED.', so we close order');	
+					dol_syslog("Qty for the ".count($order->lines)." lines of order have same value for shipments with status Expedition::STATUS_CLOSED=".self::STATUS_CLOSED.', so we close order');
 					$order->cloture($user);
 				}
 			}
-			
+
 			$this->statut=self::STATUS_CLOSED;
 
-			
+
 			// If stock increment is done on closing
 			if (! $error && ! empty($conf->stock->enabled) && ! empty($conf->global->STOCK_CALCULATE_ON_SHIPMENT_CLOSE))
 			{
 				require_once DOL_DOCUMENT_ROOT.'/product/stock/class/mouvementstock.class.php';
-	
+
 				$langs->load("agenda");
-	
+
 				// Loop on each product line to add a stock movement
 				// TODO possibilite d'expedier a partir d'une propale ou autre origine ?
 				$sql = "SELECT cd.fk_product, cd.subprice,";
@@ -1875,7 +1910,7 @@ class Expedition extends CommonObject
 				$sql.= " LEFT JOIN ".MAIN_DB_PREFIX."expeditiondet_batch as edb on edb.fk_expeditiondet = ed.rowid";
 				$sql.= " WHERE ed.fk_expedition = ".$this->id;
 				$sql.= " AND cd.rowid = ed.fk_origin_line";
-	
+
 				dol_syslog(get_class($this)."::valid select details", LOG_DEBUG);
 				$resql=$this->db->query($sql);
 				if ($resql)
@@ -1894,14 +1929,14 @@ class Expedition extends CommonObject
 						}
 						if ($qty <= 0) continue;
 						dol_syslog(get_class($this)."::valid movement index ".$i." ed.rowid=".$obj->rowid." edb.rowid=".$obj->edbrowid);
-	
+
 						$mouvS = new MouvementStock($this->db);
 						$mouvS->origin = &$this;
-						
+
 						if (empty($obj->edbrowid))
 						{
 							// line without batch detail
-							
+
 							// We decrement stock of product (and sub-products) -> update table llx_product_stock (key of this table is fk_product+fk_entrepot) and add a movement record
 							$result=$mouvS->livraison($user, $obj->fk_product, $obj->fk_entrepot, $qty, $obj->subprice, $langs->trans("ShipmentClassifyClosedInDolibarr",$numref));
 							if ($result < 0) {
@@ -1913,7 +1948,7 @@ class Expedition extends CommonObject
 						else
 						{
 							// line with batch detail
-							
+
 							// We decrement stock of product (and sub-products) -> update table llx_product_stock (key of this table is fk_product+fk_entrepot) and add a movement record
 							$result=$mouvS->livraison($user, $obj->fk_product, $obj->fk_entrepot, $qty, $obj->subprice, $langs->trans("ShipmentClassifyClosedInDolibarr",$numref), '', $this->db->jdate($obj->eatby), $this->db->jdate($obj->sellby), $obj->batch, $obj->fk_origin_stock);
 							if ($result < 0) {
@@ -1930,7 +1965,7 @@ class Expedition extends CommonObject
 					$error++;
 				}
 			}
-			
+
 			// Call trigger
 			if (! $error)
 			{
@@ -1943,9 +1978,9 @@ class Expedition extends CommonObject
 		else
 		{
 			dol_print_error($this->db);
-            $error++;			
+            $error++;
 		}
-		
+
 		if (! $error)
 		{
 		    $this->db->commit();
@@ -1967,7 +2002,7 @@ class Expedition extends CommonObject
 	{
 	    global $user;
 		$error=0;
-		
+
 		$this->db->begin();
 
 		$sql = 'UPDATE '.MAIN_DB_PREFIX.'expedition SET fk_statut=2, billed=1';    // TODO Update only billed
@@ -1978,18 +2013,18 @@ class Expedition extends CommonObject
 		{
 			$this->statut=2;
 			$this->billed=1;
-			
+
 			// Call trigger
 			$result=$this->call_trigger('SHIPPING_BILLED',$user);
-			if ($result < 0) { 
+			if ($result < 0) {
 				$error++;
 			}
-			
+
 		} else {
 			$error++;
 			$this->errors[]=$this->db->lasterror;
 		}
-		
+
 		if (empty($error)) {
 			$this->db->commit();
 			return 1;
@@ -2011,9 +2046,9 @@ class Expedition extends CommonObject
 		global $conf,$langs,$user;
 
 		$error=0;
-		
+
 		$this->db->begin();
-		
+
 		$sql = 'UPDATE '.MAIN_DB_PREFIX.'expedition SET fk_statut=1';
 		$sql .= ' WHERE rowid = '.$this->id.' AND fk_statut > 0';
 
@@ -2022,14 +2057,14 @@ class Expedition extends CommonObject
 		{
 			$this->statut=1;
 			$this->billed=0;
-			
+
 			// If stock increment is done on closing
 			if (! $error && ! empty($conf->stock->enabled) && ! empty($conf->global->STOCK_CALCULATE_ON_SHIPMENT_CLOSE))
 			{
 				require_once DOL_DOCUMENT_ROOT.'/product/stock/class/mouvementstock.class.php';
-	
+
 				$langs->load("agenda");
-	
+
 				// Loop on each product line to add a stock movement
 				// TODO possibilite d'expedier a partir d'une propale ou autre origine
 				$sql = "SELECT cd.fk_product, cd.subprice,";
@@ -2040,7 +2075,7 @@ class Expedition extends CommonObject
 				$sql.= " LEFT JOIN ".MAIN_DB_PREFIX."expeditiondet_batch as edb on edb.fk_expeditiondet = ed.rowid";
 				$sql.= " WHERE ed.fk_expedition = ".$this->id;
 				$sql.= " AND cd.rowid = ed.fk_origin_line";
-	
+
 				dol_syslog(get_class($this)."::valid select details", LOG_DEBUG);
 				$resql=$this->db->query($sql);
 				if ($resql)
@@ -2059,15 +2094,15 @@ class Expedition extends CommonObject
 						}
 						if ($qty <= 0) continue;
 						dol_syslog(get_class($this)."::reopen expedition movement index ".$i." ed.rowid=".$obj->rowid." edb.rowid=".$obj->edbrowid);
-	
+
 						//var_dump($this->lines[$i]);
 						$mouvS = new MouvementStock($this->db);
 						$mouvS->origin = &$this;
-						
+
 						if (empty($obj->edbrowid))
 						{
 							// line without batch detail
-							
+
 							// We decrement stock of product (and sub-products) -> update table llx_product_stock (key of this table is fk_product+fk_entrepot) and add a movement record
 							$result=$mouvS->livraison($user, $obj->fk_product, $obj->fk_entrepot, -$qty, $obj->subprice, $langs->trans("ShipmentUnClassifyCloseddInDolibarr",$numref));
 							if ($result < 0) {
@@ -2079,7 +2114,7 @@ class Expedition extends CommonObject
 						else
 						{
 							// line with batch detail
-							
+
 							// We decrement stock of product (and sub-products) -> update table llx_product_stock (key of this table is fk_product+fk_entrepot) and add a movement record
 							$result=$mouvS->livraison($user, $obj->fk_product, $obj->fk_entrepot, -$qty, $obj->subprice, $langs->trans("ShipmentUnClassifyCloseddInDolibarr",$numref), '', $this->db->jdate($obj->eatby), $this->db->jdate($obj->sellby), $obj->batch, $obj->fk_origin_stock);
 							if ($result < 0) {
@@ -2096,7 +2131,7 @@ class Expedition extends CommonObject
 					$error++;
 				}
 			}
-			
+
 			if (! $error)
 			{
     			// Call trigger
@@ -2105,13 +2140,13 @@ class Expedition extends CommonObject
     				$error++;
     			}
    			}
-		
+
 		} else {
 			$error++;
 			$this->errors[]=$this->db->lasterror();
 		}
-			
-		if (! $error) 
+
+		if (! $error)
 		{
 			$this->db->commit();
 			return 1;
@@ -2122,7 +2157,7 @@ class Expedition extends CommonObject
 			return -1;
 		}
 	}
-	
+
 	/**
 	 *  Create a document onto disk according to template module.
 	 *
@@ -2208,7 +2243,7 @@ class ExpeditionLigne extends CommonObjectLine
 
 	public $element='expeditiondet';
 	public $table_element='expeditiondet';
-	
+
 	public $fk_origin_line;
 
 	// Deprecated
