@@ -1,9 +1,11 @@
 <?php
-/* Copyright (C) 2004-2005	Rodolphe Quiedeville	<rodolphe@quiedeville.org>
- * Copyright (C) 2004-2014	Laurent Destailleur		<eldy@users.sourceforge.net>
- * Copyright (C) 2005		Marc Barilley / Ocebo	<marc@ocebo.com>
- * Copyright (C) 2005-2012	Regis Houssin			<regis.houssin@capnetworks.com>
- * Copyright (C) 2013		Juanjo Menent			<jmenent@2byte.es>
+/* Copyright (C) 2004-2005  Rodolphe Quiedeville    <rodolphe@quiedeville.org>
+ * Copyright (C) 2004-2015  Laurent Destailleur     <eldy@users.sourceforge.net>
+ * Copyright (C) 2005       Marc Barilley / Ocebo   <marc@ocebo.com>
+ * Copyright (C) 2005-2012  Regis Houssin           <regis.houssin@capnetworks.com>
+ * Copyright (C) 2013-2014  Juanjo Menent           <jmenent@2byte.es>
+ * Copyright (C) 2014       Marcos García           <marcosgdf@gmail.com>
+ * Copyright (C) 2015-2016  Raphaël Doursenaud      <rdoursenaud@gpcsolutions.fr>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -26,9 +28,11 @@
  */
 include_once 'inc.php';
 
+global $langs;
+
 $err = 0;
 $allowinstall = 0;
-$allowupgrade = 0;
+$allowupgrade = false;
 $checksok = 1;
 
 $setuplang=GETPOST("selectlang",'',3)?GETPOST("selectlang",'',3):$langs->getDefaultLang();
@@ -40,10 +44,12 @@ $langs->load("install");
 $useforcedwizard=false;
 $forcedfile="./install.forced.php";
 if ($conffile == "/etc/dolibarr/conf.php") $forcedfile="/etc/dolibarr/install.forced.php";
-if (@file_exists($forcedfile)) { $useforcedwizard=true; include_once $forcedfile; }
-
-dolibarr_install_syslog("Dolibarr install/upgrade process started");
+if (@file_exists($forcedfile)) {
+	$useforcedwizard = true;
+	include_once $forcedfile;
+}
 
+dolibarr_install_syslog("--- check: Dolibarr install/upgrade process started");
 
 
 /*
@@ -56,13 +62,13 @@ pHeader('','');     // No next step for navigation buttons. Next step is defined
 //print "<br>\n";
 //print $langs->trans("InstallEasy")."<br><br>\n";
 
-print '<b>'.$langs->trans("MiscellaneousChecks")."</b>:<br>\n";
+print '<h3>'.$langs->trans("MiscellaneousChecks").":</h3>\n";
 
 // Check browser
 $useragent=$_SERVER['HTTP_USER_AGENT'];
 if (! empty($useragent))
 {
-    $tmp=getBrowserInfo();
+    $tmp=getBrowserInfo($_SERVER["HTTP_USER_AGENT"]);
     $browserversion=$tmp['browserversion'];
     $browsername=$tmp['browsername'];
     if ($browsername == 'ie' && $browserversion < 7) print '<img src="../theme/eldy/img/warning.png" alt="Error"> '.$langs->trans("WarningBrowserTooOld")."<br>\n";
@@ -70,15 +76,17 @@ if (! empty($useragent))
 
 
 // Check PHP version
-if (versioncompare(versionphparray(),array(4,3,10)) < 0)        // Minimum to use (error if lower)
+$arrayphpminversionerror = array(5,3,0);
+$arrayphpminversionwarning = array(5,3,0);
+if (versioncompare(versionphparray(),$arrayphpminversionerror) < 0)        // Minimum to use (error if lower)
 {
-	print '<img src="../theme/eldy/img/error.png" alt="Error"> '.$langs->trans("ErrorPHPVersionTooLow",'4.3.10');
-	$checksok=0;
+	print '<img src="../theme/eldy/img/error.png" alt="Error"> '.$langs->trans("ErrorPHPVersionTooLow", versiontostring($arrayphpminversionerror));
+	$checksok=0;	// 0=error, 1=warning
 }
-else if (versioncompare(versionphparray(),array(5,2,0)) < 0)    // Minimum supported (warning if lower)
+else if (versioncompare(versionphparray(),$arrayphpminversionwarning) < 0)    // Minimum supported (warning if lower)
 {
-    print '<img src="../theme/eldy/img/warning.png" alt="Error"> '.$langs->trans("WarningPHPVersionTooLow",'5.2.0');
-    $checksok=1;
+    print '<img src="../theme/eldy/img/warning.png" alt="Error"> '.$langs->trans("ErrorPHPVersionTooLow",versiontostring($arrayphpminversionwarning));
+    $checksok=0;	// 0=error, 1=warning
 }
 else
 {
@@ -114,7 +122,7 @@ else
 }
 
 
-// Check if GD supported
+// Check if GD supported (we need GD for image conversion)
 if (! function_exists("imagecreate"))
 {
 	$langs->load("errors");
@@ -127,6 +135,19 @@ else
 }
 
 
+// Check if Curl supported
+if (! function_exists("curl_init"))
+{
+    $langs->load("errors");
+    print '<img src="../theme/eldy/img/warning.png" alt="Error"> '.$langs->trans("ErrorPHPDoesNotSupportCurl")."<br>\n";
+    // $checksok=0;		// If image ko, just warning. So check must still be 1 (otherwise no way to install)
+}
+else
+{
+    print '<img src="../theme/eldy/img/tick.png" alt="Ok"> '.$langs->trans("PHPSupportCurl")."<br>\n";
+}
+
+
 // Check if UTF8 supported
 if (! function_exists("utf8_encode"))
 {
@@ -151,10 +172,11 @@ if ($memmaxorig != '')
 	preg_match('/([0-9]+)([a-zA-Z]*)/i',$memmax,$reg);
 	if ($reg[2])
 	{
+		if (strtoupper($reg[2]) == 'G') $memmax=$reg[1]*1024*1024*1024;
 		if (strtoupper($reg[2]) == 'M') $memmax=$reg[1]*1024*1024;
 		if (strtoupper($reg[2]) == 'K') $memmax=$reg[1]*1024;
 	}
-	if ($memmax >= $memrequired)
+	if ($memmax >= $memrequired || $memmax == -1)
 	{
 		print '<img src="../theme/eldy/img/tick.png" alt="Ok"> '.$langs->trans("PHPMemoryOK",$memmaxorig,$memrequiredorig)."<br>\n";
 	}
@@ -165,11 +187,11 @@ if ($memmaxorig != '')
 }
 
 
-// If config file presente and filled
+// If config file present and filled
 clearstatcache();
 if (is_readable($conffile) && filesize($conffile) > 8)
 {
-	dolibarr_install_syslog("conf file '$conffile' already defined");
+	dolibarr_install_syslog("check: conf file '" . $conffile . "' already defined");
 	$confexists=1;
 	include_once $conffile;
 
@@ -177,48 +199,47 @@ if (is_readable($conffile) && filesize($conffile) > 8)
 	if ($databaseok)
 	{
 		// Already installed for all parts (config and database). We can propose upgrade.
-		$allowupgrade=1;
+		$allowupgrade=true;
 	}
 	else
 	{
-		$allowupgrade=0;
+		$allowupgrade=false;
 	}
 }
 else
 {
 	// If not, we create it
-	dolibarr_install_syslog("we try to create conf file '$conffile'");
+	dolibarr_install_syslog("check: we try to create conf file '" . $conffile . "'");
 	$confexists=0;
 
 	// First we try by copying example
 	if (@copy($conffile.".example", $conffile))
 	{
 		// Success
-		dolibarr_install_syslog("copied file ".$conffile.".example into ".$conffile." done successfully.");
+		dolibarr_install_syslog("check: successfully copied file " . $conffile . ".example into " . $conffile);
 	}
 	else
 	{
 		// If failed, we try to create an empty file
-		dolibarr_install_syslog("failed to copy file ".$conffile.".example into ".$conffile.". We try to create it.", LOG_WARNING);
+		dolibarr_install_syslog("check: failed to copy file " . $conffile . ".example into " . $conffile . ". We try to create it.", LOG_WARNING);
 
 		$fp = @fopen($conffile, "w");
 		if ($fp)
 		{
 			@fwrite($fp, '<?php');
 			@fputs($fp,"\n");
-			@fputs($fp,"?>");
 			fclose($fp);
 		}
-		else dolibarr_install_syslog("failed to create a new file ".$conffile." into current dir ".getcwd().". Check permission.", LOG_ERR);
+		else dolibarr_install_syslog("check: failed to create a new file " . $conffile . " into current dir " . getcwd() . ". Please check permissions.", LOG_ERR);
 	}
 
-	// First install, on ne peut pas upgrader
-	$allowupgrade=0;
+	// First install, we can't upgrade
+	$allowupgrade=false;
 }
 
 
 
-// Si fichier absent et n'a pu etre cree
+// File is missng and can't be created
 if (! file_exists($conffile))
 {
 	print '<img src="../theme/eldy/img/error.png" alt="Error"> '.$langs->trans("ConfFileDoesNotExistsAndCouldNotBeCreated",$conffiletoshow);
@@ -231,7 +252,7 @@ if (! file_exists($conffile))
 }
 else
 {
-	// Si fichier present mais ne peut etre modifie
+	// File exists but can't be modified
 	if (!is_writable($conffile))
 	{
 		if ($confexists)
@@ -248,7 +269,7 @@ else
 
 		$allowinstall=0;
 	}
-	// Si fichier present et peut etre modifie
+	// File exists and can be modified
 	else
 	{
 		if ($confexists)
@@ -267,12 +288,12 @@ else
 	}
 	print "<br>\n";
 
-	// Si prerequis ok, on affiche le bouton pour passer a l'etape suivante
+	// Requirements ok, we display the next step button
 	if ($checksok)
 	{
 		$ok=0;
 
-		// Try to create db connexion
+		// Try to create db connection
 		if (file_exists($conffile))
 		{
 			include_once $conffile;
@@ -281,7 +302,7 @@ else
 				if (! file_exists($dolibarr_main_document_root."/core/lib/admin.lib.php"))
 				{
 				    print '<font class="error">A '.$conffiletoshow.' file exists with a dolibarr_main_document_root to '.$dolibarr_main_document_root.' that seems wrong. Try to fix or remove the '.$conffiletoshow.' file.</font><br>'."\n";
-				    dol_syslog("A '.$conffiletoshow.' file exists with a dolibarr_main_document_root to ".$dolibarr_main_document_root." that seems wrong. Try to fix or remove the '.$conffiletoshow.' file.", LOG_WARNING);
+				    dol_syslog("A '" . $conffiletoshow . "' file exists with a dolibarr_main_document_root to " . $dolibarr_main_document_root . " that seems wrong. Try to fix or remove the '" . $conffiletoshow . "' file.", LOG_WARNING);
 				}
 				else
 				{
@@ -295,9 +316,9 @@ else
     				$conf->db->user = $dolibarr_main_db_user;
     				$conf->db->pass = $dolibarr_main_db_pass;
                     $db=getDoliDBInstance($conf->db->type,$conf->db->host,$conf->db->user,$conf->db->pass,$conf->db->name,$conf->db->port);
-    				if ($db->connected == 1 && $db->database_selected == 1)
+    				if ($db->connected && $db->database_selected)
     				{
-    					$ok=1;
+    					$ok=true;
     				}
                 }
 			}
@@ -332,39 +353,45 @@ else
 		print $langs->trans("InstallEasy")." ";
 		print $langs->trans("ChooseYourSetupMode");
 
+        print '<br /><br />';
 
 		$foundrecommandedchoice=0;
 
-
-		// Array of install choices
-		print '<table width="100%" class="listofchoices">';
+        $available_choices = array();
+        $notavailable_choices = array();
 
 		// Show first install line
-		print '<tr class="listofchoices"><td class="listofchoices nowrap" align="center"><b>'.$langs->trans("FreshInstall").'</b>';
-		print '</td>';
-		print '<td class="listofchoices">';
-		print $langs->trans("FreshInstallDesc");
+		$choice = '<tr class="listofchoices"><td class="listofchoices nowrap" align="center"><b>'.$langs->trans("FreshInstall").'</b>';
+		$choice .= '</td>';
+		$choice .= '<td class="listofchoices">';
+		$choice .= $langs->trans("FreshInstallDesc");
 		if (empty($dolibarr_main_db_host))	// This means install process was not run
 		{
-			print '<br>';
+            $choice .= '<br>';
 			//print $langs->trans("InstallChoiceRecommanded",DOL_VERSION,$conf->global->MAIN_VERSION_LAST_UPGRADE);
-			print '<center><div class="ok">'.$langs->trans("InstallChoiceSuggested").'</div></center>';
+			$choice .= '<div class="center"><div class="ok">'.$langs->trans("InstallChoiceSuggested").'</div></div>';
 			// <img src="../theme/eldy/img/tick.png" alt="Ok"> ';
 			$foundrecommandedchoice=1;	// To show only once
 		}
-		print '</td>';
-		print '<td class="listofchoices" align="center">';
+
+        $choice .= '</td>';
+        $choice .= '<td class="listofchoices" align="center">';
 		if ($allowinstall)
 		{
-			print '<a class="button" href="fileconf.php?selectlang='.$setuplang.'">'.$langs->trans("Start").'</a>';
+            $choice .= '<a class="button" href="fileconf.php?selectlang='.$setuplang.'">'.$langs->trans("Start").'</a>';
 		}
 		else
 		{
-			print $langs->trans("InstallNotAllowed");
+            $choice .= $langs->trans("InstallNotAllowed");
 		}
-		print '</td>';
-		print '</tr>'."\n";
+        $choice .= '</td>';
+        $choice .= '</tr>'."\n";
 
+        if ($allowinstall) {
+            $available_choices[] = $choice;
+        } else {
+            $notavailable_choices[] = $choice;
+        }
 
 		// Show upgrade lines
 		$allowupgrade=true;
@@ -373,26 +400,28 @@ else
 			$allowupgrade=false;
 		}
 		if (defined("MAIN_NOT_INSTALLED")) $allowupgrade=false;
-		$migrationscript=array( //array('from'=>'2.0.0', 'to'=>'2.1.0'),
-								//array('from'=>'2.1.0', 'to'=>'2.2.0'),
-								//array('from'=>'2.2.0', 'to'=>'2.4.0'),
-								//array('from'=>'2.4.0', 'to'=>'2.5.0'),
-								//array('from'=>'2.5.0', 'to'=>'2.6.0'),
-								array('from'=>'2.6.0', 'to'=>'2.7.0'),
-								array('from'=>'2.7.0', 'to'=>'2.8.0'),
-								array('from'=>'2.8.0', 'to'=>'2.9.0'),
-								array('from'=>'2.9.0', 'to'=>'3.0.0'),
-								array('from'=>'3.0.0', 'to'=>'3.1.0'),
+		if (GETPOST('allowupgrade')) $allowupgrade=true;
+		$migrationscript=array(	array('from'=>'3.0.0', 'to'=>'3.1.0'),
 								array('from'=>'3.1.0', 'to'=>'3.2.0'),
 								array('from'=>'3.2.0', 'to'=>'3.3.0'),
 								array('from'=>'3.3.0', 'to'=>'3.4.0'),
-								array('from'=>'3.4.0', 'to'=>'3.5.0')
-						);
+								array('from'=>'3.4.0', 'to'=>'3.5.0'),
+								array('from'=>'3.5.0', 'to'=>'3.6.0'),
+								array('from'=>'3.6.0', 'to'=>'3.7.0'),
+								array('from'=>'3.7.0', 'to'=>'3.8.0'),
+		                        array('from'=>'3.8.0', 'to'=>'3.9.0'),
+		                        array('from'=>'3.9.0', 'to'=>'4.0.0'),
+		                        array('from'=>'4.0.0', 'to'=>'5.0.0')
+		);
 
 		$count=0;
 		foreach ($migrationscript as $migarray)
 		{
+
+            $choice = '';
+
 			$count++;
+            $recommended_choice = false;
             $version=DOL_VERSION;
 			$versionfrom=$migarray['from'];
             $versionto=$migarray['to'];
@@ -407,59 +436,125 @@ else
             {
             	$newversionfrombis=' '.$langs->trans("or").' '.$versionto;
             }
-			print '<tr class="listofchoices"><td class="listofchoices nowrap" align="center"><b>'.$langs->trans("Upgrade").'<br>'.$newversionfrom.$newversionfrombis.' -> '.$newversionto.'</b></td>';
-			print '<td class="listofchoices">';
-			print $langs->trans("UpgradeDesc");
 
-			if ($ok)
-			{
-				if (count($dolibarrlastupgradeversionarray) >= 2)	// If a database access is available and last upgrade version is known
-				{
-					// Now we check if this is the first qualified choice
-					if ($allowupgrade && empty($foundrecommandedchoice) &&
-						(versioncompare($dolibarrversiontoarray,$dolibarrlastupgradeversionarray) > 0 || versioncompare($dolibarrversiontoarray,$versionarray) < -2)
-						)
-					{
-						print '<br>';
-						//print $langs->trans("InstallChoiceRecommanded",DOL_VERSION,$conf->global->MAIN_VERSION_LAST_UPGRADE);
-						print '<center><div class="ok">'.$langs->trans("InstallChoiceSuggested").'</div>';
-						if ($count < count($migarray))	// There is other choices after
-						{
-							print $langs->trans("MigrateIsDoneStepByStep",DOL_VERSION);
-						}
-						print '</center>';
-						// <img src="../theme/eldy/img/tick.png" alt="Ok"> ';
-						$foundrecommandedchoice=1;	// To show only once
-					}
-				}
-				else {
-					// We can not recommand a choice.
-					// A version of install may be known, but we need last upgrade.
-				}
-			}
-			print '</td>';
-			print '<td class="listofchoices" align="center">';
+            if ($ok)
+            {
+                if (count($dolibarrlastupgradeversionarray) >= 2)	// If a database access is available and last upgrade version is known
+                {
+                    // Now we check if this is the first qualified choice
+                    if ($allowupgrade && empty($foundrecommandedchoice) &&
+                        (versioncompare($dolibarrversiontoarray,$dolibarrlastupgradeversionarray) > 0 || versioncompare($dolibarrversiontoarray,$versionarray) < -2)
+                    )
+                    {
+                        $foundrecommandedchoice=1;	// To show only once
+                        $recommended_choice = true;
+                    }
+                }
+                else {
+                    // We can not recommand a choice.
+                    // A version of install may be known, but we need last upgrade.
+                }
+            }
+
+            $choice .= '<tr class="listofchoices '.($recommended_choice ? 'choiceselected' : '').'">';
+            $choice .= '<td class="listofchoices nowrap" align="center"><b>'.$langs->trans("Upgrade").'<br>'.$newversionfrom.$newversionfrombis.' -> '.$newversionto.'</b></td>';
+            $choice .= '<td class="listofchoices">';
+            $choice .= $langs->trans("UpgradeDesc");
+
+            if ($recommended_choice)
+            {
+                $choice .= '<br>';
+                //print $langs->trans("InstallChoiceRecommanded",DOL_VERSION,$conf->global->MAIN_VERSION_LAST_UPGRADE);
+                $choice .= '<div class="center"><div class="ok">'.$langs->trans("InstallChoiceSuggested").'</div>';
+                if ($count < count($migarray))	// There is other choices after
+                {
+                    print $langs->trans("MigrateIsDoneStepByStep",DOL_VERSION);
+                }
+                $choice .= '</div>';
+            }
+
+            $choice .= '</td>';
+            $choice .= '<td class="listofchoices" align="center">';
 			if ($allowupgrade)
 			{
 				// If it's not last updagre script, action = upgrade_tmp, if last action = upgrade
-				print '<a class="button" href="upgrade.php?action=upgrade'.($count<count($migrationscript)?'_'.$versionto:'').'&amp;selectlang='.$setuplang.'&amp;versionfrom='.$versionfrom.'&amp;versionto='.$versionto.'">'.$langs->trans("Start").'</a>';
+                $choice .= '<a class="button runupgrade" href="upgrade.php?action=upgrade'.($count<count($migrationscript)?'_'.$versionto:'').'&amp;selectlang='.$setuplang.'&amp;versionfrom='.$versionfrom.'&amp;versionto='.$versionto.'">'.$langs->trans("Start").'</a>';
 			}
 			else
 			{
-				print $langs->trans("NotAvailable");
+                $choice .= $langs->trans("NotAvailable");
 			}
-			print '</td>';
-			print '</tr>'."\n";
+            $choice .= '</td>';
+            $choice .= '</tr>'."\n";
+
+            if ($allowupgrade) {
+                $available_choices[] = $choice;
+            } else {
+                $notavailable_choices[] = $choice;
+            }
 		}
 
-		print '</table>';
-		print "\n";
+		// If there is no choice at all, we show all of them.
+		if (empty($available_choices))
+		{
+			$available_choices=$notavailable_choices;
+			$notavailable_choices=array();
+		}
+
+        // Array of install choices
+        print '<table width="100%" class="listofchoices">';
+        foreach ($available_choices as $choice) {
+            print $choice;
+        }
+
+        print '</table>';
+
+        if (count($notavailable_choices)) {
+
+            print '<br />';
+            print '<div id="AShowChoices">';
+            print '<img src="../theme/eldy/img/1downarrow.png"> <a href="#">'.$langs->trans('ShowNotAvailableOptions').'</a>';
+            print '</div>';
+
+            print '<div id="navail_choices" style="display:none">';
+            print '<br />';
+            print '<table width="100%" class="listofchoices">';
+            foreach ($notavailable_choices as $choice) {
+                print $choice;
+            }
+
+            print '</table>';
+            print '</div>';
+        }
+
 	}
 
 }
 
+print '<script type="text/javascript">
 
+$("div#AShowChoices a").click(function() {
 
-pFooter(1);	// 1 car ne doit jamais afficher bouton Suivant
+    $("div#navail_choices").toggle();
+
+    if ($("div#navail_choices").css("display") == "none") {
+        $(this).text("'.$langs->trans('ShowNotAvailableOptions').'");
+        $(this).parent().children("img").attr("src", "../theme/eldy/img/1downarrow.png");
+    } else {
+        $(this).text("'.$langs->trans('HideNotAvailableOptions').'");
+        $(this).parent().children("img").attr("src", "../theme/eldy/img/1uparrow.png");
+    }
+
+});
+
+/*
+$(".runupgrade").click(function() {
+	return confirm("'.dol_escape_js($langs->transnoentitiesnoconv("WarningUpgrade"), 0, 1).'");
+});
+*/
+
+</script>';
+
+dolibarr_install_syslog("--- check: end");
+pFooter(1);	// Never display next button
 
-?>
