@@ -55,5 +55,9 @@ create table llx_bank_account
   currency_code			varchar(3) NOT NULL,
   min_allowed			integer DEFAULT 0,
   min_desired			integer DEFAULT 0,
-  comment				text
+  comment				text,						-- TODO rename in note_private
+  note_public     		text,
+  model_pdf       		varchar(255),
+  import_key      		varchar(14),
+  extraparams			varchar(255)				-- for other parameters with json format
 )ENGINE=innodb;
