@@ -1,5 +1,6 @@
 -- ===================================================================
 -- Copyright (C) 2003 Rodolphe Quiedeville <rodolphe@quiedeville.org>
+-- Copyright (C) 2016 Laurent Destailleur  <eldy@users.sourceforge.net>
 --
 -- This program is free software; you can redistribute it and/or modify
 -- it under the terms of the GNU General Public License as published by
@@ -22,7 +23,7 @@ create table llx_notify_def
   tms             timestamp,
   datec           date,             -- date de creation
   fk_action       integer NOT NULL,
-  fk_soc          integer NOT NULL,
+  fk_soc          integer,
   fk_contact      integer,
   fk_user		  integer,
   type            varchar(16) DEFAULT 'email'
