@@ -50,7 +50,6 @@ $langs->load("admin");
 $langs->load("install");
 $langs->load("other");
 
-if ($dolibarr_main_db_type == "mysql") $choix=1;
 if ($dolibarr_main_db_type == "mysqli") $choix=1;
 if ($dolibarr_main_db_type == "pgsql") $choix=2;
 if ($dolibarr_main_db_type == "mssql") $choix=3;
@@ -75,8 +74,9 @@ print '<h3>'.$langs->trans("Repair").'</h3>';
 
 print 'Option restore_thirdparties_logos is '.(GETPOST('restore_thirdparties_logos')?GETPOST('restore_thirdparties_logos'):'0').'<br>'."\n";
 print 'Option clean_linked_elements is '.(GETPOST('clean_linked_elements')?GETPOST('clean_linked_elements'):'0').'<br>'."\n";
-print 'Option clean_orphelin_dir (1 or confirmed) is '.(GETPOST('clean_orphelin_dir')?GETPOST('clean_orphelin_dir'):'0').'<br>'."\n";
-print 'Option clean_product_stock_batch (1 or confirmed) is '.(GETPOST('clean_product_stock_batch')?GETPOST('clean_product_stock_batch'):'0').'<br>'."\n";
+print 'Option clean_orphelin_dir (0 or \'test\' or \'confirmed\') is '.(GETPOST('clean_orphelin_dir')?GETPOST('clean_orphelin_dir'):'0').'<br>'."\n";
+print 'Option clean_product_stock_batch (0 or \'test\' or \'confirmed\') is '.(GETPOST('clean_product_stock_batch')?GETPOST('clean_product_stock_batch'):'0').'<br>'."\n";
+print 'Option set_empty_time_spent_amount (0 or \'test\' or \'confirmed\') is '.(GETPOST('set_empty_time_spent_amount')?GETPOST('set_empty_time_spent_amount'):'0').'<br>'."\n";
 print '<br>';
 
 print '<table cellspacing="0" cellpadding="1" border="0" width="100%">';
@@ -152,7 +152,7 @@ if ($ok)
 }
 
 // Show wait message
-print '<tr><td colspan="2">'.$langs->trans("PleaseBePatient").'</td></tr>';
+print '<tr><td colspan="2">'.$langs->trans("PleaseBePatient").'<br><br></td></tr>';
 flush();
 
 
@@ -191,7 +191,7 @@ if ($ok)
     // Loop on each file
     foreach($filelist as $file)
     {
-        print '<tr><td class="nowrap">';
+        print '<tr><td class="nowrap">*** ';
         print $langs->trans("Script").'</td><td align="right">'.$file.'</td></tr>';
 
         $name = substr($file, 0, dol_strlen($file) - 4);
@@ -211,7 +211,7 @@ if ($ok)
 				'socpeople'=>'socpeople', 'commande'=>'commande', 'facture'=>'facture',
 				'commande_fournisseur'=>'commande_fournisseur', 'actioncomm'=>'actioncomm',
 				'adherent_type'=>'adherent_type','user'=>'user','projet'=>'projet', 'projet_task'=>'projet_task');
-	print '<tr><td colspan="2"><br>Check fields into extra table structure match table of definition. If not add column into table</td></tr>';
+	print '<tr><td colspan="2"><br>*** Check fields into extra table structure match table of definition. If not add column into table</td></tr>';
 	foreach($listofmodulesextra as $tablename => $elementtype)
 	{
 	    // Get list of fields
@@ -252,10 +252,34 @@ if ($ok)
 	            if (! in_array($code,array_keys($arrayoffieldsfound)))
 	            {
 	                print 'Found field '.$code.' declared into '.MAIN_DB_PREFIX.'extrafields table but not found into desc of table '.$tableextra." -> ";
-	                $type=$extrafields->attribute_type[$code]; $value=$extrafields->attribute_size[$code]; $attribute=''; $default=''; $extra=''; $null='null';
+	                $type=$extrafields->attribute_type[$code]; $length=$extrafields->attribute_size[$code]; $attribute=''; $default=''; $extra=''; $null='null';
+	                
+           			if ($type=='boolean') {
+        				$typedb='int';
+        				$lengthdb='1';
+        			} elseif($type=='price') {
+        				$typedb='double';
+        				$lengthdb='24,8';
+        			} elseif($type=='phone') {
+        				$typedb='varchar';
+        				$lengthdb='20';
+        			}elseif($type=='mail') {
+        				$typedb='varchar';
+        				$lengthdb='128';
+        			} elseif (($type=='select') || ($type=='sellist') || ($type=='radio') ||($type=='checkbox') ||($type=='chkbxlst')){
+        				$typedb='text';
+        				$lengthdb='';
+        			} elseif ($type=='link') {
+        				$typedb='int';
+        				$lengthdb='11';
+        			} else {
+        				$typedb=$type;
+        				$lengthdb=$length;
+        			}
+	                
 	                $field_desc=array(
-	                	'type'=>$type,
-	                	'value'=>$value,
+	                	'type'=>$typedb,
+	                	'value'=>$lengthdb,
 	                	'attribute'=>$attribute,
 	                	'default'=>$default,
 	                	'extra'=>$extra,
@@ -301,7 +325,7 @@ if ($ok && GETPOST('restore_thirdparties_logos'))
 
 	$ext='';
 	
-	print '<tr><td colspan="2"><br>';
+	print '<tr><td colspan="2"><br>*** Restore thirdparties logo<br>';
 	//foreach($exts as $ext)
 	//{
 		$sql="SELECT s.rowid, s.nom as name, s.logo FROM ".MAIN_DB_PREFIX."societe as s ORDER BY s.nom";
@@ -372,7 +396,7 @@ if ($ok && GETPOST('restore_thirdparties_logos'))
 // clean_linked_elements: Check and clean linked elements
 if ($ok && GETPOST('clean_linked_elements'))
 {
-    print '<tr><td colspan="2"><br>Check table of linked elements and delete orphelins links</td></tr>';
+    print '<tr><td colspan="2"><br>*** Check table of linked elements and delete orphelins links</td></tr>';
 	// propal => order
 	print '<tr><td colspan="2">'.checkLinkedElements('propal', 'commande')."</td></tr>\n";
 
@@ -412,7 +436,7 @@ if ($ok && GETPOST('clean_orphelin_dir'))
 
         if (empty($upload_dir)) continue;
 
-        print '<tr><td colspan="2"><br>Clean orphelins files into files '.$upload_dir.'</td></tr>';
+        print '<tr><td colspan="2"><br>*** Clean orphelins files into files '.$upload_dir.'</td></tr>';
 
         $filearray=dol_dir_list($upload_dir,"files",1,'',array('^SPECIMEN\.pdf$','^\.','(\.meta|_preview\.png)$','^temp$','^payments$','^CVS$','^thumbs$'),'',SORT_DESC,1,true);
 
@@ -523,14 +547,17 @@ if ($ok && GETPOST('clean_orphelin_dir'))
 // clean_linked_elements: Check and clean linked elements
 if ($ok && GETPOST('clean_product_stock_batch'))
 {
-    print '<tr><td colspan="2"><br>Clean table product_batch</td></tr>';
+    $methodtofix=GETPOST('methodtofix')?GETPOST('methodtofix'):'updatestock';
+    
+    print '<tr><td colspan="2"><br>*** Clean table product_batch, methodtofix='.$methodtofix.' (possible values: updatestock or updatebatch)</td></tr>';
     
     $sql ="SELECT p.rowid, p.ref, p.tobatch, ps.rowid as psrowid, ps.fk_entrepot, ps.reel, SUM(pb.qty) as reelbatch";
-    $sql.=" FROM ".MAIN_DB_PREFIX."product as p, ".MAIN_DB_PREFIX."product_stock as ps, ".MAIN_DB_PREFIX."product_batch as pb";
-    $sql.=" WHERE p.rowid = ps.fk_product AND ps.rowid = pb.fk_product_stock";
+    $sql.=" FROM ".MAIN_DB_PREFIX."product as p, ".MAIN_DB_PREFIX."product_stock as ps LEFT JOIN ".MAIN_DB_PREFIX."product_batch as pb ON ps.rowid = pb.fk_product_stock";
+    $sql.=" WHERE p.rowid = ps.fk_product";
     $sql.=" AND p.tobatch = 1";
     $sql.=" GROUP BY p.rowid, p.ref, p.tobatch, ps.rowid, ps.fk_entrepot, ps.reel";
-    $sql.=" HAVING reel != SUM(pb.qty)";
+    $sql.=" HAVING reel != SUM(pb.qty) or SUM(pb.qty) IS NULL";
+    print $sql;
     $resql = $db->query($sql);
     if ($resql)
     {
@@ -542,13 +569,11 @@ if ($ok && GETPOST('clean_product_stock_batch'))
             while ($i < $num)
             {
                 $obj=$db->fetch_object($resql);
-                print '<tr><td>'.$obj->rowid.'-'.$obj->ref.'-'.$obj->fk_entrepot.' -> '.$obj->psrowid.': '.$obj->reel.' != '.$obj->reelbatch;
+                print '<tr><td>Product '.$obj->rowid.'-'.$obj->ref.' in warehose '.$obj->fk_entrepot.' -> '.$obj->psrowid.': '.$obj->reel.' (product_stock.reel) != '.($obj->reelbatch?$obj->reelbatch:'0').' (sum product_batch)';
                 
                 // Fix
                 if ($obj->reel != $obj->reelbatch)
                 {
-                    $methodtofix='updatestock';
-                    
                     if ($methodtofix == 'updatebatch')
                     {
                         // Method 1
@@ -570,7 +595,7 @@ if ($ok && GETPOST('clean_product_stock_batch'))
                     if ($methodtofix == 'updatestock')
                     {
                         // Method 2
-                        print ' -> Update qty of stock with qty = '.$obj->reelbatch.' for ps.rowid = '.$obj->psrowid;
+                        print ' -> Update qty of product_stock with qty = '.($obj->reelbatch?$obj->reelbatch:'0').' for ps.rowid = '.$obj->psrowid;
                         if (GETPOST('clean_product_stock_batch') == 'confirmed')
                         {
                             $error=0;
@@ -578,11 +603,11 @@ if ($ok && GETPOST('clean_product_stock_batch'))
                             $db->begin();
                             
                             $sql2 ="UPDATE ".MAIN_DB_PREFIX."product_stock";
-                            $sql2.=" SET reel = ".$obj->reelbatch." WHERE rowid = ".$obj->psrowid;
+                            $sql2.=" SET reel = ".($obj->reelbatch?$obj->reelbatch:'0')." WHERE rowid = ".$obj->psrowid;
                             $resql2=$db->query($sql2);
                             if ($resql2)
                             {
-                                // We update product stock, so we must update product.stock too.
+                                // We update product_stock, so we must field stock into product too.
                                 $sql3='UPDATE llx_product p SET p.stock= (SELECT SUM(ps.reel) FROM llx_product_stock ps WHERE ps.fk_product = p.rowid)';
                                 $resql3=$db->query($sql3);
                                 if (! $resql3) 
@@ -608,16 +633,108 @@ if ($ok && GETPOST('clean_product_stock_batch'))
                 $i++;
             }
         }
+        else
+        {
+            print '<tr><td colspan="2">Nothing to do</td></tr>';
+        }
     }
     else
     {
         dol_print_error($db);
     }
-    
-    
 }
 
 
+// clean_linked_elements: Check and clean linked elements
+if ($ok && GETPOST('clean_product_stock_negative_if_batch'))
+{
+    print '<tr><td colspan="2"><br>Clean table product_batch, methodtofix='.$methodtofix.' (possible values: updatestock or updatebatch)</td></tr>';
+
+    $sql ="SELECT p.rowid, p.ref, p.tobatch, ps.rowid as psrowid, ps.fk_entrepot, ps.reel, SUM(pb.qty) as reelbatch";
+    $sql.=" FROM ".MAIN_DB_PREFIX."product as p, ".MAIN_DB_PREFIX."product_stock as ps, ".MAIN_DB_PREFIX."product_batch as pb";
+    $sql.=" WHERE p.rowid = ps.fk_product AND ps.rowid = pb.fk_product_stock";
+    $sql.=" AND p.tobatch = 1";
+    $sql.=" GROUP BY p.rowid, p.ref, p.tobatch, ps.rowid, ps.fk_entrepot, ps.reel";
+    $sql.=" HAVING reel != SUM(pb.qty)";
+    $resql = $db->query($sql);
+    if ($resql)
+    {
+        $num = $db->num_rows($resql);
+
+        if ($num)
+        {
+            $i = 0;
+            while ($i < $num)
+            {
+                $obj=$db->fetch_object($resql);
+                print '<tr><td>'.$obj->rowid.'-'.$obj->ref.'-'.$obj->fk_entrepot.' -> '.$obj->psrowid.': '.$obj->reel.' != '.$obj->reelbatch;
+
+            }
+        }
+    }
+}
+
+// clean_linked_elements: Check and clean linked elements
+if ($ok && GETPOST('set_empty_time_spent_amount'))
+{
+    print '<tr><td colspan="2"><br>*** Set value of time spent without amount</td></tr>';
+
+    $sql ="SELECT COUNT(ptt.rowid) as nb, u.rowid as user_id, u.login, u.thm as user_thm";
+    $sql.=" FROM ".MAIN_DB_PREFIX."projet_task_time as ptt, ".MAIN_DB_PREFIX."user as u";
+    $sql.=" WHERE ptt.fk_user = u.rowid";
+    $sql.=" AND ptt.thm IS NULL and u.thm > 0";
+    $sql.=" GROUP BY u.rowid, u.login, u.thm";
+    
+    $resql = $db->query($sql);
+    if ($resql)
+    {
+        $num = $db->num_rows($resql);
+
+        if ($num)
+        {
+            $i = 0;
+            while ($i < $num)
+            {
+                $obj=$db->fetch_object($resql);
+                print '<tr><td>'.$obj->login.'-'.$obj->user_id.' ('.$obj->nb.' lines to fix) -> '.$obj->user_thm;
+
+                $db->begin();
+
+                if (GETPOST('set_empty_time_spent_amount') == 'confirmed')
+                {
+                    $sql2 ="UPDATE ".MAIN_DB_PREFIX."projet_task_time";
+                    $sql2.=" SET thm = ".$obj->user_thm." WHERE thm IS NULL AND fk_user = ".$obj->user_id;
+                    $resql2=$db->query($sql2);
+                    if (! $resql2)
+                    {
+                        $error++;
+                        dol_print_error($db);
+                    }
+                }
+                
+                if (!$error) $db->commit();
+                else $db->rollback();
+
+                print'</td></tr>';
+
+                if ($error) break;
+                
+                $i++;
+            }
+        }
+        else
+        {
+            print '<tr><td>No time spent with empty line on users with a hourly rate defined</td></tr>';
+        }
+    }
+    else
+    {
+        dol_print_error($db);
+    }
+
+
+}
+
 
 
 
