@@ -1,10 +1,10 @@
 <?php
-/* Copyright (C) 2004-2007 Rodolphe Quiedeville <rodolphe@quiedeville.org>
- * Copyright (C) 2004-2012 Laurent Destailleur  <eldy@users.sourceforge.net>
- * Copyright (C) 2004      Benoit Mortier       <benoit.mortier@opensides.be>
- * Copyright (C) 2004      Sebastien Di Cintio  <sdicintio@ressource-toi.org>
- * Copyright (C) 2005-2011 Regis Houssin        <regis.houssin@capnetworks.com>
- * Copyright (C) 2015      Raphaël Doursenaud   <rdoursenaud@gpcsolutions.fr>
+/* Copyright (C) 2004-2007  Rodolphe Quiedeville    <rodolphe@quiedeville.org>
+ * Copyright (C) 2004-2016  Laurent Destailleur     <eldy@users.sourceforge.net>
+ * Copyright (C) 2004       Benoit Mortier          <benoit.mortier@opensides.be>
+ * Copyright (C) 2004       Sebastien Di Cintio     <sdicintio@ressource-toi.org>
+ * Copyright (C) 2005-2011  Regis Houssin           <regis.houssin@capnetworks.com>
+ * Copyright (C) 2015-2016  Raphaël Doursenaud      <rdoursenaud@gpcsolutions.fr>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -30,6 +30,8 @@ define('DONOTLOADCONF',1);	// To avoid loading conf by file inc.php
 
 include 'inc.php';
 
+global $langs;
+
 $action=GETPOST('action','alpha');
 $setuplang=(GETPOST('selectlang','',3)?GETPOST('selectlang','',3):'auto');
 $langs->setDefaultLang($setuplang);
@@ -38,12 +40,15 @@ $langs->load("admin");
 $langs->load("install");
 $langs->load("errors");
 
-// Recuparation des information de connexion
+// Dolibarr pages directory
+$main_dir = GETPOST('main_dir');
+// Directory for generated documents (invoices, orders, ecm, etc...)
+$main_data_dir = GETPOST('main_data_dir') ? GETPOST('main_data_dir') : $main_dir . '/documents';
+// Dolibarr root URL
+$main_url = GETPOST('main_url');
+// Database login informations
 $userroot=GETPOST('db_user_root');
 $passroot=GETPOST('db_pass_root');
-// Repertoire des pages dolibarr
-$main_dir=GETPOST('main_dir');
-$main_url=GETPOST('main_url');
 // Database server
 $db_type=GETPOST('db_type','alpha');
 $db_host=GETPOST('db_host','alpha');
@@ -52,8 +57,16 @@ $db_user=GETPOST('db_user','alpha');
 $db_pass=GETPOST('db_pass');
 $db_port=GETPOST('db_port','int');
 $db_prefix=GETPOST('db_prefix','alpha');
+$db_create_database = GETPOST('db_create_database');
+$db_create_user = GETPOST('db_create_user');
+// Force https
+$main_force_https = ((GETPOST("main_force_https") && (GETPOST("main_force_https") == "on" || GETPOST("main_force_https") == 1)) ? '1' : '0');
+// Use alternative directory
+$main_use_alt_dir = ((GETPOST("main_use_alt_dir") && (GETPOST("main_use_alt_dir") == "on" || GETPOST("main_use_alt_dir") == 1)) ? '' : '//');
+// Alternative root directory name
+$main_alt_dir_name = ((GETPOST("main_alt_dir_name") && GETPOST("main_alt_dir_name") != '') ? GETPOST("main_alt_dir_name") : 'custom');
 
-session_start();	// To be able to keep info into session (used for not losing password during navigation. The password must not transmit through parameters)
+session_start();    // To be able to keep info into session (used for not losing password during navigation. The password must not transit through parameters)
 
 // Save a flag to tell to restore input value if we do back
 $_SESSION['dol_save_pass']=$db_pass;
@@ -63,9 +76,60 @@ $_SESSION['dol_save_pass']=$db_pass;
 $useforcedwizard=false;
 $forcedfile="./install.forced.php";
 if ($conffile == "/etc/dolibarr/conf.php") $forcedfile="/etc/dolibarr/install.forced.php";
-if (@file_exists($forcedfile)) { $useforcedwizard=true; include_once $forcedfile; }
+if (@file_exists($forcedfile)) {
+	$useforcedwizard = true;
+	include_once $forcedfile;
+	// If forced install is enabled, let's replace post values. These are empty because form fields are disabled.
+	if ($force_install_noedit) {
+		$main_dir = detect_dolibarr_main_document_root();
+		if (!empty($force_install_main_data_root)) {
+			$main_data_dir = $force_install_main_data_root;
+		} else {
+			$main_data_dir = detect_dolibarr_main_data_root($main_dir);
+		}
+		$main_url = detect_dolibarr_main_url_root();
+
+		if (!empty($force_install_databaserootlogin)) {
+			$userroot = parse_database_login($force_install_databaserootlogin);
+		}
+		if (!empty($force_install_databaserootpass)) {
+			$passroot = parse_database_pass($force_install_databaserootpass);
+		}
+	}
+	if ($force_install_noedit == 2) {
+		if (!empty($force_install_type)) {
+			$db_type = $force_install_type;
+		}
+		if (!empty($force_install_dbserver)) {
+			$db_host = $force_install_dbserver;
+		}
+		if (!empty($force_install_database)) {
+			$db_name = $force_install_database;
+		}
+		if (!empty($force_install_databaselogin)) {
+			$db_user = $force_install_databaselogin;
+		}
+		if (!empty($force_install_databasepass)) {
+			$db_pass = $force_install_databasepass;
+		}
+		if (!empty($force_install_port)) {
+			$db_port = $force_install_port;
+		}
+		if (!empty($force_install_prefix)) {
+			$db_prefix = $force_install_prefix;
+		}
+		if (!empty($force_install_createdatabase)) {
+			$db_create_database = $force_install_createdatabase;
+		}
+		if (!empty($force_install_createuser)) {
+			$db_create_user = $force_install_createuser;
+		}
+		if (!empty($force_install_mainforcehttps)) {
+			$main_force_https = $force_install_mainforcehttps;
+		}
+	}
+}
 
-dolibarr_install_syslog("--- step1: entering step1.php page");
 
 $error = 0;
 
@@ -74,6 +138,7 @@ $error = 0;
  *	View
  */
 
+dolibarr_install_syslog("--- step1: entering step1.php page");
 
 pHeader($langs->trans("ConfigurationFile"),"step2");
 
@@ -134,28 +199,20 @@ if (! empty($main_url) && substr($main_url, dol_strlen($main_url) -1) == "/")
     $main_url = substr($main_url, 0, dol_strlen($main_url)-1);
 }
 
-// Directory for generated documents (invoices, orders, ecm, etc...)
-$main_data_dir=isset($_POST["main_data_dir"])?$_POST["main_data_dir"]:'';
-if (! $main_data_dir) { $main_data_dir="$main_dir/documents"; }
-
-
-// Test database connexion
-if (! $error)
-{
+// Test database connection
+if (! $error) {
     $result=@include_once $main_dir."/core/db/".$db_type.'.class.php';
     if ($result)
     {
         // If we ask database or user creation we need to connect as root, so we need root login
-        if (! empty($_POST["db_create_database"]) && ! $userroot)
-        {
+        if (!empty($db_create_database) && !$userroot) {
             print '<div class="error">'.$langs->trans("YouAskDatabaseCreationSoDolibarrNeedToConnect",$db_name).'</div>';
             print '<br>';
             print $langs->trans("BecauseConnectionFailedParametersMayBeWrong").'<br><br>';
             print $langs->trans("ErrorGoBackAndCorrectParameters");
             $error++;
         }
-        if (! empty($_POST["db_create_user"]) && ! $userroot)
-        {
+        if (!empty($db_create_user) && !$userroot) {
             print '<div class="error">'.$langs->trans("YouAskLoginCreationSoDolibarrNeedToConnect",$db_user).'</div>';
             print '<br>';
             print $langs->trans("BecauseConnectionFailedParametersMayBeWrong").'<br><br>';
@@ -164,11 +221,9 @@ if (! $error)
         }
 
         // If we need root access
-        if (! $error && (! empty($_POST["db_create_database"]) || ! empty($_POST["db_create_user"])))
-        {
+        if (!$error && (!empty($db_create_database) || !empty($db_create_user))) {
             $databasefortest=$db_name;
-            if (! empty($_POST["db_create_database"]))
-            {
+            if (!empty($db_create_database)) {
                 if ($db_type == 'mysql' || $db_type == 'mysqli')
                 {
                     $databasefortest='mysql';
@@ -189,16 +244,13 @@ if (! $error)
             dol_syslog("databasefortest=" . $databasefortest . " connected=" . $db->connected . " database_selected=" . $db->database_selected, LOG_DEBUG);
             //print "databasefortest=".$databasefortest." connected=".$db->connected." database_selected=".$db->database_selected;
 
-            if (empty($_POST["db_create_database"]) && $db->connected && ! $db->database_selected)
-            {
+			if (empty($db_create_database) && $db->connected && !$db->database_selected) {
                 print '<div class="error">'.$langs->trans("ErrorConnectedButDatabaseNotFound",$db_name).'</div>';
                 print '<br>';
                 if (! $db->connected) print $langs->trans("IfDatabaseNotExistsGoBackAndUncheckCreate").'<br><br>';
                 print $langs->trans("ErrorGoBackAndCorrectParameters");
                 $error++;
-            }
-            elseif ($db->error && ! (! empty($_POST["db_create_database"]) && $db->connected))
-            {
+            } elseif ($db->error && ! (! empty($db_create_database) && $db->connected)) {
             	// Note: you may experience error here with message "No such file or directory" when mysql was installed for the first time but not yet launched.
                 if ($db->error == "No such file or directory") print '<div class="error">'.$langs->trans("ErrorToConnectToMysqlCheckInstance").'</div>';
                 else print '<div class="error">'.$db->error.'</div>';
@@ -210,8 +262,7 @@ if (! $error)
             }
         }
         // If we need simple access
-        if (! $error && (empty($_POST["db_create_database"]) && empty($_POST["db_create_user"])))
-        {
+        if (!$error && (empty($db_create_database) && empty($db_create_user))) {
             $db=getDoliDBInstance($db_type, $db_host, $db_user, $db_pass, $db_name, $db_port);
 
             if ($db->error)
@@ -246,8 +297,7 @@ else
 
 if (! $error && $db->connected)
 {
-    if (! empty($_POST["db_create_database"]))
-    {
+    if (! empty($db_create_database)) {
         $result=$db->select_db($db_name);
         if ($result)
         {
@@ -262,8 +312,7 @@ if (! $error && $db->connected)
 // Define $defaultCharacterSet and $defaultDBSortingCollation
 if (! $error && $db->connected)
 {
-    if (! empty($_POST["db_create_database"]))	// If we create database, we force default value
-    {
+    if (!empty($db_create_database)) { // If we create database, we force default value
     	$defaultCharacterSet=$db->forcecharset;
     	$defaultDBSortingCollation=$db->forcecollate;
     }
@@ -430,15 +479,6 @@ if (! $error && $db->connected && $action == "set")
     // Table prefix
     $main_db_prefix = (! empty($db_prefix) ? $db_prefix : 'llx_');
 
-    // Force https
-    $main_force_https = ((GETPOST("main_force_https") && (GETPOST("main_force_https") == "on" || GETPOST("main_force_https") == '1')) ? '1' : '0');
-
-    // Use alternative directory
-    $main_use_alt_dir = ((GETPOST("main_use_alt_dir") && (GETPOST("main_use_alt_dir") == "off" || GETPOST("main_use_alt_dir") == '0')) ? '//' : '');
-
-    // Alternative root directory name
-    $main_alt_dir_name = ((GETPOST("main_alt_dir_name") && GETPOST("main_alt_dir_name") != '') ? GETPOST("main_alt_dir_name") : 'custom');
-
     // Write conf file on disk
     if (! $error)
     {
@@ -469,14 +509,8 @@ if (! $error && $db->connected && $action == "set")
         print '</td>';
         print '<td><img src="../theme/eldy/img/tick.png" alt="Ok"></td></tr>';
 
-
-        $userroot=isset($_POST["db_user_root"])?$_POST["db_user_root"]:"";
-        $passroot=isset($_POST["db_pass_root"])?$_POST["db_pass_root"]:"";
-
-
         // Si creation utilisateur admin demandee, on le cree
-        if (isset($_POST["db_create_user"]) && $_POST["db_create_user"] == "on")
-        {
+        if (isset($db_create_user) && $db_create_user == "on") {
             dolibarr_install_syslog("step1: create database user: " . $dolibarr_main_db_user);
 
             //print $conf->db->host." , ".$conf->db->name." , ".$conf->db->user." , ".$conf->db->port;
@@ -508,9 +542,20 @@ if (! $error && $db->connected && $action == "set")
             {
                 if ($db->connected)
                 {
-                    $result=$db->DDLCreateUser($dolibarr_main_db_host,$dolibarr_main_db_user,$dolibarr_main_db_pass,$dolibarr_main_db_name);
+                    $resultbis = 1;
 
-                    if ($result > 0)
+                    // Create user
+                    $result=$db->DDLCreateUser($dolibarr_main_db_host, $dolibarr_main_db_user, $dolibarr_main_db_pass, $dolibarr_main_db_name);
+                    // Create user bis
+                    if ($databasefortest == 'mysql')
+                    {
+                        if (! in_array($dolibarr_main_db_host, array('127.0.0.1', '::1', 'localhost', 'localhost.local')))
+                        {
+                            $resultbis=$db->DDLCreateUser('%', $dolibarr_main_db_user, $dolibarr_main_db_pass, $dolibarr_main_db_name);
+                        }
+                    }
+
+                    if ($result > 0 && $resultbis > 0)
                     {
 
                         print '<tr><td>';
@@ -569,8 +614,7 @@ if (! $error && $db->connected && $action == "set")
 
 
         // If database creation is asked, we create it
-        if (! $error && (isset($_POST["db_create_database"]) && $_POST["db_create_database"] == "on"))
-        {
+        if (!$error && (isset($db_create_database) && $db_create_database == "on")) {
             dolibarr_install_syslog("step1: create database: " . $dolibarr_main_db_name . " " . $dolibarr_main_db_character_set . " " . $dolibarr_main_db_collation . " " . $dolibarr_main_db_user);
         	$newdb=getDoliDBInstance($conf->db->type,$conf->db->host,$userroot,$passroot,'',$conf->db->port);
             //print 'eee'.$conf->db->type." ".$conf->db->host." ".$userroot." ".$passroot." ".$conf->db->port." ".$newdb->connected." ".$newdb->forcecharset;exit;
@@ -873,7 +917,7 @@ function write_conf_file($conffile)
 
         fputs($fp, '$dolibarr_main_restrict_os_commands=\'mysqldump, mysql, pg_dump, pgrestore\';');
 		fputs($fp,"\n");
-		
+
         fputs($fp, '$dolibarr_nocsrfcheck=\'0\';');
         fputs($fp,"\n");
 
@@ -959,4 +1003,3 @@ function write_conf_file($conffile)
 
 	return $error;
 }
-
