@@ -1,7 +1,8 @@
 <?php
-/* Copyright (C) 2004      Rodolphe Quiedeville <rodolphe@quiedeville.org>
- * Copyright (C) 2004-2010 Laurent Destailleur  <eldy@users.sourceforge.net>
- * Copyright (C) 2005-2010 Regis Houssin        <regis.houssin@capnetworks.com>
+/* Copyright (C) 2004       Rodolphe Quiedeville    <rodolphe@quiedeville.org>
+ * Copyright (C) 2004-2016  Laurent Destailleur     <eldy@users.sourceforge.net>
+ * Copyright (C) 2005-2010  Regis Houssin           <regis.houssin@capnetworks.com>
+ * Copyright (C) 2015-2016  Raphaël Doursenaud      <rdoursenaud@gpcsolutions.fr>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -22,6 +23,8 @@
  * php upgrade.php 3.4.0 3.5.0 [dirmodule|ignoredbversion]
  * php upgrade2.php 3.4.0 3.5.0
  *
+ * Option 'dirmodule' allows to provide a path for an external module, so we migrate from command line a script from a module.
+ * Option 'ignoredbversion' allows to run migration even if database is a bugged database version.
  * Return code is 0 if OK, >0 if error
  */
 
@@ -35,11 +38,13 @@ if (! file_exists($conffile))
 {
     print 'Error: Dolibarr config file was not found. This may means that Dolibarr is not installed yet. Please call the page "/install/index.php" instead of "/install/upgrade.php").';
 }
-require_once $conffile; if (! isset($dolibarr_main_db_type)) $dolibarr_main_db_type='mysql';	// For backward compatibility
+require_once $conffile;
 require_once $dolibarr_main_document_root.'/core/lib/admin.lib.php';
 
+global $langs;
+
 $grant_query='';
-$etape = 2;
+$step = 2;
 $ok = 0;
 
 
@@ -47,34 +52,51 @@ $ok = 0;
 // Ne fonctionne que si on est pas en safe_mode.
 $err=error_reporting();
 error_reporting(0);
-@set_time_limit(120);
+@set_time_limit(300);
 error_reporting($err);
 
+
 $setuplang=GETPOST("selectlang",'',3)?GETPOST("selectlang",'',3):'auto';
 $langs->setDefaultLang($setuplang);
 $versionfrom=GETPOST("versionfrom",'',3)?GETPOST("versionfrom",'',3):(empty($argv[1])?'':$argv[1]);
 $versionto=GETPOST("versionto",'',3)?GETPOST("versionto",'',3):(empty($argv[2])?'':$argv[2]);
-$versionmodule=(GETPOST("versionmodule",'',3) && GETPOST("versionmodule",'',3) != 'ignoredbversion')?GETPOST("versionmodule",'',3):((empty($argv[3]) || $argv[3] == 'ignoredbversion')?'':$argv[3]);
+$dirmodule=((GETPOST("dirmodule",'',3) && GETPOST("dirmodule",'',3) != 'ignoredbversion'))?GETPOST("dirmodule",'',3):((empty($argv[3]) || $argv[3] == 'ignoredbversion')?'':$argv[3]);
 $ignoredbversion=(GETPOST('ignoredbversion','',3)=='ignoredbversion')?GETPOST('ignoredbversion','',3):((empty($argv[3]) || $argv[3] != 'ignoredbversion')?'':$argv[3]);
 
 $langs->load("admin");
 $langs->load("install");
+$langs->load("other");
 $langs->load("errors");
 
-if ($dolibarr_main_db_type == "mysql") $choix=1;
 if ($dolibarr_main_db_type == "mysqli") $choix=1;
 if ($dolibarr_main_db_type == "pgsql") $choix=2;
 if ($dolibarr_main_db_type == "mssql") $choix=3;
 
 
-dolibarr_install_syslog("upgrade: Entering upgrade.php page");
-if (! is_object($conf)) dolibarr_install_syslog("upgrade2: conf file not initialized",LOG_ERR);
+dolibarr_install_syslog("--- upgrade: Entering upgrade.php page");
+if (! is_object($conf)) dolibarr_install_syslog("upgrade2: conf file not initialized", LOG_ERR);
 
 
 /*
  * View
  */
 
+if (! $versionfrom && ! $versionto)
+{
+	print 'Error: Parameter versionfrom or versionto missing.'."\n";
+	print 'Upgrade must be ran from cmmand line with parameters or called from page install/index.php (like a first install) instead of page install/upgrade.php'."\n";
+	// Test if batch mode
+	$sapi_type = php_sapi_name();
+	$script_file = basename(__FILE__);
+	$path=dirname(__FILE__).'/';
+	if (substr($sapi_type, 0, 3) == 'cli')
+	{
+		print 'Syntax from command line: '.$script_file." x.y.z a.b.c\n";
+	}
+	exit;
+}
+
+
 pHeader('',"upgrade2",GETPOST('action'),'versionfrom='.$versionfrom.'&versionto='.$versionto);
 
 $actiondone=0;
@@ -86,12 +108,6 @@ if (! GETPOST("action") || preg_match('/upgrade/i',GETPOST('action')))
 
     print '<h3>'.$langs->trans("DatabaseMigration").'</h3>';
 
-    if (! $versionfrom && ! $versionto)
-    {
-        print '<div class="error">Parameter versionfrom or versionto missing. Upgrade is launched from page install/index.php (like a first install) instead of install/upgrade.php</div>';
-        exit;
-    }
-
     print '<table cellspacing="0" cellpadding="1" border="0" width="100%">';
     $error=0;
 
@@ -128,33 +144,33 @@ if (! GETPOST("action") || preg_match('/upgrade/i',GETPOST('action')))
     include_once DOL_DOCUMENT_ROOT.'/core/class/hookmanager.class.php';
     $hookmanager=new HookManager($db);
 
-    if ($db->connected == 1)
+    if ($db->connected)
     {
         print '<tr><td class="nowrap">';
         print $langs->trans("ServerConnection")." : $dolibarr_main_db_host</td><td align=\"right\">".$langs->trans("OK")."</td></tr>\n";
-        dolibarr_install_syslog("upgrade: ".$langs->transnoentities("ServerConnection")." : $dolibarr_main_db_host ".$langs->transnoentities("OK"));
+        dolibarr_install_syslog("upgrade: " . $langs->transnoentities("ServerConnection") . ": $dolibarr_main_db_host " . $langs->transnoentities("OK"));
         $ok = 1;
     }
     else
     {
         print "<tr><td>".$langs->trans("ErrorFailedToConnectToDatabase",$dolibarr_main_db_name)."</td><td align=\"right\">".$langs->transnoentities("Error")."</td></tr>\n";
-        dolibarr_install_syslog("upgrade: ".$langs->transnoentities("ErrorFailedToConnectToDatabase",$dolibarr_main_db_name));
+        dolibarr_install_syslog("upgrade: " . $langs->transnoentities("ErrorFailedToConnectToDatabase", $dolibarr_main_db_name));
         $ok = 0;
     }
 
     if ($ok)
     {
-        if($db->database_selected == 1)
+        if($db->database_selected)
         {
             print '<tr><td class="nowrap">';
             print $langs->trans("DatabaseConnection")." : ".$dolibarr_main_db_name."</td><td align=\"right\">".$langs->trans("OK")."</td></tr>\n";
-            dolibarr_install_syslog("upgrade: Database connection successfull : $dolibarr_main_db_name");
+            dolibarr_install_syslog("upgrade: Database connection successful: " . $dolibarr_main_db_name);
             $ok=1;
         }
         else
         {
             print "<tr><td>".$langs->trans("ErrorFailedToConnectToDatabase",$dolibarr_main_db_name)."</td><td align=\"right\">".$langs->trans("Error")."</td></tr>\n";
-            dolibarr_install_syslog("upgrade: ".$langs->transnoentities("ErrorFailedToConnectToDatabase",$dolibarr_main_db_name));
+            dolibarr_install_syslog("upgrade: " . $langs->transnoentities("ErrorFailedToConnectToDatabase", $dolibarr_main_db_name));
             $ok=0;
         }
     }
@@ -166,20 +182,49 @@ if (! GETPOST("action") || preg_match('/upgrade/i',GETPOST('action')))
         $versionarray=$db->getVersionArray();
         print '<tr><td>'.$langs->trans("ServerVersion").'</td>';
         print '<td align="right">'.$version.'</td></tr>';
-        dolibarr_install_syslog("upgrade: ".$langs->transnoentities("ServerVersion")." : $version");
+        dolibarr_install_syslog("upgrade: " . $langs->transnoentities("ServerVersion") . ": " .$version);
 
-        // Test database version
-        $versionmindb=getStaticMember(get_class($db),'versionmin');
+        // Test database version requirement
+        $versionmindb=$db::VERSIONMIN;
         //print join('.',$versionarray).' - '.join('.',$versionmindb);
         if (count($versionmindb) && count($versionarray)
         	&& versioncompare($versionarray,$versionmindb) < 0)
         {
         	// Warning: database version too low.
         	print "<tr><td>".$langs->trans("ErrorDatabaseVersionTooLow",join('.',$versionarray),join('.',$versionmindb))."</td><td align=\"right\">".$langs->trans("Error")."</td></tr>\n";
-        	dolibarr_install_syslog("upgrade: ".$langs->transnoentities("ErrorDatabaseVersionTooLow",join('.',$versionarray),join('.',$versionmindb)));
+        	dolibarr_install_syslog("upgrade: " . $langs->transnoentities("ErrorDatabaseVersionTooLow", join('.', $versionarray), join('.', $versionmindb)));
         	$ok=0;
         }
 
+        // Test database version is not forbidden for migration
+        if (empty($ignoredbversion))
+        {
+			$dbversion_disallowed=array(
+				array('type'=>'mysql','version'=>array(5,5,40)),
+				array('type'=>'mysqli','version'=>array(5,5,40)) //,
+				//array('type'=>'mysql','version'=>array(5,5,41)),
+				//array('type'=>'mysqli','version'=>array(5,5,41))
+			);
+			$listofforbiddenversion='';
+			foreach ($dbversion_disallowed as $dbversion_totest)
+			{
+				if ($dbversion_totest['type'] == $db->type) $listofforbiddenversion.=($listofforbiddenversion?', ':'').join('.',$dbversion_totest['version']);
+			}
+			foreach ($dbversion_disallowed as $dbversion_totest)
+			{
+		        //print $db->type.' - '.join('.',$versionarray).' - '.versioncompare($dbversion_totest['version'],$versionarray)."<br>\n";
+		        if ($dbversion_totest['type'] == $db->type
+		        	&& (versioncompare($dbversion_totest['version'],$versionarray) == 0 || versioncompare($dbversion_totest['version'],$versionarray)<=-4 || versioncompare($dbversion_totest['version'],$versionarray)>=4)
+		        )
+		        {
+		        	// Warning: database version too low.
+		        	print '<tr><td><div class="warning">'.$langs->trans("ErrorDatabaseVersionForbiddenForMigration",join('.',$versionarray),$listofforbiddenversion)."</div></td><td align=\"right\">".$langs->trans("Error")."</td></tr>\n";
+		        	dolibarr_install_syslog("upgrade: " . $langs->transnoentities("ErrorDatabaseVersionForbiddenForMigration", join('.', $versionarray), $listofforbiddenversion));
+		        	$ok=0;
+		        	break;
+		        }
+			}
+        }
     }
 
     // Force l'affichage de la progression
@@ -204,7 +249,7 @@ if (! GETPOST("action") || preg_match('/upgrade/i',GETPOST('action')))
 			    $filles=array();
 			    $sql = "SELECT fk_categorie_mere, fk_categorie_fille";
 			    $sql.= " FROM ".MAIN_DB_PREFIX."categorie_association";
-			    dolibarr_install_syslog("upgrade: search duplicate sql=".$sql);
+			    dolibarr_install_syslog("upgrade: search duplicate");
 			    $resql = $db->query($sql);
 			    if ($resql)
 			    {
@@ -221,7 +266,7 @@ if (! GETPOST("action") || preg_match('/upgrade/i',GETPOST('action')))
 			            }
 			        }
 
-			        dolibarr_install_syslog("upgrade: result is num=".$num." count(couples)=".count($couples));
+			        dolibarr_install_syslog("upgrade: result is num=" . $num . " count(couples)=" . count($couples));
 
 			        // If there is duplicates couples or child with two parents
 			        if (count($couples) > 0 && $num > count($couples))
@@ -232,7 +277,7 @@ if (! GETPOST("action") || preg_match('/upgrade/i',GETPOST('action')))
 
 			            // We delete all
 			            $sql="DELETE FROM ".MAIN_DB_PREFIX."categorie_association";
-			            dolibarr_install_syslog("upgrade: delete association sql=".$sql);
+			            dolibarr_install_syslog("upgrade: delete association");
 			            $resqld=$db->query($sql);
 			            if ($resqld)
 			            {
@@ -241,7 +286,7 @@ if (! GETPOST("action") || preg_match('/upgrade/i',GETPOST('action')))
 			                {
 			                    $sql ="INSERT INTO ".MAIN_DB_PREFIX."categorie_association(fk_categorie_mere,fk_categorie_fille)";
 			                    $sql.=" VALUES(".$val['mere'].", ".$val['fille'].")";
-			                    dolibarr_install_syslog("upgrade: insert association sql=".$sql);
+			                    dolibarr_install_syslog("upgrade: insert association");
 			                    $resqli=$db->query($sql);
 			                    if (! $resqli) $error++;
 			                }
@@ -334,7 +379,7 @@ if (! GETPOST("action") || preg_match('/upgrade/i',GETPOST('action')))
     if ($ok)
     {
         $dir = "mysql/migration/";		// We use mysql migration scripts whatever is database driver
-		if (! empty($versionmodule)) $dir=dol_buildpath('/'.$versionmodule.'/sql/',0);
+		if (! empty($dirmodule)) $dir=dol_buildpath('/'.$dirmodule.'/sql/',0);
 
 		// Clean last part to exclude minor version x.y.z -> x.y
         $newversionfrom=preg_replace('/(\.[0-9]+)$/i','.0',$versionfrom);
@@ -375,47 +420,54 @@ if (! GETPOST("action") || preg_match('/upgrade/i',GETPOST('action')))
             }
         }
 
-        // Loop on each migrate files
-        foreach($filelist as $file)
+        if (count($filelist) == 0)
         {
-        	print '<tr><td colspan="2"><hr></td></tr>';
-            print '<tr><td class="nowrap">'.$langs->trans("ChoosedMigrateScript").'</td><td align="right">'.$file.'</td></tr>'."\n";
-
-            // Run sql script
-            $ok=run_sql($dir.$file, 0, '', 1);
-
-            // Scan if there is migration scripts for modules htdocs/module/sql or htdocs/custom/module/sql
-            $modulesfile = array();
-            foreach ($conf->file->dol_document_root as $type => $dirroot)
-            {
-            	$handlemodule=@opendir($dirroot);		// $dirroot may be '..'
-            	if (is_resource($handlemodule))
-            	{
-            		while (($filemodule = readdir($handlemodule))!==false)
-            		{
-            			if (! preg_match('/\./',$filemodule) && is_dir($dirroot.'/'.$filemodule.'/sql'))	// We exclude filemodule that contains . (are not directories) and are not directories.
-            			{
-            				//print "Scan for ".$dirroot . '/' . $filemodule . '/sql/'.$file;
-            				if (is_file($dirroot . '/' . $filemodule . '/sql/'.$file))
-            				{
-            					$modulesfile[$dirroot . '/' . $filemodule . '/sql/'.$file] = '/' . $filemodule . '/sql/'.$file;
-            				}
-            			}
-            		}
-            		closedir($handlemodule);
-            	}
-            }
-
-            foreach ($modulesfile as $modulefilelong => $modulefileshort)
-            {
-            	print '<tr><td colspan="2"><hr></td></tr>';
-            	print '<tr><td class="nowrap">'.$langs->trans("ChoosedMigrateScript").' (external modules)</td><td align="right">'.$modulefileshort.'</td></tr>'."\n";
+        	print '<div class="error">'.$langs->trans("ErrorNoMigrationFilesFoundForParameters").'</div>';
+        }
+		else
+		{
+	        // Loop on each migrate files
+	        foreach($filelist as $file)
+	        {
+	        	print '<tr><td colspan="2"><hr></td></tr>';
+	            print '<tr><td class="nowrap">'.$langs->trans("ChoosedMigrateScript").'</td><td align="right">'.$file.'</td></tr>'."\n";
 
 	            // Run sql script
-            	$okmodule=run_sql($modulefilelong, 0, '', 1);	// Note: Result of migration of external module should not decide if we continue migration of Dolibarr or not.
-            }
+	            $ok=run_sql($dir.$file, 0, '', 1);
 
-        }
+	            // Scan if there is migration scripts for modules htdocs/module/sql or htdocs/custom/module/sql
+	            $modulesfile = array();
+	            foreach ($conf->file->dol_document_root as $type => $dirroot)
+	            {
+	            	$handlemodule=@opendir($dirroot);		// $dirroot may be '..'
+	            	if (is_resource($handlemodule))
+	            	{
+	            		while (($filemodule = readdir($handlemodule))!==false)
+	            		{
+	            			if (! preg_match('/\./',$filemodule) && is_dir($dirroot.'/'.$filemodule.'/sql'))	// We exclude filemodule that contains . (are not directories) and are not directories.
+	            			{
+	            				//print "Scan for ".$dirroot . '/' . $filemodule . '/sql/'.$file;
+	            				if (is_file($dirroot . '/' . $filemodule . '/sql/'.$file))
+	            				{
+	            					$modulesfile[$dirroot . '/' . $filemodule . '/sql/'.$file] = '/' . $filemodule . '/sql/'.$file;
+	            				}
+	            			}
+	            		}
+	            		closedir($handlemodule);
+	            	}
+	            }
+
+	            foreach ($modulesfile as $modulefilelong => $modulefileshort)
+	            {
+	            	print '<tr><td colspan="2"><hr></td></tr>';
+	            	print '<tr><td class="nowrap">'.$langs->trans("ChoosedMigrateScript").' (external modules)</td><td align="right">'.$modulefileshort.'</td></tr>'."\n";
+
+		            // Run sql script
+	            	$okmodule=run_sql($modulefilelong, 0, '', 1);	// Note: Result of migration of external module should not decide if we continue migration of Dolibarr or not.
+	            }
+
+	        }
+		}
     }
 
     print '</table>';
@@ -432,10 +484,10 @@ $ret=0;
 if (! $ok && isset($argv[1])) $ret=1;
 dol_syslog("Exit ".$ret);
 
-pFooter(((! $ok && empty($_GET["ignoreerrors"])) || $versionmodule),$setuplang);
+dolibarr_install_syslog("--- upgrade: end ".((! $ok && empty($_GET["ignoreerrors"])) || $dirmodule));
+pFooter(((! $ok && empty($_GET["ignoreerrors"])) || $dirmodule)?2:0,$setuplang);
 
 if ($db->connected) $db->close();
 
 // Return code if ran from command line
 if ($ret) exit($ret);
-?>
\ No newline at end of file
