@@ -1,5 +1,5 @@
 <?php
-/* Copyright (C) 2014-2016	Alexandre Spangaro   <aspangaro.dolibarr@gmail.com>
+/* Copyright (C) 2014-2016	Alexandre Spangaro   <aspangaro@zendsi.com>
  * Copyright (C) 2015       Frederic France      <frederic.france@free.fr>
  *
  * This program is free software; you can redistribute it and/or modify
@@ -86,8 +86,9 @@ if ($action == 'add' && $user->rights->loan->write)
 {
 	if (! $cancel)
 	{
-		$datestart=@dol_mktime(12,0,0, $_POST["startmonth"], $_POST["startday"], $_POST["startyear"]);
-		$dateend=@dol_mktime(12,0,0, $_POST["endmonth"], $_POST["endday"], $_POST["endyear"]);
+		$datestart	= dol_mktime(12, 0, 0, GETPOST('startmonth','int'), GETPOST('startday','int'), GETPOST('startyear','int'));
+		$dateend	= dol_mktime(12, 0, 0, GETPOST('endmonth','int'), GETPOST('endday','int'), GETPOST('endyear','int'));
+		$capital 	= price2num(GETPOST('capital'));
 
 		if (! $datestart)
 		{
@@ -99,20 +100,20 @@ if ($action == 'add' && $user->rights->loan->write)
 			setEventMessages($langs->trans("ErrorFieldRequired", $langs->transnoentities("DateEnd")), null, 'errors');
 			$action = 'create';
 		}
-		elseif (! $_POST["capital"])
+		elseif (! $capital)
 		{
 			setEventMessages($langs->trans("ErrorFieldRequired", $langs->transnoentities("LoanCapital")), null, 'errors');
 			$action = 'create';
 		}
 		else
 		{
-			$object->label					= $_POST["label"];
-			$object->fk_bank				= $_POST["accountid"];
-			$object->capital				= $_POST["capital"];
+			$object->label					= GETPOST('label');
+			$object->fk_bank				= GETPOST('accountid');
+			$object->capital				= $capital;
 			$object->datestart				= $datestart;
 			$object->dateend				= $dateend;
-			$object->nbterm					= $_POST["nbterm"];
-			$object->rate					= $_POST["rate"];
+			$object->nbterm					= GETPOST('nbterm');
+			$object->rate					= GETPOST('rate');
 			$object->note_private 			= GETPOST('note_private');
 			$object->note_public 			= GETPOST('note_public');
 
@@ -147,9 +148,9 @@ else if ($action == 'update' && $user->rights->loan->write)
 
 		if ($object->fetch($id))
 		{
-			$object->label		= GETPOST("label");
 			$object->datestart	= dol_mktime(12, 0, 0, GETPOST('startmonth','int'), GETPOST('startday','int'), GETPOST('startyear','int'));
 			$object->dateend	= dol_mktime(12, 0, 0, GETPOST('endmonth','int'), GETPOST('endday','int'), GETPOST('endyear','int'));
+			$object->capital	= price2num(GETPOST("capital"));
 			$object->nbterm		= GETPOST("nbterm");
 			$object->rate		= GETPOST("rate");
 		}
@@ -173,6 +174,14 @@ else if ($action == 'update' && $user->rights->loan->write)
     }
 }
 
+if ($action == 'setlabel' && $user->rights->loan->write)
+{
+	$object->fetch($id);
+	$result = $object->setValueFrom('label', GETPOST('label'), '', '', 'text', '', $user, 'LOAN_MODIFY');
+	if ($result < 0)
+	setEventMessages($object->error, $object->errors, 'errors');
+}
+
 /*
  * View
  */
@@ -180,8 +189,9 @@ else if ($action == 'update' && $user->rights->loan->write)
 $form = new Form($db);
 if (! empty($conf->accounting->enabled)) $formaccountancy = New FormVentilation($db);
 
-$help_url='EN:Module_Loan|FR:Module_Emprunt';
-llxHeader("",$langs->trans("Loan"),$help_url);
+$title = $langs->trans("Loan") . ' - ' . $langs->trans("Card");
+$help_url = 'EN:Module_Loan|FR:Module_Emprunt';
+llxHeader("",$title,$help_url);
 
 
 // Create mode
@@ -203,7 +213,7 @@ if ($action == 'create')
     print '<table class="border" width="100%">';
 
 	// Label
-	print '<tr><td class="fieldrequired titlefieldcreate">'.$langs->trans("Label").'</td><td colspan="3"><input name="label" size="40" maxlength="255" value="'.dol_escape_htmltag(GETPOST('label')).'"></td></tr>';
+	print '<tr><td class="fieldrequired titlefieldcreate">'.$langs->trans("Label").'</td><td><input name="label" size="40" maxlength="255" value="'.dol_escape_htmltag(GETPOST('label')).'"></td></tr>';
 
 	// Bank account
 	if (! empty($conf->banque->enabled))
@@ -220,7 +230,7 @@ if ($action == 'create')
 	}
 
     // Capital
-    print '<tr><td class="fieldrequired">'.$langs->trans("LoanCapital").'</td><td><input name="capital" size="10" value="' . GETPOST("capital") . '"></td></tr>';
+    print '<tr><td class="fieldrequired">'.$langs->trans("LoanCapital").'</td><td><input name="capital" size="10" value="' . dol_escape_htmltag(GETPOST("capital")) . '"></td></tr>';
 
 	// Date Start
 	print "<tr>";
@@ -235,17 +245,17 @@ if ($action == 'create')
     print '</td></tr>';
 
 	// Number of terms
-	print '<tr><td class="fieldrequired">'.$langs->trans("Nbterms").'</td><td><input name="nbterm" size="5" value="' . GETPOST('nbterm') . '"></td></tr>';
+	print '<tr><td class="fieldrequired">'.$langs->trans("Nbterms").'</td><td><input name="nbterm" size="5" value="' . dol_escape_htmltag(GETPOST('nbterm')) . '"></td></tr>';
 
 	// Rate
-    print '<tr><td class="fieldrequired">'.$langs->trans("Rate").'</td><td><input name="rate" size="5" value="' . GETPOST("rate") . '"> %</td></tr>';
+    print '<tr><td class="fieldrequired">'.$langs->trans("Rate").'</td><td><input name="rate" size="5" value="' . dol_escape_htmltag(GETPOST("rate")) . '"> %</td></tr>';
 
     // Note Private
     print '<tr>';
     print '<td class="border" valign="top">'.$langs->trans('NotePrivate').'</td>';
-    print '<td valign="top" colspan="2">';
+    print '<td class="tdtop">';
 
-    $doleditor = new DolEditor('note_private', GETPOST('note_private', 'alpha'), '', 160, 'dolibarr_notes', 'In', false, true, true, ROWS_6, 100);
+    $doleditor = new DolEditor('note_private', GETPOST('note_private', 'alpha'), '', 160, 'dolibarr_notes', 'In', false, true, true, ROWS_6, '90%');
     print $doleditor->Create(1);
 
     print '</td></tr>';
@@ -253,16 +263,11 @@ if ($action == 'create')
     // Note Public
     print '<tr>';
     print '<td class="border" valign="top">'.$langs->trans('NotePublic').'</td>';
-    print '<td valign="top" colspan="2">';
-    $doleditor = new DolEditor('note_public', GETPOST('note_public', 'alpha'), '', 160, 'dolibarr_notes', 'In', false, true, true, ROWS_6, 100);
+    print '<td class="tdtop">';
+    $doleditor = new DolEditor('note_public', GETPOST('note_public', 'alpha'), '', 160, 'dolibarr_notes', 'In', false, true, true, ROWS_6, '90%');
     print $doleditor->Create(1);
     print '</td></tr>';
 
-	print '</table>';
-
-	print '<br>';
-
-	print '<table class="border" width="100%">';
     // Accountancy
 	if (! empty($conf->accounting->enabled))
 	{
@@ -283,7 +288,7 @@ if ($action == 'create')
         print '<td>';
 		print $formaccountancy->select_account($object->accountancy_account_interest, 'accountancy_account_interest', 1, '', 0, 1);
         print '</td></tr>';
-	}			
+	}
 	else // For external software 
 	{
         // Accountancy_account_capital
@@ -300,15 +305,16 @@ if ($action == 'create')
         print '<tr><td class="fieldrequired">'.$langs->trans("LoanAccountancyInterestCode").'</td>';
         print '<td><input name="accountancy_account_interest" size="16" value="'.$object->accountancy_account_interest.'">';
         print '</td></tr>';
-        
-        print '</table>';
 	}
 	print '</table>';
-	
+
 	dol_fiche_end();
 
-    print '<div align="center"><input class="button" type="submit" value="'.$langs->trans("Save").'">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;';
-    print '<input class="button" type="submit" name="cancel" value="'.$langs->trans("Cancel").'"></div>';
+	print '<div class="center">';
+	print '<input type="submit" class="button" value="'.$langs->trans("Add").'">';
+	print '&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;';
+	print '<input type="button" class="button" value="' . $langs->trans("Cancel") . '" onClick="javascript:history.go(-1)">';
+	print '</div>';
 
     print '</form>';
 }
@@ -316,12 +322,15 @@ if ($action == 'create')
 // View
 if ($id > 0)
 {
+	$object = new Loan($db);
     $result = $object->fetch($id);
 
 	if ($result > 0)
 	{
 		$head=loan_prepare_head($object);
 
+		$totalpaid = $object->getSumPayment();
+
 		// Confirm for loan
 		if ($action == 'paid')
 		{
@@ -345,27 +354,54 @@ if ($id > 0)
 
 		dol_fiche_head($head, 'card', $langs->trans("Loan"), 0, 'bill');
 
+		$morehtmlref='<div class="refidno">';
+		// Ref loan
+		$morehtmlref.=$form->editfieldkey("Label", 'label', $object->label, $object, $user->rights->loan->write, 'string', '', 0, 1);
+		$morehtmlref.=$form->editfieldval("Label", 'label', $object->label, $object, $user->rights->loan->write, 'string', '', null, null, '', 1);
+		$morehtmlref.='</div>';
+
+		$linkback = '<a href="' . DOL_URL_ROOT . '/loan/index.php">' . $langs->trans("BackToList") . '</a>';
+
+		$object->totalpaid = $totalpaid;   // To give a chance to dol_banner_tab to use already paid amount to show correct status
+
+		dol_banner_tab($object, 'id', $linkback, 1, 'rowid', 'ref', $morehtmlref, '', 0, '', $morehtmlright);
+
+		print '<div class="fichecenter">';
+		print '<div class="fichehalfleft">';
+		print '<div class="underbanner clearboth"></div>';
+
 		print '<table class="border" width="100%">';
 
+		/*
 		// Ref
-		print '<tr><td class="titlefield">'.$langs->trans("Ref").'</td><td colspan="3">';
+		print '<tr><td class="titlefield">'.$langs->trans("Ref").'</td><td>';
 		print $form->showrefnav($object,'id');
 		print "</td></tr>";
 
 		// Label
 		if ($action == 'edit')
 		{
-			print '<tr><td>'.$langs->trans("Label").'</td><td colspan="2">';
+			print '<tr><td>'.$langs->trans("Label").'</td><td>';
 			print '<input type="text" name="label" size="40" value="'.$object->label.'">';
 			print '</td></tr>';
 		}
 		else
 		{
-			print '<tr><td>'.$langs->trans("Label").'</td><td colspan="2">'.$object->label.'</td></tr>';
+			print '<tr><td>'.$langs->trans("Label").'</td><td>'.$object->label.'</td></tr>';
 		}
+		*/
 
 		// Capital
-		print '<tr><td>'.$langs->trans("LoanCapital").'</td><td>'.price($object->capital,0,$outputlangs,1,-1,-1,$conf->currency).'</td></tr>';
+		if ($action == 'edit')
+		{
+			print '<tr><td class="titlefield">'.$langs->trans("LoanCapital").'</td><td>';
+			print '<input name="capital" size="10" value="' . $object->capital . '"></td></tr>';
+			print '</td></tr>';
+		}
+		else
+		{
+			print '<tr><td class="titlefield">'.$langs->trans("LoanCapital").'</td><td>'.price($object->capital,0,$outputlangs,1,-1,-1,$conf->currency).'</td></tr>';
+		}
 
     	// Date start
 		print "<tr><td>".$langs->trans("DateStart")."</td>";
@@ -399,12 +435,6 @@ if ($id > 0)
 		// Rate
 		print '<tr><td>'.$langs->trans("Rate").'</td><td>'.$object->rate.' %</td></tr>';
 
-        // Note Private
-        print '<tr><td>'.$langs->trans('NotePrivate').'</td><td>'.nl2br($object->note_private).'</td></tr>';
-
-        // Note Public
-        print '<tr><td>'.$langs->trans('NotePublic').'</td><td>'.nl2br($object->note_public).'</td></tr>';
-
         // Accountancy account capital
 		print '<tr><td class="nowrap">';
         print $langs->trans("LoanAccountancyCapitalCode");
@@ -439,25 +469,13 @@ if ($id > 0)
 		print '</td></tr>';
 
 		// Status
-		print '<tr><td>'.$langs->trans("Status").'</td><td>'.$object->getLibStatut(4, $totalpaye).'</td></tr>';
+		// print '<tr><td>'.$langs->trans("Status").'</td><td>'.$object->getLibStatut(4, $totalpaye).'</td></tr>';
 
 		print '</table>';
 
-		dol_fiche_end();
-
-	
-		if ($action == 'edit')
-		{
-			print '<div align="center">';
-			print '<input type="submit" class="button" name="save" value="'.$langs->trans("Save").'">';
-			print ' &nbsp; ';
-			print '<input type="submit" class="button" name="cancel" value="'.$langs->trans("Cancel").'">';
-			print '</div>';
-			print '</form><br><br>';
-		}
-		
-		print '<table class="border" width="100%">';
-		print '<tr><td>';
+		print '</div>';
+		print '<div class="fichehalfright">';
+		print '<div class="ficheaddleft">';
 
 		/*
 		 * Payments
@@ -483,14 +501,14 @@ if ($id > 0)
             $total_insurance = 0;
             $total_interest = 0;
             $total_capital = 0;
-			echo '<table class="nobordernopadding" width="100%">';
+			print '<table class="noborder paymenttable">';
 			print '<tr class="liste_titre">';
 			print '<td>'.$langs->trans("RefPayment").'</td>';
 			print '<td>'.$langs->trans("Date").'</td>';
 			print '<td>'.$langs->trans("Type").'</td>';
-			print '<td align="center">'.$langs->trans("Insurance").'</td>';
-			print '<td align="center">'.$langs->trans("Interest").'</td>';
-      		print '<td align="center">'.$langs->trans("LoanCapital").'</td>';
+			print '<td align="right">'.$langs->trans("Insurance").'</td>';
+			print '<td align="right">'.$langs->trans("Interest").'</td>';
+      		print '<td align="right">'.$langs->trans("LoanCapital").'</td>';
       		print '</tr>';
 
 			$var=True;
@@ -514,13 +532,13 @@ if ($id > 0)
 
 			if ($object->paid == 0)
 			{
-				print '<tr><td colspan="5" align="right">'.$langs->trans("AlreadyPaid").' :</td><td align="right"><b>'.price($totalpaid, 0, $langs, 0, 0, -1, $conf->currency).'</b></td></tr>';
-				print '<tr><td colspan="5" align="right">'.$langs->trans("AmountExpected").' :</td><td align="right" bgcolor="#d0d0d0">'.price($object->capital, 0, $langs, 0, 0, -1, $conf->currency).'</td></tr>';
+				print '<tr><td colspan="5" align="right">'.$langs->trans("AlreadyPaid").' :</td><td align="right">'.price($totalpaid, 0, $langs, 0, 0, -1, $conf->currency).'</td></tr>';
+				print '<tr><td colspan="5" align="right">'.$langs->trans("AmountExpected").' :</td><td align="right">'.price($object->capital,0,$outputlangs,1,-1,-1,$conf->currency).'</td></tr>';
 
 				$staytopay = $object->capital - $totalpaid;
 
 				print '<tr><td colspan="5" align="right">'.$langs->trans("RemainderToPay").' :</td>';
-				print '<td align="right" bgcolor="#f0f0f0"><b>'.price($staytopay, 0, $langs, 0, 0, -1, $conf->currency).'</b></td></tr>';
+				print '<td align="right"><b>'.price($staytopay, 0, $langs, 0, 0, -1, $conf->currency).'</b></td></tr>';
 			}
 			print "</table>";
 			$db->free($resql);
@@ -529,8 +547,25 @@ if ($id > 0)
 		{
 			dol_print_error($db);
 		}
-		print "</td></tr>";
-		print "</table>";
+
+		print '</div>';
+		print '</div>';
+		print '</div>';
+
+		print '<div class="clearboth"></div>';
+
+		dol_fiche_end();
+
+		if ($action == 'edit')
+		{
+			print '<div class="center">';
+			print '<input type="submit" class="button" name="save" value="'.$langs->trans("Save").'">';
+			print '&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;';
+			print '<input type="submit" class="button" name="cancel" value="'.$langs->trans("Cancel").'">';
+			print '</div>';
+		}
+
+		if ($action == 'edit') print "</form>\n";
 
 		/*
 		 *   Buttons actions
@@ -568,7 +603,7 @@ if ($id > 0)
 	}
 	else
 	{
-		// Loan not find
+		// Loan not found
 		dol_print_error('',$object->error);
 	}
 }
