@@ -86,8 +86,8 @@ if ($action == 'add_prod' && ($user->rights->produit->creer || $user->rights->se
 				$action = 're-edit';
 				if ($object->error == "isFatherOfThis") {
 					setEventMessages($langs->trans("ErrorAssociationIsFatherOfThis"), null, 'errors');
-				} 
-				else 
+				}
+				else
 				{
 					setEventMessages($object->error, $object->errors, 'errors');
 				}
@@ -204,15 +204,22 @@ if ($id > 0 || ! empty($ref))
 	if ($user->rights->produit->lire || $user->rights->service->lire)
 	{
         $linkback = '<a href="'.DOL_URL_ROOT.'/product/list.php">'.$langs->trans("BackToList").'</a>';
-	    
-        dol_banner_tab($object, 'ref', $linkback, ($user->societe_id?0:1), 'ref');
-		
-		print '<table class="border tableforfield" width="100%">';
+
+        $shownav = 1;
+        if ($user->societe_id && ! in_array('product', explode(',',$conf->global->MAIN_MODULES_FOR_EXTERNAL))) $shownav=0;
+
+        dol_banner_tab($object, 'ref', $linkback, $shownav, 'ref', '', '', '', 0, '', '', 1);
+
+        if ($object->type!=Product::TYPE_SERVICE || empty($conf->global->PRODUIT_MULTIPRICES))
+        {
+    	    print '<div class="underbanner clearboth"></div>';
+            print '<table class="border tableforfield" width="100%">';
+        }
 
 		// Nature
-		if($object->type!=Product::TYPE_SERVICE)
+		if ($object->type!=Product::TYPE_SERVICE)
 		{
-			print '<tr><td>'.$langs->trans("Nature").'</td><td colspan="2">';
+			print '<tr><td>'.$langs->trans("Nature").'</td><td>';
 			print $object->getLibFinished();
 			print '</td></tr>';
 		}
@@ -244,15 +251,19 @@ if ($id > 0 || ! empty($ref))
 			print '</td></tr>';
 		}
 
-		print '</table>';
+        if ($object->type!=Product::TYPE_SERVICE || empty($conf->global->PRODUIT_MULTIPRICES))
+        {
+		  print '</table>';
+        }
 
 		dol_fiche_end();
 
+        print '<br>';
 
 		$prodsfather = $object->getFather(); 		// Parent Products
 		$object->get_sousproduits_arbo();			// Load $object->sousprods
-		$prods_arbo=$object->get_arbo_each_prod();		
-		
+		$prods_arbo=$object->get_arbo_each_prod();
+
 		$nbofsubsubproducts=count($prods_arbo);		// This include sub sub product into nb
 		$prodschild = $object->getChildsArbo($id,1);
 		$nbofsubproducts=count($prodschild);		// This include only first level of childs
@@ -361,7 +372,7 @@ if ($id > 0 || ! empty($ref))
 
 					    $totalline=price2num($value['nb'] * ($product_fourn->fourn_unitprice * (1 - $product_fourn->fourn_remise_percent/100) + $product_fourn->fourn_unitcharges - $product_fourn->fourn_remise), 'MT');
 						$total+=$totalline;
-						
+
 						print '<td align="right">';
 						print ($notdefined?'':($value['nb']> 1 ? $value['nb'].'x' : '').price($product_fourn->fourn_unitprice,'','',0,0,-1,$conf->currency));
 						print '</td>';
@@ -377,7 +388,7 @@ if ($id > 0 || ! empty($ref))
 						print '<td align="right" colspan="2">';
 						print ($notdefined?'':($value['nb']> 1 ? $value['nb'].'x' : '').price($pricesell,'','',0,0,-1,$conf->currency));
 						print '</td>';
-						
+
 						// Stock
 						if (! empty($conf->stock->enabled)) print '<td align="right">'.$value['stock'].'</td>';	// Real stock
 
@@ -416,7 +427,7 @@ if ($id > 0 || ! empty($ref))
 						// Best selling price
 						print '<td>&nbsp;</td>';
 						print '<td>&nbsp;</td>';
-						
+
 						if (! empty($conf->stock->enabled)) print '<td></td>';	// Real stock
 						print '<td align="center">'.$value['nb'].'</td>';
 						print '<td>&nbsp;</td>';
@@ -448,7 +459,7 @@ if ($id > 0 || ! empty($ref))
 				if ($atleastonenotdefined) print $langs->trans("Unknown").' ('.$langs->trans("SomeSubProductHaveNoPrices").')';
 				print ($atleastonenotdefined?'':price($totalsell,'','',0,0,-1,$conf->currency));
 				print '</td>';
-				
+
 				// Stock
 				if (! empty($conf->stock->enabled)) print '<td class="liste_total" align="right">&nbsp;</td>';
 
