@@ -5,7 +5,7 @@
  * Copyright (C) 2005-2015	Regis Houssin			<regis.houssin@capnetworks.com>
  * Copyright (C) 2006		Andre Cianfarani		<acianfa@free.fr>
  * Copyright (C) 2014		Florian Henry			<florian.henry@open-concept.pro>
- * Copyright (C) 2014		Juanjo Menent			<jmenent@2byte.es>
+ * Copyright (C) 2014-2016	Juanjo Menent			<jmenent@2byte.es>
  * Copyright (C) 2014-2015 	Philippe Grand 		    <philippe.grand@atoo-net.com>
  * Copyright (C) 2014		Ion agorria				<ion@agorria.com>
  * Copyright (C) 2015		Alexandre Spangaro		<aspangaro.dolibarr@gmail.com>
@@ -88,11 +88,19 @@ if ($reshook < 0) setEventMessages($hookmanager->error, $hookmanager->errors, 'e
 
 if (empty($reshook))
 {
-    if (GETPOST("button_removefilter_x") || GETPOST("button_removefilter.x") || GETPOST("button_removefilter")) // Both test are required to be compatible with all browsers
+    if (GETPOST("button_removefilter_x") || GETPOST("button_removefilter.x") || GETPOST("button_removefilter")) // All tests are required to be compatible with all browsers
     {
-        $search_soc = '';        
+        $search_soc = '';
     }
-    
+
+    if ($action == 'setlabelsellingprice' && $user->admin)
+    {
+        require_once DOL_DOCUMENT_ROOT . '/core/lib/admin.lib.php';
+        $keyforlabel = 'PRODUIT_MULTIPRICES_LABEL'.GETPOST('pricelevel');
+        dolibarr_set_const($db, $keyforlabel, GETPOST('labelsellingprice','alpha'), 'chaine', 0, '', $conf->entity);
+        $action = '';
+    }
+
 	if (($action == 'update_vat') && !$cancel && ($user->rights->produit->creer || $user->rights->service->creer))
 	{
 	    $tva_tx_txt = GETPOST('tva_tx', 'alpha');           // tva_tx can be '8.5'  or  '8.5*'  or  '8.5 (XXX)' or '8.5* (XXX)'
@@ -105,7 +113,7 @@ if (empty($reshook))
 	    // If value contains the unique code of vat line (new recommanded method), we use it to find npr and local taxes
 	    if (preg_match('/\((.*)\)/', $tva_tx_txt, $reg))
 	    {
-	        // We look into database using code
+	        // We look into database using code (we can't use get_localtax() because it depends on buyer that is not known). Same in create product.
 	        $vatratecode=$reg[1];
 	        // Get record from code
 	        $sql = "SELECT t.rowid, t.code, t.recuperableonly, t.localtax1, t.localtax2, t.localtax1_type, t.localtax2_type";
@@ -141,14 +149,14 @@ if (empty($reshook))
 	        $error++;
 	        setEventMessages($object->error, $object->errors, 'errors');
 	    }
-	    
+
 	    if ($error)
 	    {
 	        //$localtaxarray=array('0'=>$localtax1_type,'1'=>$localtax1,'2'=>$localtax2_type,'3'=>$localtax2);
 	        $localtaxarray=array();    // We do not store localtaxes into product, we will use instead the "vat code" to retreive them.
 	        $object->updatePrice(0, $object->price_base_type, $user, $tva_tx, '', 0, $npr, 0, 0, $localtaxarray, $vatratecode);
 	    }
-	    
+
 	    if (! $error)
 	    {
 	        $db->commit();
@@ -157,10 +165,10 @@ if (empty($reshook))
 	    {
 	        $db->rollback();
 	    }
-	    
+
 	    $action='';
 	}
-	    
+
 	if (($action == 'update_price') && !$cancel && $object->getRights()->creer)
     {
 		$error = 0;
@@ -200,14 +208,14 @@ if (empty($reshook))
 			//Shall we generate prices using price rules?
 			$object->price_autogen = GETPOST('usePriceRules') == 'on';
 
-			for ($i = 1; $i <= $conf->global->PRODUIT_MULTIPRICES_LIMIT; $i ++) 
+			for ($i = 1; $i <= $conf->global->PRODUIT_MULTIPRICES_LIMIT; $i ++)
 			{
 				if (!isset($newprice[$i])) {
 					continue;
 				}
 
 				$tva_tx_txt = $newvattx[$i];
-				
+
 				$vatratecode = '';
         	    $tva_tx = preg_replace('/[^0-9\.].*$/', '', $tva_tx_txt);     // keep remove all after the numbers and dot
         	    $npr = preg_match('/\*/', $tva_tx_txt) ? 1 : 0;
@@ -234,7 +242,7 @@ if (empty($reshook))
         	            $localtax2 = $obj->localtax2;
         	            $localtax1_type = $obj->localtax1_type;
         	            $localtax2_type = $obj->localtax2_type;
-        	        }        	        
+        	        }
         	    }
 
 				$pricestoupdate[$i] = array(
@@ -282,6 +290,13 @@ if (empty($reshook))
 		            $localtax2 = $obj->localtax2;
 		            $localtax1_type = $obj->localtax1_type;
 		            $localtax2_type = $obj->localtax2_type;
+
+		            // If spain, we don't use the localtax found into tax record in database with same code, but using the get_localtax rule
+		            if (in_array($mysoc->country_code, array('ES')))
+		            {
+    		            $localtax1 = get_localtax($tva_tx,1);
+	   	                $localtax2 = get_localtax($tva_tx,2);
+		            }
 		        }
 		    }
 			$pricestoupdate[0] = array(
@@ -454,7 +469,7 @@ if (empty($reshook))
 		$prodcustprice->price_base_type = GETPOST("price_base_type", 'alpha');
 
 		$tva_tx_txt = GETPOST("tva_tx");
-		
+
 		$vatratecode = '';
 		// We must define tva_tx, npr and local taxes
 		$tva_tx = preg_replace('/[^0-9\.].*$/', '', $tva_tx_txt);     // keep remove all after the numbers and dot
@@ -481,8 +496,8 @@ if (empty($reshook))
 		        $localtax1_type = $obj->localtax1_type;
 		        $localtax2_type = $obj->localtax2_type;
 		    }
-		}		
-		
+		}
+
 		$prodcustprice->default_vat_code = $vatratecode;
 		$prodcustprice->tva_tx = $tva_tx;
 		$prodcustprice->recuperableonly = $npr;
@@ -490,7 +505,7 @@ if (empty($reshook))
 		$prodcustprice->localtax2_tx = $localtax2;
 		$prodcustprice->localtax1_type = $localtax1_type;
 		$prodcustprice->localtax2_type = $localtax2_type;
-		
+
 		if (! ($prodcustprice->fk_soc > 0))
 		{
 		    $langs->load("errors");
@@ -576,7 +591,7 @@ if (empty($reshook))
 		        $localtax2_type = $obj->localtax2_type;
 		    }
 		}
-		
+
 		$prodcustprice->default_vat_code = $vatratecode;
 		$prodcustprice->tva_tx = $tva_tx;
 		$prodcustprice->recuperableonly = $npr;
@@ -584,7 +599,7 @@ if (empty($reshook))
 		$prodcustprice->localtax2_tx = $localtax2;
 		$prodcustprice->localtax1_type = $localtax1_type;
 		$prodcustprice->localtax2_type = $localtax2_type;
-		
+
 		if ($prodcustprice->price_min < $maxpricesupplier && !empty($conf->global->PRODUCT_MINIMUM_RECOMMENDED_PRICE))
 		{
 			setEventMessages($langs->trans("MinimumPriceLimit",price($maxpricesupplier,0,'',1,-1,-1,'auto')), null, 'errors');
@@ -643,7 +658,10 @@ dol_fiche_head($head, 'price', $titre, 0, $picto);
 
 $linkback = '<a href="'.DOL_URL_ROOT.'/product/list.php">'.$langs->trans("BackToList").'</a>';
 
-dol_banner_tab($object, 'ref', $linkback, ($user->societe_id?0:1), 'ref');
+$shownav = 1;
+if ($user->societe_id && ! in_array('product', explode(',',$conf->global->MAIN_MODULES_FOR_EXTERNAL))) $shownav=0;
+
+dol_banner_tab($object, 'ref', $linkback, $shownav, 'ref');
 
 
 print '<div class="fichecenter">';
@@ -662,7 +680,9 @@ if (! empty($conf->global->PRODUIT_MULTIPRICES))
 		$soc->fetch($socid);
 
 		// Selling price
-		print '<tr><td class="titlefield">' . $langs->trans("SellingPrice") . '</td>';
+		print '<tr><td class="titlefield">';
+		print $langs->trans("SellingPrice");
+		print '</td>';
 		print '<td colspan="2">';
 		if ($object->multiprices_base_type[$soc->price_level] == 'TTC') {
 			print price($object->multiprices_ttc[$soc->price_level]);
@@ -685,7 +705,7 @@ if (! empty($conf->global->PRODUIT_MULTIPRICES))
 			print price($object->multiprices_min[$soc->price_level]) . ' ' . $langs->trans(empty($object->multiprices_base_type[$soc->price_level])?'HT':$object->multiprices_base_type[$soc->price_level]);
 		}
 		print '</td></tr>';
-        
+
 		if (! empty($conf->global->PRODUIT_MULTIPRICES_USE_VAT_PER_LEVEL))  // using this option is a bug. kept for backward compatibility
 		{
     	   // TVA
@@ -702,14 +722,16 @@ if (! empty($conf->global->PRODUIT_MULTIPRICES))
         	else print vatrate($object->tva_tx . ($object->tva_npr ? '*' : ''), true);
         	print '</td></tr>';
 		}
-		
+
 	}
 	else
 	{
 		if (! empty($conf->global->PRODUIT_MULTIPRICES_USE_VAT_PER_LEVEL))  // using this option is a bug. kept for backward compatibility
 		{
     	   // We show only vat for level 1
-	       print '<tr><td class="titlefield">' . $langs->trans("VATRate") . '</td><td colspan="2">' . vatrate($object->multiprices_tva_tx[1], true) . '</td></tr>';
+	       print '<tr><td class="titlefield">' . $langs->trans("VATRate") . '</td>';
+	       print '<td colspan="2">' . vatrate($object->multiprices_tva_tx[1], true) . '</td>';
+	       print '</tr>';
 		}
 		else
 		{
@@ -722,17 +744,46 @@ if (! empty($conf->global->PRODUIT_MULTIPRICES))
 	        else print vatrate($object->tva_tx . ($object->tva_npr ? '*' : ''), true);
 	        print '</td></tr>';
 		}
-	   
-		print '<tr class="liste_titre"><td style="text-align: center">'.$langs->trans("PriceLevel").'</td><td style="text-align: center">'.$langs->trans("SellingPrice").'</td><td style="text-align: center">'.$langs->trans("MinPrice").'</td></tr>';
+	    print '</table>';
+
+	    print '<br>';
+
+	    print '<table class="noborder tableforfield" width="100%">';
+		print '<tr class="liste_titre"><td>';
+		print $langs->trans("PriceLevel");
+		if ($user->admin) print ' <a href="'.$_SERVER["PHP_SELF"].'?action=editlabelsellingprice&amp;pricelevel='.$i.'&amp;id='.$object->id.'">'.img_edit($langs->trans('EditSellingPriceLabel'),0).'</a>';
+		print '</td>';
+		print '<td style="text-align: right">'.$langs->trans("SellingPrice").'</td>';
+		print '<td style="text-align: right">'.$langs->trans("MinPrice").'</td>';
+		print '</tr>';
+
+		$var=True;
 
 		for($i = 1; $i <= $conf->global->PRODUIT_MULTIPRICES_LIMIT; $i++)
 		{
-			print '<tr>';
+		    $var = ! $var;
+
+			print '<tr '.$bc[$var].'>';
 
 			// Label of price
-			print '<td>' . $langs->trans("SellingPrice") . ' ' . $i;
+			print '<td>';
 			$keyforlabel='PRODUIT_MULTIPRICES_LABEL'.$i;
-			if (! empty($conf->global->$keyforlabel)) print ' - '.$langs->trans($conf->global->$keyforlabel);
+			if (preg_match('/editlabelsellingprice/', $action))
+			{
+			    print '<form method="post" action="'.$_SERVER["PHP_SELF"].'?id='.$object->id.'">';
+			    print '<input type="hidden" name="token" value="'.$_SESSION['newtoken'].'">';
+			    print '<input type="hidden" name="action" value="setlabelsellingprice">';
+			    print '<input type="hidden" name="pricelevel" value="'.$i.'">';
+			    print $langs->trans("SellingPrice") . ' ' . $i.' - ';
+			    print '<input size="10" class="maxwidthonsmartphone" type="text" name="labelsellingprice" value="'.$conf->global->$keyforlabel.'">';
+			    print '&nbsp;<input type="submit" class="button" value="'.$langs->trans("Modify").'">';
+			    print '</form>';
+			}
+			else
+			{
+			    print $langs->trans("SellingPrice") . ' ' . $i;
+			    if (! empty($conf->global->$keyforlabel)) print ' - '.$langs->trans($conf->global->$keyforlabel);
+			}
 			print '</td>';
 
 			if ($object->multiprices_base_type [$i] == 'TTC') {
@@ -761,7 +812,7 @@ if (! empty($conf->global->PRODUIT_MULTIPRICES))
 			print '</td></tr>';
 
 			// Price by quantity
-			if (! empty($conf->global->PRODUIT_CUSTOMER_PRICES_BY_QTY))
+			if (! empty($conf->global->PRODUIT_CUSTOMER_PRICES_BY_QTY))      // TODO Fix the form included into a tr instead of a td
 			{
 				print '<tr><td>' . $langs->trans("PriceByQuantity") . ' ' . $i;
 				print '</td><td>';
@@ -776,7 +827,8 @@ if (! empty($conf->global->PRODUIT_MULTIPRICES))
 					print '<td align="right">' . $langs->trans("Discount") . '</td>';
 					print '<td>&nbsp;</td>';
 					print '</tr>';
-					foreach ($object->prices_by_qty_list[$i] as $ii => $prices) {
+					foreach ($object->prices_by_qty_list[$i] as $ii => $prices)
+					{
 						if ($action == 'edit_price_by_qty' && $rowid == $prices['rowid'] && ($user->rights->produit->creer || $user->rights->service->creer)) {
 							print '<form action="' . $_SERVER["PHP_SELF"] . '?id=' . $object->id . '" method="POST">';
 							print '<input type="hidden" name="action" value="update_price_by_qty">';
@@ -833,15 +885,15 @@ if (! empty($conf->global->PRODUIT_MULTIPRICES))
 			}
 		}
 	}
-} 
-else 
+}
+else
 {
 	// TVA
 	print '<tr><td class="titlefield">' . $langs->trans("VATRate") . '</td><td>';
 	if ($object->default_vat_code)
 	{
         print vatrate($object->tva_tx, true) . ' ('.$object->default_vat_code.')';
-	}   
+	}
 	else print vatrate($object->tva_tx, true, $object->tva_npr, true);
 	print '</td></tr>';
 
@@ -864,7 +916,7 @@ else
 	print '</td></tr>';
 
 	// Price by quantity
-	if (! empty($conf->global->PRODUIT_CUSTOMER_PRICES_BY_QTY))
+	if (! empty($conf->global->PRODUIT_CUSTOMER_PRICES_BY_QTY))    // TODO Fix the form inside tr instead of td
 	{
 		print '<tr><td>' . $langs->trans("PriceByQuantity");
 		if ($object->prices_by_qty [0] == 0) {
@@ -917,7 +969,7 @@ else
 				}
 			}
 			if ($action != 'edit_price_by_qty') {
-				print '<form action="' . $_SERVER["PHP_SELF"] . '?id=' . $object->id . '" method="POST">';
+				print '<form action="' . $_SERVER["PHP_SELF"] . '?id=' . $object->id . '" method="POST">';  // FIXME a form into a table is not allowed
 				print '<input type="hidden" name="action" value="update_price_by_qty">';
 				print '<input type="hidden" name="priceid" value="' . $object->prices_by_qty_id [0] . '">';
 				print '<input type="hidden" value="0" name="rowid">';
@@ -972,18 +1024,18 @@ if (! $action || $action == 'delete' || $action == 'showlog_customer_price' || $
 	 		print '<div class="inline-block divButAction"><a class="butAction" href="' . $_SERVER["PHP_SELF"] . '?action=add_customer_price&amp;id=' . $object->id . '">' . $langs->trans("AddCustomerPrice") . '</a></div>';
 	  	}
 	}
-	
+
 	if (! empty($conf->global->PRODUIT_MULTIPRICES))
 	{
 	    if ($user->rights->produit->creer || $user->rights->service->creer) {
     		print '<div class="inline-block divButAction"><a class="butAction" href="' . $_SERVER['PHP_SELF'] . '?action=edit_vat&amp;id=' . $object->id . '">' . $langs->trans("UpdateVAT") . '</a></div>';
     	}
-	    
+
 	    if ($user->rights->produit->creer || $user->rights->service->creer) {
     		print '<div class="inline-block divButAction"><a class="butAction" href="' . $_SERVER['PHP_SELF'] . '?action=edit_price&amp;id=' . $object->id . '">' . $langs->trans("UpdateLevelPrices") . '</a></div>';
     	}
 	}
-    
+
 	print "\n</div>\n";
 }
 
@@ -992,7 +1044,7 @@ if (! $action || $action == 'delete' || $action == 'showlog_customer_price' || $
 /*
  * Edit price area
  */
- 
+
 if ($action == 'edit_vat' && ($user->rights->produit->creer || $user->rights->service->creer))
 {
 	print load_fiche_titre($langs->trans("UpdateVAT"), '');
@@ -1003,9 +1055,9 @@ if ($action == 'edit_vat' && ($user->rights->produit->creer || $user->rights->se
 	print '<input type="hidden" name="id" value="' . $object->id . '">';
 
 	dol_fiche_head('');
-	
+
 	print '<table class="border" width="100%">';
-	
+
 	// VAT
 	print '<tr><td>' . $langs->trans("VATRate") . '</td><td>';
 	print $form->load_tva("tva_tx", $object->default_vat_code ? $object->tva_tx.' ('.$object->default_vat_code.')' : $object->tva_tx, $mysoc, '', $object->id, $object->tva_npr, $object->type, false, 1);
@@ -1023,7 +1075,7 @@ if ($action == 'edit_vat' && ($user->rights->produit->creer || $user->rights->se
 
 	print '<br></form><br>';
 }
- 
+
 if ($action == 'edit_price' && $object->getRights()->creer)
 {
 	print load_fiche_titre($langs->trans("NewPrice"), '');
@@ -1036,19 +1088,19 @@ if ($action == 'edit_price' && $object->getRights()->creer)
 		print '<input type="hidden" name="id" value="' . $object->id . '">';
 
 		dol_fiche_head('');
-		
+
 		print '<table class="border" width="100%">';
 
 		// VAT
-		print '<tr><td>' . $langs->trans("VATRate") . '</td><td colspan="2">';
+		print '<tr><td class="titlefield">' . $langs->trans("VATRate") . '</td><td>';
 		print $form->load_tva("tva_tx", $object->default_vat_code ? $object->tva_tx.' ('.$object->default_vat_code.')' : $object->tva_tx, $mysoc, '', $object->id, $object->tva_npr, $object->type, false, 1);
 		print '</td></tr>';
 
 		// Price base
-		print '<tr><td width="20%">';
+		print '<tr><td>';
 		print $langs->trans('PriceBase');
 		print '</td>';
-		print '<td colspan="2">';
+		print '<td>';
 		print $form->selectPriceBaseType($object->price_base_type, "price_base_type");
 		print '</td>';
 		print '</tr>';
@@ -1056,7 +1108,7 @@ if ($action == 'edit_price' && $object->getRights()->creer)
  		// Only show price mode and expression selector if module is enabled
 		if (! empty($conf->dynamicprices->enabled)) {
 			// Price mode selector
-			print '<tr><td>'.$langs->trans("PriceMode").'</td><td colspan="2">';
+			print '<tr><td>'.$langs->trans("PriceMode").'</td><td>';
 			$price_expression = new PriceExpression($db);
 			$price_expression_list = array(0 => $langs->trans("PriceNumeric")); //Put the numeric mode as first option
 			foreach ($price_expression->list_price_expression() as $entry) {
@@ -1092,10 +1144,10 @@ if ($action == 'edit_price' && $object->getRights()->creer)
 		// Price
 		$product = new Product($db);
 		$product->fetch($id, $ref, '', 1); //Ignore the math expression when getting the price
-		print '<tr id="price_numeric"><td width="20%">';
+		print '<tr id="price_numeric"><td>';
 		$text = $langs->trans('SellingPrice');
 		print $form->textwithpicto($text, $langs->trans("PrecisionUnitIsLimitedToXDecimals", $conf->global->MAIN_MAX_DECIMALS_UNIT), 1, 1);
-		print '</td><td colspan="2">';
+		print '</td><td>';
 		if ($object->price_base_type == 'TTC') {
 			print '<input name="price" size="10" value="' . price($product->price_ttc) . '">';
 		} else {
@@ -1107,21 +1159,17 @@ if ($action == 'edit_price' && $object->getRights()->creer)
 		print '<tr><td>';
 		$text = $langs->trans('MinPrice');
 		print $form->textwithpicto($text, $langs->trans("PrecisionUnitIsLimitedToXDecimals", $conf->global->MAIN_MAX_DECIMALS_UNIT), 1, 1);
-		print '</td><td';
-		if (empty($conf->global->PRODUCT_MINIMUM_RECOMMENDED_PRICE)) {
-			print ' colspan="2"';
-		}
-		print '>';
+		print '</td><td>';
 		if ($object->price_base_type == 'TTC') {
 			print '<input name="price_min" size="10" value="' . price($object->price_min_ttc) . '">';
 		} else {
 			print '<input name="price_min" size="10" value="' . price($object->price_min) . '">';
 		}
-		print '</td>';
-		if ( !empty($conf->global->PRODUCT_MINIMUM_RECOMMENDED_PRICE))
+		if (! empty($conf->global->PRODUCT_MINIMUM_RECOMMENDED_PRICE))
 		{
-			print '<td align="left">'.$langs->trans("MinimumRecommendedPrice", price($maxpricesupplier,0,'',1,-1,-1,'auto')).' '.img_warning().'</td>';
+		    print ' &nbsp; '.$langs->trans("MinimumRecommendedPrice", price($maxpricesupplier,0,'',1,-1,-1,'auto')).' '.img_warning().'</td>';
 		}
+		print '</td>';
 		print '</tr>';
 
 		print '</table>';
@@ -1168,21 +1216,21 @@ if ($action == 'edit_price' && $object->getRights()->creer)
 		print '<input type="hidden" name="id" value="' . $object->id . '">';
 
 		dol_fiche_head('');
-		
+
 		if (! empty($conf->global->PRODUIT_MULTIPRICES) && ! empty($conf->global->PRODUIT_MULTIPRICES_ALLOW_AUTOCALC_PRICELEVEL)) {
 			print $langs->trans('UseMultipriceRules'). ' <input type="checkbox" id="usePriceRules" name="usePriceRules" '.($object->price_autogen ? 'checked' : '').'><br><br>';
 		}
 
 		print '<table class="noborder">';
 		print '<thead><tr class="liste_titre">';
-		
+
 		print '<td>'.$langs->trans("PriceLevel").'</td>';
 
 		if (!empty($conf->global->PRODUIT_MULTIPRICES_USE_VAT_PER_LEVEL)) print '<td style="text-align: center">'.$langs->trans("VATRate").'</td>';
 		else print '<td></td>';
-		
+
 		print '<td class="center">'.$langs->trans("SellingPrice").'</td>';
-		
+
 		print '<td class="center">'.$langs->trans("MinPrice").'</td>';
 
 		if (!empty($conf->global->PRODUCT_MINIMUM_RECOMMENDED_PRICE)) {
@@ -1191,7 +1239,9 @@ if ($action == 'edit_price' && $object->getRights()->creer)
 		print '</tr></thead>';
 
 		print '<tbody>';
-		for ($i = 1; $i <= $conf->global->PRODUIT_MULTIPRICES_LIMIT; $i ++) 
+
+		$var = false;
+		for ($i = 1; $i <= $conf->global->PRODUIT_MULTIPRICES_LIMIT; $i ++)
 		{
 			$var = !$var;
 
@@ -1244,11 +1294,11 @@ if ($action == 'edit_price' && $object->getRights()->creer)
 		}
 
 		print '</tbody>';
-		
+
 		print '</table>';
-		
+
 		dol_fiche_end();
-		
+
 		print '<div style="text-align: center">';
 		print '<input type="submit" class="button" value="' . $langs->trans("Save") . '">';
 		print '&nbsp;&nbsp;&nbsp;';
@@ -1258,10 +1308,12 @@ if ($action == 'edit_price' && $object->getRights()->creer)
 	}
 }
 
-// List of price changes -log historic (ordered by descending date)
+
+// List of price changes - log historic (ordered by descending date)
+
 if ((empty($conf->global->PRODUIT_CUSTOMER_PRICES) || $action=='showlog_default_price') && ! in_array($action, array('edit_price','edit_vat')))
 {
-    $sql = "SELECT p.rowid, p.price, p.price_ttc, p.price_base_type, p.tva_tx, p.recuperableonly,";
+    $sql = "SELECT p.rowid, p.price, p.price_ttc, p.price_base_type, p.tva_tx, p.default_vat_code, p.recuperableonly,";
     $sql .= " p.price_level, p.price_min, p.price_min_ttc,p.price_by_qty,";
     $sql .= " p.date_price as dp, p.fk_price_expression, u.rowid as user_id, u.login";
     $sql .= " FROM " . MAIN_DB_PREFIX . "product_price as p,";
@@ -1272,42 +1324,50 @@ if ((empty($conf->global->PRODUIT_CUSTOMER_PRICES) || $action=='showlog_default_
     if (! empty($socid) && ! empty($conf->global->PRODUIT_MULTIPRICES)) $sql .= " AND p.price_level = " . $soc->price_level;
     $sql .= " ORDER BY p.date_price DESC, p.rowid DESC, p.price_level ASC";
     // $sql .= $db->plimit();
-    
+
     $result = $db->query($sql);
     if ($result)
     {
-    	$num = $db->num_rows($result);
-    
+        print '<div class="divlogofpreviouscustomerprice">';
+
+        $num = $db->num_rows($result);
+
     	if (! $num)
     	{
     		$db->free($result);
-    
+
     		// Il doit au moins y avoir la ligne de prix initial.
     		// On l'ajoute donc pour remettre a niveau (pb vieilles versions)
     		$object->updatePrice($object->price, $object->price_base_type, $user, $newprice_min);
-    
+
     		$result = $db->query($sql);
     		$num = $db->num_rows($result);
     	}
-    
+
     	if ($num > 0)
     	{
+    	    // Default prices or
+    	    // Log of previous customer prices
     	    $backbutton='<a class="butAction" href="' . $_SERVER["PHP_SELF"] . '?id=' . $object->id . '">' . $langs->trans("Back") . '</a>';
-    	    	
-    		if (! empty($conf->global->PRODUIT_CUSTOMER_PRICES)) print_barre_liste($langs->trans("DefaultPrice"),'','','','','',$backbutton, 0, 0, 'title_accountancy.png');
-    
+
+    		if (! empty($conf->global->PRODUIT_CUSTOMER_PRICES)) print_barre_liste($langs->trans("DefaultPrice"), 0, $_SERVER["PHP_SELF"], '', '', '', $backbutton, $num, $num, 'title_accountancy.png');
+    		else print_barre_liste($langs->trans("PriceByCustomerLog"), 0, $_SERVER["PHP_SELF"], '', '', '', '', $num, $num, 'title_accountancy.png');
+    	    //if (! empty($conf->global->PRODUIT_CUSTOMER_PRICES)) print_barre_liste($langs->trans("DefaultPrice"),'','','','','',$backbutton, 0, 0, 'title_accountancy.png');
+    		//else print_barre_liste($langs->trans("PriceByCustomerLog"),'','','','','','', 0, 0, 'title_accountancy.png');
+
+    		print '<div class="div-table-responsive">';
     		print '<table class="noborder" width="100%">';
-    
+
     		print '<tr class="liste_titre">';
     		print '<td>' . $langs->trans("AppliedPricesFrom") . '</td>';
-    
+
     		if (! empty($conf->global->PRODUIT_MULTIPRICES)) {
     			print '<td align="center">' . $langs->trans("PriceLevel") . '</td>';
     		}
     		if (! empty($conf->global->PRODUIT_CUSTOMER_PRICES_BY_QTY)) {
     			print '<td align="center">' . $langs->trans("Type") . '</td>';
     		}
-    
+
     		print '<td align="center">' . $langs->trans("PriceBase") . '</td>';
     		print $conf->global->PRODUIT_MULTIPRICES_USE_VAT_PER_LEVEL;
     		if (empty($conf->global->PRODUIT_MULTIPRICES)) print '<td align="right">' . $langs->trans("VATRate") . '</td>';
@@ -1322,19 +1382,19 @@ if ((empty($conf->global->PRODUIT_CUSTOMER_PRICES) || $action=='showlog_default_
     		if ($user->rights->produit->supprimer)
     			print '<td align="right">&nbsp;</td>';
     		print '</tr>';
-    
+
     		$notfirstlineforlevel=array();
-    		
+
     		$var = True;
     		$i = 0;
     		while ($i < $num)
     		{
     			$objp = $db->fetch_object($result);
     			$var = ! $var;
-    			print '<tr'. $bc[$var].'>';
+    			print '<tr '. $bc[$var].'>';
     			// Date
     			print "<td>" . dol_print_date($db->jdate($objp->dp), "dayhour") . "</td>";
-    
+
     			// Price level
     			if (! empty($conf->global->PRODUIT_MULTIPRICES)) {
     				print '<td align="center">' . $objp->price_level . "</td>";
@@ -1345,10 +1405,19 @@ if ((empty($conf->global->PRODUIT_CUSTOMER_PRICES) || $action=='showlog_default_
     				$type = ($objp->price_by_qty == 1) ? 'PriceByQuantity' : 'Standard';
     				print '<td align="center">' . $langs->trans($type) . "</td>";
     			}
-    
+
     			print '<td align="center">' . $langs->trans($objp->price_base_type) . "</td>";
-    			if (empty($conf->global->PRODUIT_MULTIPRICES)) print '<td align="right">' . vatrate($objp->tva_tx, true, $objp->recuperableonly) . "</td>";
-    
+    			if (empty($conf->global->PRODUIT_MULTIPRICES))
+    			{
+    			    print '<td align="right">';
+    			    if ($objp->default_vat_code)
+    			    {
+    			        print vatrate($objp->tva_tx, true) . ' ('.$objp->default_vat_code.')';
+    			    }
+    			    else print vatrate($objp->tva_tx, true, $objp->recuperableonly);
+    			    print "</td>";
+    			}
+
     			// Price
     			if (! empty($objp->fk_price_expression) && ! empty($conf->dynamicprices->enabled))
     			{
@@ -1369,23 +1438,23 @@ if ((empty($conf->global->PRODUIT_CUSTOMER_PRICES) || $action=='showlog_default_
     			}
     			print '<td align="right">' . ($objp->price_base_type != 'TTC' ? price($objp->price_min) : '') . '</td>';
     			print '<td align="right">' . ($objp->price_base_type == 'TTC' ? price($objp->price_min_ttc) : '') . '</td>';
-    
+
     			// User
     			print '<td align="right"><a href="' . DOL_URL_ROOT . '/user/card.php?id=' . $objp->user_id . '">' . img_object($langs->trans("ShowUser"), 'user') . ' ' . $objp->login . '</a></td>';
-    
+
     			// Action
     			if ($user->rights->produit->supprimer)
     			{
     			    $candelete=0;
-    			    if (! empty($conf->global->PRODUIT_MULTIPRICES)) 
+    			    if (! empty($conf->global->PRODUIT_MULTIPRICES))
     			    {
     			        if (empty($notfirstlineforlevel[$objp->price_level])) $notfirstlineforlevel[$objp->price_level]=1;
     			        else $candelete=1;
     			    }
     			    elseif ($i > 0) $candelete=1;
-    			    
+
     				print '<td align="right">';
-    				if ($candelete) 
+    				if ($candelete)
     				{
     					print '<a href="' . $_SERVER["PHP_SELF"] . '?action=delete&amp;id=' . $object->id . '&amp;lineid=' . $objp->rowid . '">';
     					print img_delete();
@@ -1394,14 +1463,18 @@ if ((empty($conf->global->PRODUIT_CUSTOMER_PRICES) || $action=='showlog_default_
     					print '&nbsp;'; // Can not delete last price (it's current price)
     				print '</td>';
     			}
-    
+
     			print "</tr>\n";
-    			$i ++;
+    			$i++;
     		}
+
     		$db->free($result);
     		print "</table>";
+    		print '</div>';
     		print "<br>";
     	}
+
+    	print '</div>';
     } else {
     	dol_print_error($db);
     }
@@ -1445,20 +1518,20 @@ if (! empty($conf->global->PRODUIT_CUSTOMER_PRICES))
 		print '<input type="hidden" name="token" value="' . $_SESSION ['newtoken'] . '">';
 		print '<input type="hidden" name="action" value="add_customer_price_confirm">';
 		print '<input type="hidden" name="id" value="' . $object->id . '">';
-		
+
 		dol_fiche_head();
-		
+
 		print '<table class="border" width="100%">';
 		print '<tr>';
 		print '<td class="fieldrequired">' . $langs->trans('ThirdParty') . '</td>';
 		print '<td>';
-		print $form->select_company('', 'socid', 's.client in (1,2,3) AND s.rowid NOT IN (SELECT fk_soc FROM ' . MAIN_DB_PREFIX . 'product_customer_price WHERE fk_product='.$object->id.')', 'SelectThirdParty', 0, 0, array(), 0, 'minwidth300');
+		print $form->select_company('', 'socid', 's.client in (1,2,3)', 'SelectThirdParty', 0, 0, array(), 0, 'minwidth300');
 		print '</td>';
 		print '</tr>';
 
 		// VAT
 		print '<tr><td class="fieldrequired">' . $langs->trans("VATRate") . '</td><td>';
-		print $form->load_tva("tva_tx", $object->tva_tx, $mysoc, '', $object->id, $object->tva_npr, $object->type, false, 1);
+		print $form->load_tva("tva_tx", $object->default_vat_code ? $object->tva_tx.' ('.$object->default_vat_code.')' : $object->tva_tx, $mysoc, '', $object->id, $object->tva_npr, $object->type, false, 1);
 		print '</td></tr>';
 
 		// Price base
@@ -1509,7 +1582,7 @@ if (! empty($conf->global->PRODUIT_CUSTOMER_PRICES))
 		print '</table>';
 
 		dol_fiche_end();
-		
+
 		print '<div class="center">';
 		print '<input type="submit" class="button" value="' . $langs->trans("Save") . '">';
 		print '&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;';
@@ -1544,7 +1617,7 @@ if (! empty($conf->global->PRODUIT_CUSTOMER_PRICES))
 
 		// VAT
 		print '<tr><td>' . $langs->trans("VATRate") . '</td><td colspan="2">';
-		print $form->load_tva("tva_tx", $prodcustprice->tva_tx, $mysoc, '', $object->id, $prodcustprice->recuperableonly, $object->type, false, 1);
+		print $form->load_tva("tva_tx", $prodcustprice->default_vat_code ? $prodcustprice->tva_tx.' ('.$prodcustprice->default_vat_code.')' : $prodcustprice->tva_tx, $mysoc, '', $object->id, $prodcustprice->recuperableonly, $object->type, false, 1);
 		print '</td></tr>';
 
 		// Price base
@@ -1609,7 +1682,7 @@ if (! empty($conf->global->PRODUIT_CUSTOMER_PRICES))
 		$filter = array('t.fk_product' => $object->id,'t.fk_soc' => GETPOST('socid', 'int'));
 
 		// Count total nb of records
-		$nbtotalofrecords = 0;
+		$nbtotalofrecords = '';
 		if (empty($conf->global->MAIN_DISABLE_FULL_SCANLIST)) {
 			$nbtotalofrecords = $prodcustprice->fetch_all_log($sortorder, $sortfield, $conf->liste_limit, $offset, $filter);
 		}
@@ -1623,12 +1696,12 @@ if (! empty($conf->global->PRODUIT_CUSTOMER_PRICES))
 
 		$staticsoc = new Societe($db);
 		$staticsoc->fetch(GETPOST('socid', 'int'));
-		
+
 		$title=$langs->trans('PriceByCustomerLog');
 		$title.=' - '.$staticsoc->getNomUrl(1);
 
 		$backbutton='<a class="butAction" href="' . $_SERVER["PHP_SELF"] . '?id=' . $object->id . '">' . $langs->trans("Back") . '</a>';
-		
+
 		print_barre_liste($title, $page, $_SERVEUR['PHP_SELF'], $option, $sortfield, $sortorder, $backbutton, count($prodcustprice->lines), $nbtotalofrecords, 'title_accountancy.png');
 
 		if (count($prodcustprice->lines) > 0)
@@ -1665,8 +1738,10 @@ if (! empty($conf->global->PRODUIT_CUSTOMER_PRICES))
 				print "<td>" . $staticsoc->getNomUrl(1) . "</td>";
 				print "<td>" . dol_print_date($line->datec, "dayhour") . "</td>";
 
+				$tva_tx = $line->default_vat_code ? $line->tva_tx.' ('.$line->default_vat_code.')' : $line->tva_tx;
+
 				print '<td align="center">' . $langs->trans($line->price_base_type) . "</td>";
-				print '<td align="right">' . vatrate($line->tva_tx, true, $line->recuperableonly) . "</td>";
+				print '<td align="right">' . vatrate($tva_tx, true, $line->recuperableonly) . "</td>";
 				print '<td align="right">' . price($line->price) . "</td>";
 				print '<td align="right">' . price($line->price_ttc) . "</td>";
 				print '<td align="right">' . price($line->price_min) . '</td>';
@@ -1687,9 +1762,10 @@ if (! empty($conf->global->PRODUIT_CUSTOMER_PRICES))
 	else if ($action != 'showlog_default_price' && $action != 'edit_price')
 	{
 		// List of all prices by customers
+        print '<!-- list of prices per customer -->'."\n";
 
 		// Count total nb of records
-		$nbtotalofrecords = 0;
+		$nbtotalofrecords = '';
 		if (empty($conf->global->MAIN_DISABLE_FULL_SCANLIST)) {
 			$nbtotalofrecords = $prodcustprice->fetch_all($sortorder, $sortfield, 0, 0, $filter);
 		}
@@ -1724,8 +1800,8 @@ if (! empty($conf->global->PRODUIT_CUSTOMER_PRICES))
 		if (count($prodcustprice->lines) > 0 || $search_soc)
 		{
     		print '<tr class="liste_titre">';
-    		print '<td><input type="text" class="flat" name="search_soc" value="' . $search_soc . '" size="20"></td>';
-    		print '<td colspan="8">&nbsp;</td>';
+    		print '<td class="liste_titre"><input type="text" class="flat" name="search_soc" value="' . $search_soc . '" size="20"></td>';
+    		print '<td class="liste_titre" colspan="8">&nbsp;</td>';
     		// Print the search button
             print '<td class="liste_titre" align="right">';
             $searchpitco=$form->showFilterAndCheckAddButtons(0);
@@ -1733,17 +1809,20 @@ if (! empty($conf->global->PRODUIT_CUSTOMER_PRICES))
             print '</td>';
     		print '</tr>';
 		}
-		
+
 		$var = False;
-		
-		
+
+
 		// Line for default price
 		print "<tr ".$bc[$var].">";
 		print "<td>" . $langs->trans("Default") . "</td>";
 		print "<td>" . "</td>";
-		
+
 		print '<td align="center">' . $langs->trans($object->price_base_type) . "</td>";
-		print '<td align="right">' . vatrate($object->tva_tx, true, $object->recuperableonly) . "</td>";
+		print '<td align="right">';
+		print vatrate($object->tva_tx, true, $object->recuperableonly);
+		print $object->default_vat_code?' ('.$object->default_vat_code.')':'';
+		print "</td>";
 		print '<td align="right">' . price($object->price) . "</td>";
 		print '<td align="right">' . price($object->price_ttc) . "</td>";
 		print '<td align="right">' . price($object->price_min) . '</td>';
@@ -1765,23 +1844,26 @@ if (! empty($conf->global->PRODUIT_CUSTOMER_PRICES))
 		}
 		print "</tr>\n";
 
-		
+
 		if (count($prodcustprice->lines) > 0)
 		{
+		    $var = false;
 			foreach ($prodcustprice->lines as $line)
 			{
 			    $var = ! $var;
-			    
+
 				print "<tr ".$bc[$var].">";
 				// Date
 				$staticsoc = new Societe($db);
 				$staticsoc->fetch($line->fk_soc);
 
+				$tva_tx = $line->default_vat_code ? $line->tva_tx.' ('.$line->default_vat_code.')' : $line->tva_tx;
+
 				print "<td>" . $staticsoc->getNomUrl(1) . "</td>";
 				print "<td>" . dol_print_date($line->datec, "dayhour") . "</td>";
 
 				print '<td align="center">' . $langs->trans($line->price_base_type) . "</td>";
-				print '<td align="right">' . vatrate($line->tva_tx, true, $line->recuperableonly) . "</td>";
+				print '<td align="right">' . vatrate($tva_tx, true, $line->recuperableonly) . "</td>";
 				print '<td align="right">' . price($line->price) . "</td>";
 				print '<td align="right">' . price($line->price_ttc) . "</td>";
 				print '<td align="right">' . price($line->price_min) . '</td>';
