@@ -30,11 +30,32 @@
  */
 class MouvementStock extends CommonObject
 {
-	var $product_id;
-	var $entrepot_id;
-	var $qty;
-	var $type;
+	/**
+	 * @var string Id to identify managed objects
+	 */
+	public $element = 'stockmouvement';
+	/**
+	 * @var string Name of table without prefix where object is stored
+	 */
+	public $table_element = 'stock_mouvement';
+	
 
+	public $product_id;
+	public $warehouse_id;
+	public $qty;
+	public $type;
+	
+	public $tms = '';
+	public $datem = '';
+	public $price;
+	public $fk_user_author;
+	public $label;
+	public $fk_origin;
+	public $origintype;
+	public $inventorycode;
+	public $batch;
+	
+	
 
     /**
 	 *  Constructor
@@ -46,6 +67,7 @@ class MouvementStock extends CommonObject
 		$this->db = $db;
 	}
 
+	
 	/**
 	 *	Add a movement of stock (in one direction only)
 	 *
@@ -54,18 +76,18 @@ class MouvementStock extends CommonObject
 	 *	@param		int		$entrepot_id	Id of warehouse
 	 *	@param		int		$qty			Qty of movement (can be <0 or >0 depending on parameter type)
 	 *	@param		int		$type			Direction of movement:
-	 *										0=input (stock increase after stock transfert), 1=output (stock decrease after stock transfer),
+	 *										0=input (stock increase by a stock transfer), 1=output (stock decrease after by a stock transfer),
 	 *										2=output (stock decrease), 3=input (stock increase)
 	 *                                      Note that qty should be > 0 with 0 or 3, < 0 with 1 or 2.
 	 *	@param		int		$price			Unit price HT of product, used to calculate average weighted price (PMP in french). If 0, average weighted price is not changed.
 	 *	@param		string	$label			Label of stock movement
 	 *	@param		string	$inventorycode	Inventory code
 	 *	@param		string	$datem			Force date of movement
-	 *	@param		date	$eatby			eat-by date
-	 *	@param		date	$sellby			sell-by date
+	 *	@param		date	$eatby			eat-by date. Will be used if lot does not exists yet and will be created.
+	 *	@param		date	$sellby			sell-by date. Will be used if lot does not exists yet and will be created.
 	 *	@param		string	$batch			batch number
 	 *	@param		boolean	$skip_batch		If set to true, stock movement is done without impacting batch record
-	 * 	@param		int		$id_product_batch	Id product_batch (when skip_batch is flase and we already know which record of product_batch to use)
+	 * 	@param		int		$id_product_batch	Id product_batch (when skip_batch is false and we already know which record of product_batch to use)
 	 *	@return		int						<0 if KO, 0 if fk_product is null, >0 if OK
 	 */
 	function _create($user, $fk_product, $entrepot_id, $qty, $type, $price=0, $label='', $inventorycode='', $datem='',$eatby='',$sellby='',$batch='',$skip_batch=false, $id_product_batch=0)
@@ -75,7 +97,7 @@ class MouvementStock extends CommonObject
 		require_once DOL_DOCUMENT_ROOT.'/product/class/product.class.php';
 		require_once DOL_DOCUMENT_ROOT.'/product/stock/class/productlot.class.php';
 		$error = 0;
-		dol_syslog(get_class($this)."::_create start userid=$user->id, fk_product=$fk_product, warehouse=$entrepot_id, qty=$qty, type=$type, price=$price, label=$label, inventorycode=$inventorycode, datem=".$datem.", eatby=".$eatby.", sellby=".$sellby.", batch=".$batch.", skip_batch=".$skip_batch);
+		dol_syslog(get_class($this)."::_create start userid=$user->id, fk_product=$fk_product, warehouse_id=$entrepot_id, qty=$qty, type=$type, price=$price, label=$label, inventorycode=$inventorycode, datem=".$datem.", eatby=".$eatby.", sellby=".$sellby.", batch=".$batch.", skip_batch=".$skip_batch);
 
 		// Clean parameters
 		if (empty($price)) $price=0;
@@ -90,7 +112,7 @@ class MouvementStock extends CommonObject
 		}
 		if ($sellby < 0)
 		{
-			$this->errors[]='ErrorBadValueForParameterEatBy';
+			$this->errors[]='ErrorBadValueForParameterSellBy';
 			return -1;
 		}
 
@@ -154,8 +176,8 @@ class MouvementStock extends CommonObject
                         		if ($this->db->jdate($obj->eatby) != $eatby && $this->db->jdate($obj->eatby) != $eatbywithouthour)    // We test date without hours and with hours for backward compatibility 
                                 {
                                     // If found and eatby/sellby defined into table and provided and differs, return error
-                                    $this->errors[]=$langs->trans("ThisSerialAlreadyExistWithDifferentDate", $batch, dol_print_date($this->db->jdate($obj->eatby)), dol_print_date($eatby));
-                                    dol_syslog($langs->transnoentities("ThisSerialAlreadyExistWithDifferentDate", $batch, dol_print_date($this->db->jdate($obj->eatby)), dol_print_date($eatby)), LOG_ERR);
+                                    $this->errors[]=$langs->trans("ThisSerialAlreadyExistWithDifferentDate", $batch, dol_print_date($this->db->jdate($obj->eatby), 'dayhour'), dol_print_date($eatby, 'dayhour'));
+                                    dol_syslog("ThisSerialAlreadyExistWithDifferentDate batch=".$batch.", eatby found into product_lot = ".$obj->eatby." = ".dol_print_date($this->db->jdate($obj->eatby), 'dayhourrfc')." so eatbywithouthour = ".$eatbywithouthour." = ".dol_print_date($eatbywithouthour)." - eatby provided = ".$eatby." = ".dol_print_date($eatby, 'dayhourrfc'), LOG_ERR);
                                     $this->db->rollback();
                                     return -3;
                                 }
@@ -248,21 +270,48 @@ class MouvementStock extends CommonObject
             	return -1;
 			}
 		}
-
-		// TODO Check qty is ok for stock move.
-		if (! empty($conf->productbatch->enabled) && $product->hasbatch() && ! $skip_batch)
-		{
-
-		}
-		else
-		{
-
-		}
-
+		
 		// Define if we must make the stock change (If product type is a service or if stock is used also for services)
 		$movestock=0;
 		if ($product->type != Product::TYPE_SERVICE || ! empty($conf->global->STOCK_SUPPORTS_SERVICES)) $movestock=1;
 
+		// Check if stock is enough when qty is < 0
+		// Note that qty should be > 0 with type 0 or 3, < 0 with type 1 or 2.
+		if ($movestock && $qty < 0 && empty($conf->global->STOCK_ALLOW_NEGATIVE_TRANSFER))
+		{
+    		if (! empty($conf->productbatch->enabled) && $product->hasbatch() && ! $skip_batch)
+    		{
+    		    $foundforbatch=0;
+    		    $qtyisnotenough=0;
+    		    foreach($product->stock_warehouse[$entrepot_id]->detail_batch as $batchcursor => $prodbatch)
+    		    {
+    		        if ($batch != $batchcursor) continue;
+    		        $foundforbatch=1;
+    		        if ($prodbatch->qty < abs($qty)) $qtyisnotenough=1;
+        		    break;
+    		    }
+    		    if (! $foundforbatch || $qtyisnotenough)
+    		    {
+    		        $langs->load("stocks");
+        		    $this->error = $langs->trans('qtyToTranferLotIsNotEnough');
+        		    $this->errors[] = $langs->trans('qtyToTranferLotIsNotEnough');
+        		    $this->db->rollback();
+        		    return -8;
+    		    }		    
+    		}
+    		else
+    		{
+    		    if (empty($product->stock_warehouse[$entrepot_id]->real) || $product->stock_warehouse[$entrepot_id]->real < abs($qty))
+    		    {
+    		        $langs->load("stocks");
+    		        $this->error = $langs->trans('qtyToTranferIsNotEnough');
+    		        $this->errors[] = $langs->trans('qtyToTranferIsNotEnough');
+    		        $this->db->rollback();
+    		        return -8;
+    		    }
+    		}
+		}		
+		
 		if ($movestock && $entrepot_id > 0)	// Change stock for current product, change for subproduct is done after
 		{
 			if(!empty($this->origin)) {			// This is set by caller for tracking reason
@@ -290,7 +339,7 @@ class MouvementStock extends CommonObject
 			$sql.= " '".$origintype."'";
 			$sql.= ")";
 
-			dol_syslog(get_class($this)."::_create", LOG_DEBUG);
+			dol_syslog(get_class($this)."::_create insert record into stock_mouvement", LOG_DEBUG);
 			$resql = $this->db->query($sql);
 			if ($resql)
 			{
@@ -315,7 +364,7 @@ class MouvementStock extends CommonObject
 				$sql = "SELECT rowid, reel FROM ".MAIN_DB_PREFIX."product_stock";
 				$sql.= " WHERE fk_entrepot = ".$entrepot_id." AND fk_product = ".$fk_product;		// This is a unique key
 
-				dol_syslog(get_class($this)."::_create", LOG_DEBUG);
+				dol_syslog(get_class($this)."::_create check if a record already exists in product_stock", LOG_DEBUG);
 				$resql=$this->db->query($sql);
 				if ($resql)
 				{
@@ -380,7 +429,7 @@ class MouvementStock extends CommonObject
 					$sql.= " (".$qty.", ".$entrepot_id.", ".$fk_product.")";
 				}
 
-				dol_syslog(get_class($this)."::_create", LOG_DEBUG);
+				dol_syslog(get_class($this)."::_create update stock value", LOG_DEBUG);
 				$resql=$this->db->query($sql);
 				if (! $resql)
 				{
@@ -419,7 +468,7 @@ class MouvementStock extends CommonObject
 				$sql.= " stock=(SELECT SUM(ps.reel) FROM ".MAIN_DB_PREFIX."product_stock as ps WHERE ps.fk_product = p.rowid)";
 				$sql.= " WHERE rowid = ".$fk_product;
 				
-				dol_syslog(get_class($this)."::_create", LOG_DEBUG);
+				dol_syslog(get_class($this)."::_create update AWP", LOG_DEBUG);
 				$resql=$this->db->query($sql);
 				if (! $resql)
 				{
@@ -462,6 +511,96 @@ class MouvementStock extends CommonObject
 		}
 	}
 
+	
+
+	/**
+	 * Load object in memory from the database
+	 *
+	 * @param int    $id  Id object
+	 *
+	 * @return int <0 if KO, 0 if not found, >0 if OK
+	 */
+	public function fetch($id)
+	{
+	    dol_syslog(__METHOD__, LOG_DEBUG);
+	
+	    $sql = 'SELECT';
+	    $sql .= ' t.rowid,';
+	    $sql .= " t.tms,";
+	    $sql .= " t.datem,";
+	    $sql .= " t.fk_product,";
+	    $sql .= " t.fk_entrepot,";
+	    $sql .= " t.value,";
+	    $sql .= " t.price,";
+	    $sql .= " t.type_mouvement,";
+	    $sql .= " t.fk_user_author,";
+	    $sql .= " t.label,";
+	    $sql .= " t.fk_origin,";
+	    $sql .= " t.origintype,";
+	    $sql .= " t.inventorycode,";
+	    $sql .= " t.batch,";
+	    $sql .= " t.eatby,";
+	    $sql .= " t.sellby";
+	    $sql .= ' FROM ' . MAIN_DB_PREFIX . $this->table_element . ' as t';
+	    $sql.= ' WHERE 1 = 1';
+	    //if (null !== $ref) {
+	        //$sql .= ' AND t.ref = ' . '\'' . $ref . '\'';
+	    //} else {
+	        $sql .= ' AND t.rowid = ' . $id;
+	    //}
+	
+	    $resql = $this->db->query($sql);
+	    if ($resql) {
+	        $numrows = $this->db->num_rows($resql);
+	        if ($numrows) {
+	            $obj = $this->db->fetch_object($resql);
+	
+	            $this->id = $obj->rowid;
+	
+	            $this->product_id = $obj->fk_product;
+	            $this->warehouse_id = $obj->fk_entrepot;
+	            $this->qty = $obj->value;
+	            $this->type = $obj->type_mouvement;
+	             
+	            $this->tms = $this->db->jdate($obj->tms);
+	            $this->datem = $this->db->jdate($obj->datem);
+	            $this->price = $obj->price;
+	            $this->fk_user_author = $obj->fk_user_author;
+	            $this->label = $obj->label;
+	            $this->fk_origin = $obj->fk_origin;
+	            $this->origintype = $obj->origintype;
+	            $this->inventorycode = $obj->inventorycode;
+	            $this->batch = $obj->batch;
+	            $this->eatby = $this->db->jdate($obj->eatby);
+	            $this->sellby = $this->db->jdate($obj->sellby);
+	        }
+	        	
+	        // Retrieve all extrafields for invoice
+	        // fetch optionals attributes and labels
+	        require_once DOL_DOCUMENT_ROOT.'/core/class/extrafields.class.php';
+	        $extrafields=new ExtraFields($this->db);
+	        $extralabels=$extrafields->fetch_name_optionals_label($this->table_element,true);
+	        $this->fetch_optionals($this->id,$extralabels);
+	
+	        // $this->fetch_lines();
+	        	
+	        $this->db->free($resql);
+	
+	        if ($numrows) {
+	            return 1;
+	        } else {
+	            return 0;
+	        }
+	    } else {
+	        $this->errors[] = 'Error ' . $this->db->lasterror();
+	        dol_syslog(__METHOD__ . ' ' . implode(',', $this->errors), LOG_ERR);
+	
+	        return - 1;
+	    }
+	}
+	
+	
+	
 
 	/**
 	 *  Create movement in database for all subproducts
@@ -520,18 +659,18 @@ class MouvementStock extends CommonObject
 	/**
 	 *	Decrease stock for product and subproducts
 	 *
-	 * 	@param 		User	$user			Object user
-	 * 	@param		int		$fk_product		Id product
-	 * 	@param		int		$entrepot_id	Warehouse id
-	 * 	@param		int		$qty			Quantity
-	 * 	@param		int		$price			Price
-	 * 	@param		string	$label			Label of stock movement
-	 * 	@param		string	$datem			Force date of movement
-	 *	@param		date	$eatby			eat-by date
-	 *	@param		date	$sellby			sell-by date
-	 *	@param		string	$batch			batch number
+	 * 	@param 		User	$user			    Object user
+	 * 	@param		int		$fk_product		    Id product
+	 * 	@param		int		$entrepot_id	    Warehouse id
+	 * 	@param		int		$qty			    Quantity
+	 * 	@param		int		$price			    Price
+	 * 	@param		string	$label			    Label of stock movement
+	 * 	@param		string	$datem			    Force date of movement
+	 *	@param		date	$eatby			    eat-by date
+	 *	@param		date	$sellby			    sell-by date
+	 *	@param		string	$batch			    batch number
 	 * 	@param		int		$id_product_batch	Id product_batch
-	 * 	@return		int						<0 if KO, >0 if OK
+	 * 	@return		int						    <0 if KO, >0 if OK
 	 */
 	function livraison($user, $fk_product, $entrepot_id, $qty, $price=0, $label='', $datem='', $eatby='', $sellby='', $batch='', $id_product_batch=0)
 	{
@@ -567,8 +706,10 @@ class MouvementStock extends CommonObject
 	 *
 	 * @param      int		$id				Id of product
 	 * @return     int						<0 if KO, nb of subproducts if OK
+	 * @deprecated A count($product->getChildsArbo($id,1)) is same. No reason to have this in this class.
 	 */
-	function nbOfSubProdcuts($id)
+	/*
+	function nbOfSubProducts($id)
 	{
 		$nbSP=0;
 
@@ -580,7 +721,7 @@ class MouvementStock extends CommonObject
 			$nbSP=$obj->nb;
 		}
 		return $nbSP;
-	}
+	}*/
 
 	/**
 	 * Count number of product in stock before a specific date
@@ -728,7 +869,11 @@ class MouvementStock extends CommonObject
 				require_once DOL_DOCUMENT_ROOT.'/fourn/class/fournisseur.facture.class.php';
 				$origin = new FactureFournisseur($this->db);
 				break;
-				
+			case 'project':
+				require_once DOL_DOCUMENT_ROOT.'/projet/class/project.class.php';
+				$origin = new Project($this->db);
+				break;
+
 			default:
 				if ($origintype)
 				{
