@@ -1,6 +1,6 @@
 <?php
 /* Copyright (C) 2005		Rodolphe Quiedeville	<rodolphe@quiedeville.org>
- * Copyright (C) 2006-2014	Laurent Destailleur		<eldy@users.sourceforge.net>
+ * Copyright (C) 2006-2015	Laurent Destailleur		<eldy@users.sourceforge.net>
  * Copyright (C) 2010-2012	Regis Houssin			<regis.houssin@capnetworks.com>
  *
  * This program is free software; you can redistribute it and/or modify
@@ -23,7 +23,6 @@
  *	\brief      Page of a project task
  */
 
-
 require ("../../main.inc.php");
 require_once DOL_DOCUMENT_ROOT.'/projet/class/project.class.php';
 require_once DOL_DOCUMENT_ROOT.'/projet/class/task.class.php';
@@ -38,20 +37,21 @@ $langs->load("projects");
 $langs->load("companies");
 
 $id=GETPOST('id','int');
-$ref=GETPOST('ref','alpha');
+$ref=GETPOST("ref",'alpha',1);          // task ref
+$taskref=GETPOST("taskref",'alpha');    // task ref
 $action=GETPOST('action','alpha');
 $confirm=GETPOST('confirm','alpha');
 $withproject=GETPOST('withproject','int');
 $project_ref=GETPOST('project_ref','alpha');
-$planned_workload=GETPOST('planned_workloadhour')*3600+GETPOST('planned_workloadmin')*60;
+$planned_workload=((GETPOST('planned_workloadhour')!='' && GETPOST('planned_workloadmin')!='')?GETPOST('planned_workloadhour')*3600+GETPOST('planned_workloadmin')*60:'');
 
 // Security check
 $socid=0;
-if ($user->societe_id > 0) $socid = $user->societe_id;
+//if ($user->societe_id > 0) $socid = $user->societe_id;    // For external user, no check is done on company because readability is managed by public status of project and assignement.
 if (! $user->rights->projet->lire) accessforbidden();
 
 // Initialize technical object to manage hooks of thirdparties. Note that conf->hooks_modules contains array array
-$hookmanager->initHooks(array('projecttaskcard'));
+$hookmanager->initHooks(array('projecttaskcard','globalcard'));
 
 $object = new Task($db);
 $extrafields = new ExtraFields($db);
@@ -59,39 +59,56 @@ $projectstatic = new Project($db);
 
 // fetch optionals attributes and labels
 $extralabels=$extrafields->fetch_name_optionals_label($object->table_element);
+
+
 /*
  * Actions
-*/
+ */
 
 if ($action == 'update' && ! $_POST["cancel"] && $user->rights->projet->creer)
 {
 	$error=0;
 
+	if (empty($taskref))
+	{
+		$error++;
+		setEventMessages($langs->trans("ErrorFieldRequired", $langs->transnoentities("Ref")), null, 'errors');
+	}
 	if (empty($_POST["label"]))
 	{
 		$error++;
-		$mesg='<div class="error">'.$langs->trans("ErrorFieldRequired",$langs->transnoentities("Label")).'</div>';
+		setEventMessages($langs->trans("ErrorFieldRequired", $langs->transnoentities("Label")), null, 'errors');
 	}
 	if (! $error)
 	{
 		$object->fetch($id,$ref);
+        $object->oldcopy = clone $object;
 
 		$tmparray=explode('_',$_POST['task_parent']);
 		$task_parent=$tmparray[1];
 		if (empty($task_parent)) $task_parent = 0;	// If task_parent is ''
 
+		$object->ref = $taskref?$taskref:GETPOST("ref",'alpha',2);
 		$object->label = $_POST["label"];
 		$object->description = $_POST['description'];
 		$object->fk_task_parent = $task_parent;
 		$object->planned_workload = $planned_workload;
-		$object->date_start = dol_mktime(0,0,0,$_POST['dateomonth'],$_POST['dateoday'],$_POST['dateoyear']);
-		$object->date_end = dol_mktime(0,0,0,$_POST['dateemonth'],$_POST['dateeday'],$_POST['dateeyear']);
+		$object->date_start = dol_mktime($_POST['dateohour'],$_POST['dateomin'],0,$_POST['dateomonth'],$_POST['dateoday'],$_POST['dateoyear']);
+		$object->date_end = dol_mktime($_POST['dateehour'],$_POST['dateemin'],0,$_POST['dateemonth'],$_POST['dateeday'],$_POST['dateeyear']);
 		$object->progress = $_POST['progress'];
 
 		// Fill array 'array_options' with data from add form
 		$ret = $extrafields->setOptionalsFromPost($extralabels,$object);
+		if ($ret < 0) $error++;
 
-		$result=$object->update($user);
+		if (! $error)
+		{
+			$result=$object->update($user);
+			if ($result < 0)
+			{
+			    setEventMessages($object->error,$object->errors,'errors');
+			}
+		}
 	}
 	else
 	{
@@ -101,23 +118,19 @@ if ($action == 'update' && ! $_POST["cancel"] && $user->rights->projet->creer)
 
 if ($action == 'confirm_delete' && $confirm == "yes" && $user->rights->projet->supprimer)
 {
-	if ($object->fetch($id,$ref) >= 0 )
+	if ($object->fetch($id,$ref) >= 0)
 	{
-		$result=$projectstatic->fetch($object->fk_projet);
-		if (! empty($projectstatic->socid))
-		{
-			$projectstatic->societe->fetch($projectstatic->socid);
-		}
+		$result=$projectstatic->fetch($object->fk_project);
+		$projectstatic->fetch_thirdparty();
 
 		if ($object->delete($user) > 0)
 		{
-			header("Location: index.php");
+			header('Location: '.DOL_URL_ROOT.'/projet/tasks.php?id='.$projectstatic->id.($withproject?'&withproject=1':''));
 			exit;
 		}
 		else
 		{
-			$langs->load("errors");
-			$mesg='<div class="error">'.$langs->trans($object->error).'</div>';
+		    setEventMessages($object->error,$object->errors,'errors');
 			$action='';
 		}
 	}
@@ -154,11 +167,11 @@ if ($action == 'builddoc' && $user->rights->projet->creer)
 		$outputlangs = new Translate("",$conf);
 		$outputlangs->setDefaultLang(GETPOST('lang_id'));
 	}
-	$result=task_pdf_create($db, $object, $object->modelpdf, $outputlangs);
+	$result= $object->generateDocument($object->modelpdf, $outputlangs);
 	if ($result <= 0)
 	{
-		dol_print_error($db,$result);
-		exit;
+		setEventMessages($object->error, $object->errors, 'errors');
+        $action='';
 	}
 }
 
@@ -174,8 +187,8 @@ if ($action == 'remove_file' && $user->rights->projet->creer)
 		$file =	$upload_dir	. '/' .	GETPOST('file');
 
 		$ret=dol_delete_file($file);
-		if ($ret) setEventMessage($langs->trans("FileWasRemoved", GETPOST('urlfile')));
-		else setEventMessage($langs->trans("ErrorFailToDeleteFile", GETPOST('urlfile')), 'errors');
+		if ($ret) setEventMessages($langs->trans("FileWasRemoved", GETPOST('urlfile')), null, 'mesgs');
+		else setEventMessages($langs->trans("ErrorFailToDeleteFile", GETPOST('urlfile')), null, 'errors');
 	}
 }
 
@@ -197,9 +210,9 @@ if ($id > 0 || ! empty($ref))
 		$res=$object->fetch_optionals($object->id,$extralabels);
 
 		$result=$projectstatic->fetch($object->fk_project);
-		if (! empty($projectstatic->socid)) $projectstatic->societe->fetch($projectstatic->socid);
+		if (! empty($projectstatic->socid)) $projectstatic->fetch_thirdparty();
 
-		$object->project = dol_clone($projectstatic);
+		$object->project = clone $projectstatic;
 
 		$userWrite  = $projectstatic->restrictedProjectArea($user,'write');
 
@@ -212,43 +225,87 @@ if ($id > 0 || ! empty($ref))
 
 			$param=($mode=='mine'?'&mode=mine':'');
 
-			print '<table class="border" width="100%">';
-
-			// Ref
-			print '<tr><td width="30%">';
-			print $langs->trans("Ref");
-			print '</td><td>';
-			// Define a complementary filter for search of next/prev ref.
-			if (! $user->rights->projet->all->lire)
-			{
-				$projectsListId = $projectstatic->getProjectsAuthorizedForUser($user,$mine,0);
-				$projectstatic->next_prev_filter=" rowid in (".(count($projectsListId)?join(',',array_keys($projectsListId)):'0').")";
-			}
-			print $form->showrefnav($projectstatic,'project_ref','',1,'ref','ref','',$param.'&withproject=1');
-			print '</td></tr>';
-
-			print '<tr><td>'.$langs->trans("Label").'</td><td>'.$projectstatic->title.'</td></tr>';
-
-			print '<tr><td>'.$langs->trans("ThirdParty").'</td><td>';
-			if (! empty($projectstatic->societe->id)) print $projectstatic->societe->getNomUrl(1);
-			else print '&nbsp;';
-			print '</td>';
-			print '</tr>';
-
-			// Visibility
-			print '<tr><td>'.$langs->trans("Visibility").'</td><td>';
-			if ($projectstatic->public) print $langs->trans('SharedProject');
-			else print $langs->trans('PrivateProject');
-			print '</td></tr>';
-
-			// Statut
-			print '<tr><td>'.$langs->trans("Status").'</td><td>'.$projectstatic->getLibStatut(4).'</td></tr>';
-
-			print '</table>';
-
+			// Project card
+    
+            $linkback = '<a href="'.DOL_URL_ROOT.'/projet/list.php">'.$langs->trans("BackToList").'</a>';
+            
+            $morehtmlref='<div class="refidno">';
+            // Title
+            $morehtmlref.=$projectstatic->title;
+            // Thirdparty
+            if ($projectstatic->thirdparty->id > 0) 
+            {
+                $morehtmlref.='<br>'.$langs->trans('ThirdParty') . ' : ' . $projectstatic->thirdparty->getNomUrl(1, 'project');
+            }
+            $morehtmlref.='</div>';
+            
+            // Define a complementary filter for search of next/prev ref.
+            if (! $user->rights->projet->all->lire)
+            {
+                $objectsListId = $projectstatic->getProjectsAuthorizedForUser($user,0,0);
+                $projectstatic->next_prev_filter=" rowid in (".(count($objectsListId)?join(',',array_keys($objectsListId)):'0').")";
+            }
+            
+            dol_banner_tab($projectstatic, 'project_ref', $linkback, 1, 'ref', 'ref', $morehtmlref);
+        
+            print '<div class="fichecenter">';
+            print '<div class="fichehalfleft">';
+            print '<div class="underbanner clearboth"></div>';
+        
+            print '<table class="border" width="100%">';
+        
+            // Visibility
+            print '<tr><td class="titlefield">'.$langs->trans("Visibility").'</td><td>';
+            if ($projectstatic->public) print $langs->trans('SharedProject');
+            else print $langs->trans('PrivateProject');
+            print '</td></tr>';
+        
+            // Date start - end
+            print '<tr><td>'.$langs->trans("DateStart").' - '.$langs->trans("DateEnd").'</td><td>';
+            print dol_print_date($projectstatic->date_start,'day');
+            $end=dol_print_date($projectstatic->date_end,'day');
+            if ($end) print ' - '.$end;
+            print '</td></tr>';
+            
+            // Budget
+            print '<tr><td>'.$langs->trans("Budget").'</td><td>';
+            if (strcmp($projectstatic->budget_amount, '')) print price($projectstatic->budget_amount,'',$langs,1,0,0,$conf->currency);
+            print '</td></tr>';
+        
+            // Other attributes
+            $cols = 2;
+            //include DOL_DOCUMENT_ROOT . '/core/tpl/extrafields_view.tpl.php';
+            
+            print '</table>';
+            
+            print '</div>';
+            print '<div class="fichehalfright">';
+            print '<div class="ficheaddleft">';
+            print '<div class="underbanner clearboth"></div>';
+            
+            print '<table class="border" width="100%">';
+            
+            // Description
+            print '<td class="titlefield tdtop">'.$langs->trans("Description").'</td><td>';
+            print nl2br($projectstatic->description);
+            print '</td></tr>';
+        
+            // Categories
+            if($conf->categorie->enabled) {
+                print '<tr><td valign="middle">'.$langs->trans("Categories").'</td><td>';
+                print $form->showCategories($projectstatic->id,'project',1);
+                print "</td></tr>";
+            }
+            
+            print '</table>';
+            
+            print '</div>';
+            print '</div>';
+            print '</div>';
+            
+            print '<div class="clearboth"></div>';
+        
 			dol_fiche_end();
-
-			print '<br>';
 		}
 
 		/*
@@ -279,12 +336,7 @@ if ($id > 0 || ! empty($ref))
 		//$userAccess = $projectstatic->restrictedProjectArea($user); // We allow task affected to user even if a not allowed project
 		//$arrayofuseridoftask=$object->getListContactId('internal');
 
-		dol_htmloutput_mesg($mesg);
-
 		$head=task_prepare_head($object);
-		dol_fiche_head($head, 'task_task', $langs->trans("Task"),0,'projecttask');
-
-
 
 		if ($action == 'edit' && $user->rights->projet->creer)
 		{
@@ -294,14 +346,16 @@ if ($id > 0 || ! empty($ref))
 			print '<input type="hidden" name="withproject" value="'.$withproject.'">';
 			print '<input type="hidden" name="id" value="'.$object->id.'">';
 
+			dol_fiche_head($head, 'task_task', $langs->trans("Task"),0,'projecttask');
+
 			print '<table class="border" width="100%">';
 
 			// Ref
-			print '<tr><td width="30%">'.$langs->trans("Ref").'</td>';
-			print '<td>'.$object->ref.'</td></tr>';
+			print '<tr><td class="titlefield fieldrequired">'.$langs->trans("Ref").'</td>';
+			print '<td><input size="12" name="taskref" value="'.$object->ref.'"></td></tr>';
 
 			// Label
-			print '<tr><td>'.$langs->trans("Label").'</td>';
+			print '<tr><td class="fieldrequired">'.$langs->trans("Label").'</td>';
 			print '<td><input size="30" name="label" value="'.$object->label.'"></td></tr>';
 
 			// Project
@@ -325,12 +379,12 @@ if ($id > 0 || ! empty($ref))
 
 			// Date start
 			print '<tr><td>'.$langs->trans("DateStart").'</td><td>';
-			print $form->select_date($object->date_start,'dateo');
+			print $form->select_date($object->date_start,'dateo',1,1,0,'',1,0,1);
 			print '</td></tr>';
 
 			// Date end
 			print '<tr><td>'.$langs->trans("DateEnd").'</td><td>';
-			print $form->select_date($object->date_end?$object->date_end:-1,'datee');
+			print $form->select_date($object->date_end?$object->date_end:-1,'datee',1,1,0,'',1,0,1);
 			print '</td></tr>';
 
 			// Planned workload
@@ -338,13 +392,13 @@ if ($id > 0 || ! empty($ref))
 			print $form->select_duration('planned_workload',$object->planned_workload,0,'text');
 			print '</td></tr>';
 
-			// Progress
-			print '<tr><td>'.$langs->trans("Progress").'</td><td colspan="3">';
+			// Progress declared
+			print '<tr><td>'.$langs->trans("ProgressDeclared").'</td><td colspan="3">';
 			print $formother->select_percent($object->progress,'progress');
 			print '</td></tr>';
 
 			// Description
-			print '<tr><td valign="top">'.$langs->trans("Description").'</td>';
+			print '<tr><td class="tdtop">'.$langs->trans("Description").'</td>';
 			print '<td>';
 			print '<textarea name="description" wrap="soft" cols="80" rows="'.ROWS_3.'">'.$object->description.'</textarea>';
 			print '</td></tr>';
@@ -359,10 +413,12 @@ if ($id > 0 || ! empty($ref))
 
 			print '</table>';
 
-			print '<center><br>';
+			dol_fiche_end();
+
+			print '<div align="center">';
 			print '<input type="submit" class="button" name="update" value="'.$langs->trans("Modify").'"> &nbsp; ';
 			print '<input type="submit" class="button" name="cancel" value="'.$langs->trans("Cancel").'">';
-			print '<center>';
+			print '</div>';
 
 			print '</form>';
 		}
@@ -370,10 +426,12 @@ if ($id > 0 || ! empty($ref))
 		{
 			/*
 			 * Fiche tache en mode visu
-			*/
+			 */
 			$param=($withproject?'&withproject=1':'');
 			$linkback=$withproject?'<a href="'.DOL_URL_ROOT.'/projet/tasks.php?id='.$projectstatic->id.'">'.$langs->trans("BackToList").'</a>':'';
 
+			dol_fiche_head($head, 'task_task', $langs->trans("Task"),0,'projecttask');
+
 			if ($action == 'delete')
 			{
 				print $form->formconfirm($_SERVER["PHP_SELF"]."?id=".$_GET["id"].'&withproject='.$withproject,$langs->trans("DeleteATask"),$langs->trans("ConfirmDeleteATask"),"confirm_delete");
@@ -382,12 +440,12 @@ if ($id > 0 || ! empty($ref))
 			print '<table class="border" width="100%">';
 
 			// Ref
-			print '<tr><td width="30%">';
+			print '<tr><td class="titlefield">';
 			print $langs->trans("Ref");
 			print '</td><td colspan="3">';
 			if (! GETPOST('withproject') || empty($projectstatic->id))
 			{
-				$projectsListId = $projectstatic->getProjectsAuthorizedForUser($user,$mine,1);
+				$projectsListId = $projectstatic->getProjectsAuthorizedForUser($user,0,1);
 				$object->next_prev_filter=" fk_projet in (".$projectsListId.")";
 			}
 			else $object->next_prev_filter=" fk_projet = ".$projectstatic->id;
@@ -414,26 +472,44 @@ if ($id > 0 || ! empty($ref))
 
 			// Date start
 			print '<tr><td>'.$langs->trans("DateStart").'</td><td colspan="3">';
-			print dol_print_date($object->date_start,'day');
+			print dol_print_date($object->date_start,'dayhour');
 			print '</td></tr>';
 
 			// Date end
 			print '<tr><td>'.$langs->trans("DateEnd").'</td><td colspan="3">';
-			print dol_print_date($object->date_end,'day');
+			print dol_print_date($object->date_end,'dayhour');
+        	if ($object->hasDelay()) print img_warning("Late");
 			print '</td></tr>';
 
 			// Planned workload
 			print '<tr><td>'.$langs->trans("PlannedWorkload").'</td><td colspan="3">';
-			print convertSecondToTime($object->planned_workload,'allhourmin');
+			if ($object->planned_workload != '')
+			{
+				print convertSecondToTime($object->planned_workload,'allhourmin');
+			}
 			print '</td></tr>';
 
-			// Progress
-			print '<tr><td>'.$langs->trans("Progress").'</td><td colspan="3">';
-			print $object->progress.' %';
+			// Progress declared
+			print '<tr><td>'.$langs->trans("ProgressDeclared").'</td><td colspan="3">';
+			if ($object->progress != '')
+			{
+				print $object->progress.' %';
+			}
+			print '</td></tr>';
+
+			// Progress calculated
+			print '<tr><td>'.$langs->trans("ProgressCalculated").'</td><td colspan="3">';
+			if ($object->planned_workload != '')
+			{
+				$tmparray=$object->getSummaryOfTimeSpent();
+				if ($tmparray['total_duration'] > 0 && ! empty($object->planned_workload)) print round($tmparray['total_duration'] / $object->planned_workload * 100, 2).' %';
+				else print '0 %';
+			}
+			else print '';
 			print '</td></tr>';
 
 			// Description
-			print '<td valign="top">'.$langs->trans("Description").'</td><td colspan="3">';
+			print '<td class="tdtop">'.$langs->trans("Description").'</td><td colspan="3">';
 			print nl2br($object->description);
 			print '</td></tr>';
 
@@ -447,46 +523,52 @@ if ($id > 0 || ! empty($ref))
 
 			print '</table>';
 
+			dol_fiche_end();
 		}
 
-		dol_fiche_end();
 
-
-		if ($_GET["action"] != 'edit')
+		if ($action != 'edit')
 		{
 			/*
 			 * Actions
-			*/
-			print '<div class="tabsAction">';
-
-			// Modify
-			if ($user->rights->projet->creer)
-			{
-				print '<a class="butAction" href="'.$_SERVER['PHP_SELF'].'?id='.$object->id.'&amp;action=edit&amp;withproject='.$withproject.'">'.$langs->trans('Modify').'</a>';
-			}
-			else
-			{
-				print '<a class="butActionRefused" href="#" title="'.$langs->trans("NotAllowed").'">'.$langs->trans('Modify').'</a>';
-			}
-
-			// Delete
-			if ($user->rights->projet->supprimer && ! $object->hasChildren())
-			{
-				print '<a class="butActionDelete" href="'.$_SERVER['PHP_SELF'].'?id='.$object->id.'&amp;action=delete&amp;withproject='.$withproject.'">'.$langs->trans('Delete').'</a>';
-			}
-			else
-			{
-				print '<a class="butActionRefused" href="#" title="'.$langs->trans("NotAllowed").'">'.$langs->trans('Delete').'</a>';
-			}
-
-			print '</div>';
-
-			print '<table width="100%"><tr><td width="50%" valign="top">';
-			print '<a name="builddoc"></a>'; // ancre
+ 			 */
+			
+		    print '<div class="tabsAction">';
 
+		    $parameters = array();
+		    $reshook = $hookmanager->executeHooks('addMoreActionsButtons', $parameters, $object, $action); // Note that $action and $object may have been
+		    // modified by hook
+		    if (empty($reshook))
+		    {
+				// Modify
+				if ($user->rights->projet->creer)
+				{
+					print '<a class="butAction" href="'.$_SERVER['PHP_SELF'].'?id='.$object->id.'&amp;action=edit&amp;withproject='.$withproject.'">'.$langs->trans('Modify').'</a>';
+				}
+				else
+				{
+					print '<a class="butActionRefused" href="#" title="'.$langs->trans("NotAllowed").'">'.$langs->trans('Modify').'</a>';
+				}
+	
+				// Delete
+				if ($user->rights->projet->supprimer && ! $object->hasChildren())
+				{
+					print '<a class="butActionDelete" href="'.$_SERVER['PHP_SELF'].'?id='.$object->id.'&amp;action=delete&amp;withproject='.$withproject.'">'.$langs->trans('Delete').'</a>';
+				}
+				else
+				{
+					print '<a class="butActionRefused" href="#" title="'.$langs->trans("NotAllowed").'">'.$langs->trans('Delete').'</a>';
+				}
+	
+				print '</div>';
+		    }
+		    
+    		print '<div class="fichecenter"><div class="fichehalfleft">';
+    		print '<a name="builddoc"></a>'; // ancre
+    		
 			/*
 			 * Documents generes
-			*/
+			 */
 			$filename=dol_sanitizeFileName($projectstatic->ref). "/". dol_sanitizeFileName($object->ref);
 			$filedir=$conf->projet->dir_output . "/" . dol_sanitizeFileName($projectstatic->ref). "/" .dol_sanitizeFileName($object->ref);
 			$urlsource=$_SERVER["PHP_SELF"]."?id=".$object->id;
@@ -495,11 +577,11 @@ if ($id > 0 || ! empty($ref))
 
 			$var=true;
 
-			$somethingshown=$formfile->show_documents('project_task',$filename,$filedir,$urlsource,$genallowed,$delallowed,$object->modelpdf);
+			print $formfile->showdocuments('project_task',$filename,$filedir,$urlsource,$genallowed,$delallowed,$object->modelpdf);
 
-
-
-			print '</td></tr></table>';
+			print '</div><div class="fichehalfright"><div class="ficheaddleft">';
+				
+			print '</div></div></div>';
 		}
 	}
 }
@@ -507,4 +589,3 @@ if ($id > 0 || ! empty($ref))
 
 llxFooter();
 $db->close();
-?>
