@@ -326,7 +326,7 @@ if ($result)
             $i++;
         }
 
-        $db->free();
+        $db->free($result);
 
         print "</table>\n";
         print "<!-- End last thirdparties modified -->\n";
