@@ -82,7 +82,7 @@ if ($key != $conf->global->CRON_KEY)
 // If param userlogin is reserved word 'firstadmin' 
 if ($userlogin == 'firstadmin')
 {
-    $sql='SELECT login from '.MAIN_DB_PREFIX.'user WHERE admin = 1 ORDER BY entity LIMIT 1';
+    $sql='SELECT login from '.MAIN_DB_PREFIX.'user WHERE admin = 1 and statut = 1 ORDER BY entity LIMIT 1';
     $resql=$db->query($sql);
     if ($resql)
     {
@@ -90,7 +90,7 @@ if ($userlogin == 'firstadmin')
         if ($obj) 
         {
             $userlogin = $obj->login;
-            echo "First admin user found is login '".$userlogin."'\n<br>";
+            echo "First admin user found is login '".$userlogin."'\n";
         }
     }
     else dol_print_error($db);
@@ -146,7 +146,8 @@ if(is_array($object->lines) && (count($object->lines)>0))
 	// Loop over job
 	foreach($object->lines as $line)
 	{
-	    dol_syslog("cron_run_jobs.php cronjobid: ".$line->id, LOG_WARNING);
+	    dol_syslog("cron_run_jobs.php cronjobid: ".$line->id, LOG_DEBUG);
+	    echo "cron_run_jobs.php cronjobid: ".$line->id."\n";
 	    
 		//If date_next_jobs is less of current date, execute the program, and store the execution time of the next execution in database
 		if (($line->datenextrun < $now) && (empty($line->datestart) || $line->datestart <= $now) && (empty($line->dateend) || $line->dateend >= $now))
